////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.PeerDocuments;

namespace Vela.ApplicationBackend
{
	/// <summary>
	/// Constants used for the application backend.
	/// </summary>
	public static class ApplicationBackendConsts
	{
		#region Public constants

		/// <summary>
		/// The minimum tally approval which an account must have in order to allow the remote peer to change the local
		/// wallpaper.
		/// </summary>
		public const TallyApprovals AllowChangeWallpaperApprovalMin = TallyApprovals.White;

		/// <summary>
		/// The minimum tally approval which an account must have in order to allow the remote peer to update the local
		/// emoticons with custom ones.
		/// </summary>
		public const TallyApprovals AllowUpdateWithCustomEmoticonsApprovalMin = TallyApprovals.White;

		/// <summary>
		/// The title of the folder where custom emoticons are.
		/// </summary>
		public const string CustomEmoticonsFolderTitle = "CustomEmoticons";

		/// <summary>
		/// The title of the root folder where files are saved.
		/// </summary>
		public const string RootSaveFolderTitle = "Downloaded";

		/// <summary>
		/// The maximum number of files to attach to a letter, to verify if they are readable. The limit exists because the
		/// verifying is a slow operation.
		/// </summary>
		public const int VerifyReadableFilesToAttachLimit = 50;

		/// <summary>
		/// The name of the (temporary) folder in which the clipboard images attached to letters are saved.
		/// </summary>
		public const string AttachClipboardImageFolderName = "ClipboardImages";

		/// <summary>
		/// The extension for a file which contains a clipboard image attached to a letter.
		/// </summary>
		public const string AttachClipboardImageFileExtension = ".png";

		/// <summary>
		/// The compression quality of the saved clipboard image which has to be attached to a letter. If this is 0 or a negative
		/// number, the image is saved in a lossless format.
		/// </summary>
		public const int AttachClipboardImageQuality = 0;

		/// <summary>
		/// The maximum number of emoticon symbols to show in a letter. If this is 0 or a negative number, it's ignored.
		/// </summary>
		public const int LetterEmoticonSymbolsCountMax = 7;

		#endregion Public constants
	}
}
