////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.ApplicationBackend
{
	/// <summary>
	/// The available closing modes of an application.
	/// </summary>
	public enum ApplicationCloseModes
	{
		/// <summary>
		/// The application is minimized, not closed. The application may be closed only if the user chooses to do so from the
		/// dedicated menu.
		/// </summary>
		Minimize,

		/// <summary>
		/// The user has chosen to close the application from the dedicated menu. The application may be closed only if the user
		/// gives his consent.
		/// </summary>
		UserPermission,

		/// <summary>
		/// The application must be closed without asking the user for consent, but must first perform cleanup operations.
		/// </summary>
		CleanUp,

		/// <summary>
		/// The application must be closed without asking the user for consent, and must not perform cleanup operations (they
		/// must have already been performed).
		/// </summary>
		Force
	}

	/// <summary>
	/// The available notifications of an application.
	/// </summary>
	public enum ApplicationNotifications
	{
		/// <summary>
		/// The application notification was never set. The vaults from the storehouse do NOT have their peer registrations
		/// started, and NO service listener is listening for client requests.
		/// </summary>
		None,

		/// <summary>
		/// At least 1 vault from the storehouse doesn't have its peer registrations started, or at least 1 service listener
		/// is not listening for client requests.
		/// </summary>
		OneNotStarted,

		/// <summary>
		/// All the service listeners are listening for client requests.
		/// </summary>
		AllServicesStarted,

		/// <summary>
		/// All the vaults from the storehouse have their peer registrations started, and all the service listeners are listening
		/// for client requests.
		/// </summary>
		AllStarted,

		/// <summary>
		/// A letter requires the attention of the user.
		/// </summary>
		NewLetter
	}
}
