////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.PeerDocuments;

namespace Vela.ApplicationBackend
{
	/// <summary>
	/// Asynchronously loaded letter information item.
	/// </summary>
	public class LetterAsyncItem
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LetterAsyncItem()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="letterLocator">Letter locator.</param>
		/// <param name="potentialImagePreviewFiles">The local attached files which can potentially be used for image previews.
		/// This may be null or empty.</param>
		public LetterAsyncItem( Locator letterLocator, LocalAttachedFiles potentialImagePreviewFiles )
		{
			LetterLocator = letterLocator;
			PotentialImagePreviewFiles = potentialImagePreviewFiles;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private DateTime _CreationTime = DateTime.UtcNow;
		/// <summary>
		/// The time (in UTC format) when the current object was created. This is automatically set with the time of the creation
		/// of the current object (and you should not modify it). READ-ONLY.
		/// </summary>
		public DateTime CreationTime
		{
			get { return _CreationTime; }
			protected set { _CreationTime = value; }
		}

		private Locator _LetterLocator;
		/// <summary>
		/// Letter locator. READ-ONLY.
		/// </summary>
		public Locator LetterLocator
		{
			get { return _LetterLocator; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "LetterLocator" );

				_LetterLocator = value;
			}
		}

		private LocalAttachedFiles _PotentialImagePreviewFiles;
		/// <summary>
		/// The local attached files which can potentially be used for image previews. This may be null or empty.
		/// </summary>
		public LocalAttachedFiles PotentialImagePreviewFiles
		{
			get { return _PotentialImagePreviewFiles; }
			set
			{
				_PotentialImagePreviewFiles = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
