////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ApplicationBackend
{
	/// <summary>
	/// List of asynchronously loaded letter information items (<see cref="LetterAsyncItem"/>).
	/// </summary>
	public class LetterAsyncItems : KernelDictionaryWithLimit<Locator, LetterAsyncItem>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public LetterAsyncItems()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Private methods

		/// <summary>
		/// Gets the age (in the current list) of the specified item.
		/// </summary>
		/// <param name="item">The item whose age to get. This is not validated.</param>
		/// <returns>Returns the age of the specified item.</returns>
		/// <remarks>
		/// <para>This is used by the <see cref="KernelDictionaryWithLimit{ TKey, TItem }.MakeRoomWhenLimitExceeded"/> method.
		/// </para>
		/// 
		/// <para><see cref="LetterAsyncItem.CreationTime"/> is used as age.</para>
		/// </remarks>
		protected override DateTime GetItemAge( LetterAsyncItem item )
		{
			return item.CreationTime;
		}

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The <see cref="LetterAsyncItem.LetterLocator"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( LetterAsyncItem item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.LetterLocator;
		}

		#endregion Public methods
	}
}
