////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Runtime.InteropServices;
using Microsoft.Win32;
using Vela.Kernel;

namespace Vela.ApplicationBackend
{
	/// <summary>
	/// System wallpaper utilities.
	/// </summary>
	public static class SystemWallpaperUtils
	{
		#region Private classes

		/// <summary>
		/// Native API utilities.
		/// </summary>
		private class NativeApi
		{
			public const int SPI_SETDESKWALLPAPER = 0x14;
			public const int SPIF_UPDATEINIFILE = 0x01;
			public const int SPIF_SENDWININICHANGE = 0x02;

			[DllImport( "user32.dll", CharSet = CharSet.Unicode )]
			public static extern bool SystemParametersInfo( uint uiAction, uint uiParam, string pvParam, uint fWinIni );
		}

		#endregion Private classes

		#region Private constants

		/// <summary>
		/// The path of the registry key which contains the configuration of the system's wallpaper.
		/// </summary>
		private const string DesktopRegistryKey = @"Control Panel\Desktop";

		#endregion Private constants

		#region Public static methods

		/// <summary>
		/// Sets the system's wallpaper with the specified file name.
		/// </summary>
		/// <param name="fileName">The name of the file to set as wallpaper.</param>
		public static void Set( string fileName )
		{
			ValidationUtils.TextHasContent( fileName, "fileName" );

			using( RegistryKey key = Registry.CurrentUser.OpenSubKey( DesktopRegistryKey, true ) )
			{
				key.SetValue( "TileWallpaper", "0" );
				key.SetValue( "WallpaperStyle", "0" ); // Center image.
			}

			NativeApi.SystemParametersInfo( NativeApi.SPI_SETDESKWALLPAPER, 0, fileName, NativeApi.SPIF_UPDATEINIFILE
				| NativeApi.SPIF_SENDWININICHANGE );
		}

		#endregion Public static methods
	}
}
