////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.ImBackend
{
	/// <summary>
	/// Constants used for the application backend.
	/// </summary>
	public static class ImBackendConsts
	{
		#region Public constants

		/// <summary>
		/// Template for the application title, with the storehouse name. Placeholders: 0 - default application title,
		/// 1 - storehouse name.
		/// </summary>
		public const string AppTitleTemplateWithStorehouseName = "{0} - {1}";

		/// <summary>
		/// The maximum number of items allowed in the list of logged records (<see cref="LogRecordsModel.LogRecords"/>). If this
		/// is 0 or a negative number, it's ignored.
		/// </summary>
		public const int LogRecordsCountMax = 500;

		/// <summary>
		/// The display format for the clock.
		/// </summary>
		public const string ClockFormat = "HH.mm";

		/// <summary>
		/// The time format for the long operation progress.
		/// </summary>
		public const string LopTimeFormat = "0.#";

		/// <summary>
		/// Template for the text which the user must type in order to delete a vault. Placeholders: 0 - entity name.
		/// </summary>
		public const string DeleteVaultConfirmationTemplate = "{0}";

		/// <summary>
		/// Template for the text which the user must type in order to delete a account. Placeholders: 0 - entity name.
		/// </summary>
		public const string DeleteAccountConfirmationTemplate = "{0}";

		/// <summary>
		/// The number of letters to show to the user.
		/// </summary>
		public const int ShowLetterCount = 100;

		/// <summary>
		/// When the letters to show to the user are collected from the storehouse, if this is true then it loads the information
		/// which takes a significant amount of time to load, else this information has to be loaded afterwards (preferably just
		/// for the visible letters).
		/// </summary>
		public const bool LoadTimeConsumingInformationWhenCollectingLetters = false;

		/// <summary>
		/// If this is true then the group image previews for letters are shown full-sized, else thumb-sized.
		/// </summary>
		public const bool ShowFullSizedGroupImagePreview = true;

		/// <summary>
		/// Template for the text which the user must type in order to delete multiple letters.
		/// </summary>
		public const string DeleteLettersConfirmationTemplate = "{0}";

		/// <summary>
		/// The emoticon which may be used to update the emoticons with custom emoticons.
		/// </summary>
		public static readonly string UpdateWithCustomEmoticonsEmoticon = ";Emoticons";

		/// <summary>
		/// Placeholder which is to be replaced with the file name of the playlist which contains media file names (to play).
		/// </summary>
		public const string PlaylistFileNamePlaceholder = "{PlaylistFileName}";

		/// <summary>
		/// The name of the (temporary) folder in which plain-text playlists are saved.
		/// </summary>
		public const string PlaylistFolderName = "Playlists";

		/// <summary>
		/// The extension for a file which contains a plain-text playlist.
		/// </summary>
		public const string PlaylistFileExtension = ".m3u8";

		/// <summary>
		/// The default password with which a storehouse is opened when it has to be automatically opened when the application
		/// starts (see <see cref="ImConfiguration.AutoStartStorehouseWithApplication"/>).
		/// </summary>
		public const string StorehousePasswordDef = "0123456789";

		#endregion Public constants
	}
}
