////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Networking;

namespace Vela.ImBackend
{
	/// <summary>
	/// Application utilities.
	/// </summary>
	public static class ImBackendUtils
	{
		#region Public static methods

		/// <summary>
		/// Gets information about how to use the alternative peer address, in order to avoid using the PNRP.
		/// </summary>
		/// <param name="longHostLabel">The long host label of the local peer.</param>
		/// /// <param name="shortHostLabel">The short host label of the local peer.</param>
		/// <returns>Returns information about how to use the alternative peer address, in order to avoid using the PNRP.
		/// </returns>
		public static string GetAlternativePeerAddressInfo( string longHostLabel, string shortHostLabel )
		{
			ValidationUtils.TextHasContent( longHostLabel, "longHostLabel" );
			ValidationUtils.TextHasContent( shortHostLabel, "shortHostLabel" );

			return string.Format( Properties.Resources.AlternativePeerAddressClipTemplate, longHostLabel, shortHostLabel
				, NetworkingUtils.GetLocalFullHostName() );
		}

		#endregion Public static methods
	}
}
