////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ImBackend
{
	/// <summary>
	/// Manager of application specific window views.
	/// </summary>
	/// <remarks>
	/// <para>Ensure that this class doesn't create windows before the application's main window is created.</para>
	/// </remarks>
	public class AppViewWindowsManager : IAppViewWindowsManager
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">The application model.</param>
		public AppViewWindowsManager( ApplicationModel applicationModel )
		{
			ValidationUtils.ObjectHasContent( applicationModel, "applicationModel" );

			ApplicationModel = applicationModel;
		}

		#endregion Constructors

		#region Private fields

		/// <summary>
		/// The application model. READ-ONLY.
		/// </summary>
		private ApplicationModel ApplicationModel;

		#endregion Private fields

		#region Public methods

		/// <summary>
		/// Shows the existing command lines output.
		/// </summary>
		public void ShowCommandLinesOutput()
		{
			CommandLinesOutputWindow.Show( ApplicationModel, null );
		}

		/// <summary>
		/// Appends the specified command line output to the existing ones, and shows it.
		/// </summary>
		/// <param name="creationTime">The creation time (in UTC format) of the command line.</param>
		/// <param name="commandLine">Command line to append. This may be null or empty.</param>
		/// <param name="commandLineOutput">Command line output to append. This may be null or empty.</param>
		public void ShowCommandLinesOutput( DateTime creationTime, string commandLine, string commandLineOutput )
		{
			CommandLinesOutputWindow.Show( ApplicationModel, creationTime, commandLine, commandLineOutput );
		}

		#endregion Public methods
	}
}
