////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Controls;

namespace Vela.ImBackend
{
	/// <summary>
	/// Contract for a model.
	/// </summary>
	public abstract class BaseModel : NotifyPropertyChanged, IModel
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected BaseModel()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">The application model.</param>
		public BaseModel( ApplicationModel applicationModel )
		{
			ApplicationModel = applicationModel;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private ApplicationModel _ApplicationModel;
		/// <summary>
		/// The application model. Notifies property observers. READ-ONLY.
		/// </summary>
		public ApplicationModel ApplicationModel
		{
			get { return _ApplicationModel; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "ApplicationModel" );

				_ApplicationModel = value;

				// Notify property observers.
				OnPropertyChanged( "ApplicationModel" );
			}
		}

		#endregion Public non-serializable properties
	}
}
