////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Controls;

namespace Vela.ImBackend
{
	/// <summary>
	/// Contract for an application specific user control view.
	/// </summary>
	/// <remarks>
	/// <para>Don't bind a view's UI to properties (from that view) whose values depend on the application model. If you were to
	/// do so, the UI would not be properly updated. Instead, create properties in the application model, notify the property
	/// observers, and bind to them.</para>
	/// </remarks>
	public class AppViewUserControl : ViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public AppViewUserControl()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public AppViewUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			ApplicationModel = applicationModel;
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The application model. Notifies property observers. READ-ONLY.
		/// </summary>
		public ApplicationModel ApplicationModel
		{
			get { return Model as ApplicationModel; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "ApplicationModel" );

				Model = value;

				// Notify property observers.
				OnPropertyChanged( "ApplicationModel" );
			}
		}

		#endregion Public non-serializable properties
	}
}
