////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Controls;
using Vela.Kernel;
using Vela.Storehouse;

namespace Vela.ImBackend
{
	/// <summary>
	/// Contract for an application specific window view.
	/// </summary>
	public abstract class AppViewWindow : ViewWindow
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected AppViewWindow()
		{
			DataContext = this;
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public AppViewWindow( ApplicationModel applicationModel )
		{
			ValidationUtils.ObjectHasContent( applicationModel, "applicationModel" );

			DataContext = this;
			ApplicationModel = applicationModel;
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The application model. Notifies property observers. READ-ONLY.
		/// </summary>
		public ApplicationModel ApplicationModel
		{
			get { return Model as ApplicationModel; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "ApplicationModel" );

				Model = value;

				// Notify property observers.
				OnPropertyChanged( "ApplicationModel" );
				OnPropertyChanged( "StorehouseModel" );
				OnPropertyChanged( "StorehouseProvider" );
				OnPropertyChanged( "StorehouseExists" );
			}
		}

		/// <summary>
		/// The storehouse model. This may be null. READ-ONLY.
		/// </summary>
		public StorehouseModel StorehouseModel
		{
			get { return ApplicationModel.StorehouseModel; }
		}

		/// <summary>
		/// The currently opened storehouse. This may be null. READ-ONLY.
		/// </summary>
		public IStorehouseProvider StorehouseProvider
		{
			get { return (StorehouseModel != null) ? StorehouseModel.StorehouseProvider : null; }
		}

		/// <summary>
		/// Is true if a storehouse is currently opened. READ-ONLY.
		/// </summary>
		public bool StorehouseExists
		{
			get { return (StorehouseProvider != null) && StorehouseProvider.StorehouseExists; }
		}

		#endregion Public non-serializable properties
	}
}
