////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.ComponentModel;
using Vela.ActionProcessor;
using Vela.ApplicationBackend;
using Vela.Kernel;

namespace Vela.ImBackend
{
	/// <summary>
	/// Window for deleting an account.
	/// </summary>
	public partial class DeleteAccountWindow : BackgroundOperationWindow
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected DeleteAccountWindow()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		/// <param name="accountLocator">The locator of the account to delete.</param>
		/// <param name="serviceManager">Action service manager which is used to stop processing action requests which have a
		/// multiframe action response. Its content must be thread safe.</param>
		/// <param name="clientManager">Action client manager which is used to stop processing action requests which have a
		/// multiframe action response. Its content must be thread safe.</param>
		public DeleteAccountWindow( ApplicationModel applicationModel, Locator accountLocator
				, IActionServiceManager serviceManager, IActionClientManager clientManager )
			: base( applicationModel )
		{
			ValidationUtils.ObjectHasContent( accountLocator, "accountLocator" );
			ValidationUtils.ObjectHasContent( serviceManager, "serviceManager" );
			ValidationUtils.ObjectHasContent( clientManager, "clientManager" );

			AccountLocator = accountLocator;
			ServiceManager = serviceManager;
			ClientManager = clientManager;

			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Private fields

		/// <summary>
		/// The locator of the account to delete.
		/// </summary>
		private Locator AccountLocator;

		/// <summary>
		/// Action service manager which is used to stop processing action requests which have a multiframe action response. Its
		/// content must be thread safe.
		/// </summary>
		private IActionServiceManager ServiceManager;

		/// <summary>
		/// Action client manager which is used to stop processing action requests which have a multiframe action response. Its
		/// content must be thread safe.
		/// </summary>
		private IActionClientManager ClientManager;

		#endregion Private fields

		#region Event handlers

		/// <summary>
		/// Method called when the background operation was successful.
		/// </summary>
		/// <param name="e">Information about the state of the background operation.</param>
		protected override void BackgroundOperationSuccessful( RunWorkerCompletedEventArgs e )
		{
			// Nothing to do.
		}

		#endregion Event handlers

		#region Private methods

		/// <summary>
		/// Executes the core of the background operation.
		/// </summary>
		/// <returns>Returns null.</returns>
		protected override object ExecuteCore()
		{
			StorehouseModel sm = StorehouseModel;

			ApplicationBackendStorehouse.DeleteAccount( sm.StorehouseProvider, AccountLocator, ServiceManager, ClientManager
				, LongOperationProgress );

			return null;
		}

		#endregion Private methods
	}
}
