////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.ActionProcessor;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ImDocuments
{
	/// <summary>
	/// Storehouse configuration.
	/// </summary>
	public class ImStorehouseConfiguration : ServiceListenersStorehouseConfiguration
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ImStorehouseConfiguration()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="actionListenerServices">The action service listener configurations.</param>
		public ImStorehouseConfiguration( ActionServiceListenerConfigurations actionListenerServices )
			: base( actionListenerServices )
		{
			PostFlags = new SortedStrings();

			AddPredefinedPostFlags();
		}

		#endregion Constructors

		#region Public serializable properties

		private SortedStrings _PostFlags;
		/// <summary>
		/// The available post flags. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public SortedStrings PostFlags
		{
			get { return _PostFlags; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "PostFlags" );

				_PostFlags = value;
			}
		}

		private string _DraftLetterMessage;
		/// <summary>
		/// The message of the draft letter. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string DraftLetterMessage
		{
			get { return _DraftLetterMessage; }
			set { _DraftLetterMessage = value; }
		}

		#endregion Public serializable properties

		#region Private methods

		/// <summary>
		/// This method is automatically called after the current object has been deserialized.
		/// </summary>
		protected virtual void Deserialized()
		{
			AddPredefinedPostFlags();
		}

		/// <summary>
		/// Adds the predefined post flags to the list of letter flags (<see cref="PostFlags"/>).
		/// </summary>
		private void AddPredefinedPostFlags()
		{
			string[] names = Enum.GetNames( typeof( PeerDocuments.PostFlags ) );

			foreach( string name in names )
				PostFlags.Add( name, true );
		}

		#endregion Private methods
	}
}
