////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows.Controls.Primitives;

namespace Vela.Controls
{
	/// <summary>
	/// Constants used for controls.
	/// </summary>
	public static class ControlsConsts
	{
		#region Public constants

		/// <summary>
		/// The initial show delay for tooltips.
		/// </summary>
		public const int TooltipInitialShowDelay = 1000;

		/// <summary>
		/// The delay for consecutive showing of tooltips.
		/// </summary>
		public const int TooltipBetweenShowDelay = 0;

		/// <summary>
		/// The show duration for tooltips.
		/// </summary>
		public const int TooltipShowDuration = int.MaxValue;

		/// <summary>
		/// The placement mode for tooltips.
		/// </summary>
		public const PlacementMode TooltipPlacement = PlacementMode.Mouse;

		/// <summary>
		/// The template for the file name of a mode image. Placeholders: 0 - mode.
		/// </summary>
		public const string ModeImageFileNameTemplate
			= "pack://application:,,,/Vela.Resources;component/Images/ThumbSized/{0}.png";

		/// <summary>
		/// The file name of the full-sized image to use when an image preview is not available.
		/// </summary>
		public const string FullSizedNoPreviewFileName
			= "pack://application:,,,/Vela.Resources;component/Images/FullSized/NoPreview.png";

		/// <summary>
		/// The file name of the thumb-sized image to use when an image preview is not available.
		/// </summary>
		public const string ThumbSizedNoPreviewFileName
			= "pack://application:,,,/Vela.Resources;component/Images/ThumbSized/NoPreview.png";

		/// <summary>
		/// The width of a tiny label column.
		/// </summary>
		public const double TinyLabelColumnWidth = 110;

		/// <summary>
		/// The width of a narrow label column.
		/// </summary>
		public const double NarrowLabelColumnWidth = 195;

		/// <summary>
		/// The width of a medium label column.
		/// </summary>
		public const double MediumLabelColumnWidth = 240;

		/// <summary>
		/// The width of a wide label column.
		/// </summary>
		public const double WideLabelColumnWidth = 350;

		/// <summary>
		/// The width of a tiny value column.
		/// </summary>
		public const double TinyValueColumnWidth = 135;

		/// <summary>
		/// The width of a narrow value column.
		/// </summary>
		public const double NarrowValueColumnWidth = 200;

		/// <summary>
		/// The width of a medium value column.
		/// </summary>
		public const double MediumValueColumnWidth = 385;

		/// <summary>
		/// The width of a wide value column.
		/// </summary>
		public const double WideValueColumnWidth = 500;

		/// <summary>
		/// The width of a jumbo value column.
		/// </summary>
		public const double JumboValueColumnWidth = 800;

		/// <summary>
		/// The sum of <see cref="NarrowLabelColumnWidth"/> and <see cref="MediumValueColumnWidth"/>.
		/// </summary>
		public const double NarrowLabel_MediumValue_ColumnWidth = NarrowLabelColumnWidth + MediumValueColumnWidth;

		#endregion Public constants
	}
}
