////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Controls
{
	/// <summary>
	/// The available modes for a message window.
	/// </summary>
	public enum TooltipWindowModes
	{
		/// <summary>
		/// The window shows a completion message.
		/// </summary>
		Done,

		/// <summary>
		/// The window shows an informational message.
		/// </summary>
		Info,

		/// <summary>
		/// The window shows a warning message.
		/// </summary>
		Warning,

		/// <summary>
		/// The window shows an image.
		/// </summary>
		Image,

		/// <summary>
		/// The window shows an image which is loaded in the image preview cache (<see cref="ImagePreviewsCache"/>).
		/// </summary>
		CachedImage
	}

	/// <summary>
	/// The available modes for a message window.
	/// </summary>
	public enum MessageWindowModes
	{
		/// <summary>
		/// The window shows an error message.
		/// </summary>
		Error,

		/// <summary>
		/// The window shows an informational message.
		/// </summary>
		Info,

		/// <summary>
		/// The window shows a query message.
		/// </summary>
		Query,

		/// <summary>
		/// The window shows a warning message.
		/// </summary>
		Warning
	}

	/// <summary>
	/// The available results for a query message window.
	/// </summary>
	public enum QueryMessageResults
	{
		/// <summary>
		/// The user has closed the window without choosing either the "Yes" or the "No" button.
		/// </summary>
		Okay,

		/// <summary>
		/// The user choose the "Yes" button.
		/// </summary>
		Yes,

		/// <summary>
		/// The user choose the "No" button.
		/// </summary>
		No
	}

	/// <summary>
	/// The available results for a choice message window.
	/// </summary>
	public enum ChoiceMessageResults
	{
		/// <summary>
		/// The user has closed the window without choosing either the left or the right button.
		/// </summary>
		Cancel,

		/// <summary>
		/// The user choose the left button.
		/// </summary>
		Left,

		/// <summary>
		/// The user choose the right button.
		/// </summary>
		Right
	}

	/// <summary>
	/// The available visibilities of an application.
	/// </summary>
	public enum ApplicationVisibilities
	{
		/// <summary>
		/// The application's current top window is visible.
		/// </summary>
		Normal,

		/// <summary>
		/// The application's main window is minimized.
		/// </summary>
		Minimized,

		/// <summary>
		/// The application's main window is hidden.
		/// </summary>
		Hidden
	}

	/// <summary>
	/// The available alignments for texts which are meant to be written on images.
	/// </summary>
	public enum TextOnImageAlignments
	{
		/// <summary>
		/// The text (frame) must be aligned at the bottom-center of the image.
		/// </summary>
		BottomCenter,

		/// <summary>
		/// The text (frame) must be aligned at the bottom-right of the image.
		/// </summary>
		BottomRight
	}
}
