////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.Controls
{
	/// <summary>
	/// A group image preview is a list of image previews (<see cref="ImagePreview"/>) which have the same group identifier.
	/// </summary>
	/// <remarks>
	/// <para>This is a sorted list to ensure that the image previews are always in the same order, to maintain consistency in
	/// the UI.</para>
	/// </remarks>
	public class GroupImagePreview : KernelSortedList<string, ImagePreview>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public GroupImagePreview()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="imagePreview">Image preview to add to the current group image preview.</param>
		public GroupImagePreview( ImagePreview imagePreview )
			: base( StringInsensitiveComparer.Instance )
		{
			Add( imagePreview );
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="ImagePreview.FileName"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( ImagePreview item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.FileName;
		}

		#endregion Public methods
	}
}
