////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows.Data;

namespace Vela.Controls
{
	/// <summary>
	/// Converts multiple boolean conditions to a single one.
	/// </summary>
	public class BoolConditionsConverter : IMultiValueConverter
	{
		#region Public methods

		/// <summary>
		/// Determines the emoticon file name which has to be used.
		/// </summary>
		/// <param name="values">The values to convert, as follows: emoticon manager, letter speckle.</param>
		/// <param name="targetType">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns true if all the specified values are true.</returns>
		public object Convert( object[] values, Type targetType, object parameter, CultureInfo culture )
		{
			if( values == null ) return null;

			foreach( object condition in values )
			{
				if( !(condition is bool) || !(bool)condition ) return false;
			}


			return true;
		}

		/// <summary>
		/// Converts back the specified value to the specified target types. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetTypes">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted values.</returns>
		public object[] ConvertBack( object value, Type[] targetTypes, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
