////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using Vela.Kernel;

namespace Vela.Controls
{
	/// <summary>
	/// Converts between an empty text and the <see cref="Visibility.Collapsed"/> visibility of a control.
	/// </summary>
	[ValueConversion( typeof( string ), typeof( Visibility ) )]
	public class EmptyTextToCollapsedVisibilityConverter : IValueConverter
	{
		#region Public methods

		/// <summary>
		/// Converts the specified value to the specified target type.
		/// </summary>
		/// <param name="value">Value to convert. This may be null.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value. This is null if "value" is null.</returns>
		public object Convert( object value, Type targetType, object parameter, CultureInfo culture )
		{
			return TextUtils.HasContent( value as string ) ? Visibility.Visible : Visibility.Collapsed;
		}

		/// <summary>
		/// Converts back the specified value to the specified target type. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value.</returns>
		public object ConvertBack( object value, Type targetType, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
