////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.ComponentModel;
using System.Globalization;
using System.Reflection;
using System.Windows.Data;
using Vela.Kernel;

namespace Vela.Controls
{
	/// <summary>
	/// Converter which provides the friendly name of an enumeration value.
	/// </summary>
	[ValueConversion( typeof( object ), typeof( string ) )]
	public class EnumDescriptionConverter : IValueConverter
	{
		#region Public methods

		/// <summary>
		/// Converts the specified value to the specified target type.
		/// </summary>
		/// <param name="value">Value to convert. This may be null.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value. This is null if "value" is null.</returns>
		public object Convert( object value, Type targetType, object parameter, CultureInfo culture )
		{
			if( value == null ) return null;

			FieldInfo fi = value.GetType().GetField( value.ToString() );
			if( fi == null ) return "";

			DescriptionAttribute[] attributes = (DescriptionAttribute[])fi.GetCustomAttributes( typeof( DescriptionAttribute )
				, false );

			return
				(ArrayUtils.HasContent( attributes ) && (attributes[ 0 ] != null)
					&& (TextUtils.HasContent( attributes[ 0 ].Description ))
				) ? attributes[ 0 ].Description : value.ToString();
		}

		/// <summary>
		/// Converts back the specified value to the specified target type. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value.</returns>
		public object ConvertBack( object value, Type targetType, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
