////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;

namespace Vela.Controls
{
	/// <summary>
	/// Loader for the preview of an image.
	/// </summary>
	public class ImagePreviewConverter : IMultiValueConverter
	{
		#region Public methods

		/// <summary>
		/// Loads the image preview.
		/// </summary>
		/// <param name="values">The values to convert, as follows: the name of the file to load, a boolean which if it's true
		/// indicates that the full-sized image is returned (else that the thumb-sized image is returned).</param>
		/// <param name="targetType">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the loaded image preview. This may be null.</returns>
		public object Convert( object[] values, Type targetType, object parameter, CultureInfo culture )
		{
			if( (values == null) || (values.Length != 2)
				|| (values[ 0 ] == null) || (values[ 1 ] == null)
				|| (values[ 0 ] == DependencyProperty.UnsetValue) || (values[ 1 ] == DependencyProperty.UnsetValue) )
			{
				return null;
			}

			string fileName = (string)values[ 0 ];
			bool loadFullSize = (bool)values[ 1 ];

			ImagePreview imagePreview = ImagePreviewsCache.GetCachedOrLoad( fileName, fileName, loadFullSize );

			return (imagePreview != null) ? imagePreview.Image : null;
		}

		/// <summary>
		/// Converts back the specified value to the specified target types. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetTypes">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted values.</returns>
		public object[] ConvertBack( object value, Type[] targetTypes, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
