////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;

namespace Vela.Controls
{
	/// <summary>
	/// Converts between a true boolean and the <see cref="Visibility.Hidden"/> visibility of a control.
	/// </summary>
	[ValueConversion( typeof( bool ), typeof( Visibility ) )]
	public class TrueToHiddenVisibilityConverter : IValueConverter
	{
		#region Public methods

		/// <summary>
		/// Converts the specified value to the specified target type.
		/// </summary>
		/// <param name="value">Value to convert. This may be null.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value. This is null if "value" is null.</returns>
		public object Convert( object value, Type targetType, object parameter, CultureInfo culture )
		{
			if( value == null ) return null;

			return (bool)value ? Visibility.Hidden : Visibility.Visible;
		}

		/// <summary>
		/// Converts back the specified value to the specified target type. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetType">Target type to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted value.</returns>
		public object ConvertBack( object value, Type targetType, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
