////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.Controls
{
	/// <summary>
	/// An attribute which may be applied on classes to indicate that they can be registered as views.
	/// </summary>
	[AttributeUsage( AttributeTargets.Class, AllowMultiple = false )]
	public abstract class ViewRegistrationAttribute : Attribute
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ViewRegistrationAttribute()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="sortKey">The sorting key.</param>
		public ViewRegistrationAttribute( string sortKey )
		{
			SortKey = sortKey;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private string _SortKey;
		/// <summary>
		/// The sorting key.
		/// </summary>
		public string SortKey
		{
			get { return _SortKey; }
			set
			{
				ValidationUtils.TextHasContent( value, "SortKey" );

				_SortKey = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
