////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Windows;
using Vela.Kernel;

namespace Vela.Controls
{
	/// <summary>
	/// A window where to show program information.
	/// </summary>
	public partial class AboutWindow : ViewWindow
	{
		#region Public constants

		/// <summary>
		/// Template of the version label.
		/// </summary>
		public const string VersionLabelTemplate = "Version {0} released on {1}";

		/// <summary>
		/// The default value for <see cref="WebsiteUrl"/>.
		/// </summary>
		public const string WebsiteUrlDef = "http://vela.im";

		#endregion Public constants

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected AboutWindow()
		{
			InitializeComponent();

			ProductNameLabel.Text = AssemblyUtils.ApplicationBuildInfo.ProductDisplayName;
			VersionLabel.Text = string.Format( VersionLabelTemplate, AssemblyUtils.ApplicationBuildInfo.Version
				, AssemblyUtils.ApplicationBuildInfo.ReleaseDate );
			AuthorLabel.Text = AssemblyUtils.ApplicationBuildInfo.Copyright;
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="websiteUrl">The URL of the website of the current program. If this is null or empty, the default value
		/// is used.</param>
		public AboutWindow( string websiteUrl )
			: this()
		{
			if( TextUtils.HasContent( websiteUrl ) ) WebsiteUrl = websiteUrl;
		}

		#endregion Constructors

		#region Private fields

		/// <summary>
		/// The URL of the website of the current program.
		/// </summary>
		private string WebsiteUrl = WebsiteUrlDef;

		#endregion Private fields

		#region Event handlers

		private void WebsiteButton_Click( object sender, RoutedEventArgs e )
		{
			FileUtils.RunFile( WebsiteUrl );
		}

		#endregion Event handlers
	}
}
