////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionClient
{
	/// <summary>
	/// List of action service listeners (<see cref="ActionClientChannel"/>).
	/// </summary>
	public class ActionClientChannels : KernelSortedList<Locator, ActionClientChannel>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public ActionClientChannels()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="ActionClientChannel.RequestLocator"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( ActionClientChannel item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.RequestLocator;
		}

		#endregion Public methods
	}
}
