////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionClient
{
	/// <summary>
	/// Exception which indicates that the processing of an action request by an action client must be skipped until the next
	/// retry.
	/// </summary>
	/// <remarks>
	/// <para>An action request which is skipped from processing should not have its processing status updated since there was
	/// no processing involved.</para>
	/// </remarks>
	public abstract class SkipProcessingActionRequestException : BaseException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public SkipProcessingActionRequestException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		/// <param name="details">Exception details. This may be null or empty.</param>
		public SkipProcessingActionRequestException( string message, Exception exception = null
				, params ExceptionDetail[] details )
			: base( message, exception, details )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception which indicates that the resolution of a UPN was already started.
	/// </summary>
	public class UpnResolutionInProgressException : SkipProcessingActionRequestException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public UpnResolutionInProgressException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		/// <param name="details">Exception details. This may be null or empty.</param>
		public UpnResolutionInProgressException( string message, Exception exception = null, params ExceptionDetail[] details )
			: base( message, exception, details )
		{
		}

		#endregion Constructors
	}
}
