////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionClient
{
	/// <summary>
	/// A request which has to be processed by the action client manager.
	/// </summary>
	public class PendingRequest
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected PendingRequest()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="requestLocator">The instance locator of the action request to process.</param>
		/// <param name="ignoreScheduler">If this is true then the action request with the specified locator must be processed
		/// even if the retry schedules don't allow it.</param>
		public PendingRequest( Locator requestLocator, bool ignoreScheduler )
		{
			RequestLocator = requestLocator;
			IgnoreScheduler = ignoreScheduler;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private Locator _RequestLocator;
		/// <summary>
		/// The instance locator of the action request to process.. READ-ONLY.
		/// </summary>
		public Locator RequestLocator
		{
			get { return _RequestLocator; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "RequestLocator" );

				_RequestLocator = value;
			}
		}

		private bool _IgnoreScheduler;
		/// <summary>
		/// If this is true then the referred action request must be processed even if the retry schedules don't allow it.
		/// READ-ONLY.
		/// </summary>
		public bool IgnoreScheduler
		{
			get { return _IgnoreScheduler; }
			protected set { _IgnoreScheduler = value; }
		}

		#endregion Public non-serializable properties
	}
}
