////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionClient
{
	/// <summary>
	/// List of pending requests (<see cref="PendingRequest"/>).
	/// </summary>
	public class PendingRequests : KernelList<PendingRequest>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PendingRequests()
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Finds the pending request with the specified request locator.
		/// </summary>
		/// <param name="requestLocator">Request locator to find.</param>
		/// <returns>Returns the found pending request, or null if none is found.</returns>
		public PendingRequest FindItemByRequestLocator( Locator requestLocator )
		{
			ValidationUtils.ObjectHasContent( requestLocator, "requestLocator" );

			foreach( PendingRequest pendingRequest in this )
			{
				if( pendingRequest.RequestLocator.Equals( requestLocator ) )
					return pendingRequest;
			}

			return null;
		}

		/// <summary>
		/// Finds the list index of the pending request with the specified request locator.
		/// </summary>
		/// <param name="requestLocator">Request locator to find.</param>
		/// <returns>Returns the index of the found pending request, or -1 if none is found.</returns>
		public int FindIndexByRequestLocator( Locator requestLocator )
		{
			ValidationUtils.ObjectHasContent( requestLocator, "requestLocator" );

			int count = Count;
			for( int i = 0; i < count; i++ )
			{
				if( Items[ i ].RequestLocator.Equals( requestLocator ) )
					return i;
			}

			return -1;
		}

		#endregion Public methods
	}
}
