////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.Kernel.Cloning;

namespace Vela.ActionClient
{
	/// <summary>
	/// Locker record for the resolution of a UPN by an action client.
	/// </summary>
	public class UpnResolutionLockerRecord : IUnclonable
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected UpnResolutionLockerRecord()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="upn">The UPN whose resolution to track.</param>
		public UpnResolutionLockerRecord( Upn upn )
		{
			Upn = upn;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private Upn _Upn;
		/// <summary>
		/// The UPN whose resolution to track. READ-ONLY.
		/// </summary>
		public Upn Upn
		{
			get { return _Upn; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "Upn" );

				_Upn = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
