////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionClient
{
	/// <summary>
	/// List of locker records for the resolution of UPNs by an action client (<see cref="UpnResolutionLockerRecord"/>).
	/// </summary>
	public class UpnResolutionLockerRecords : KernelDictionary<Locator, UpnResolutionLockerRecord>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public UpnResolutionLockerRecords()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The fingerprint of the <see cref="UpnResolutionLockerRecord.Upn"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( UpnResolutionLockerRecord item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.Upn.Fingerprint;
		}

		#endregion Public methods
	}
}
