////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Action client configuration.
	/// </summary>
	public class ActionClientConfiguration : IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionClientConfiguration()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="recipientAccessStatesManager">The recipient access states manager configuration.</param>
		public ActionClientConfiguration( RecipientAccessStatesManagerConfiguration recipientAccessStatesManager )
		{
			RecipientAccessStatesManager = recipientAccessStatesManager;
		}

		#endregion Constructors

		#region Public serializable properties

		private RecipientAccessStatesManagerConfiguration _RecipientAccessStatesManager;
		/// <summary>		
		/// The recipient access states manager configuration. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public RecipientAccessStatesManagerConfiguration RecipientAccessStatesManager
		{
			get { return _RecipientAccessStatesManager; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "RecipientAccessStatesManager" );

				_RecipientAccessStatesManager = value;
			}
		}

		#endregion Public serializable properties
	}
}
