////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Information about when the next processing attempt of an action request will be made.
	/// </summary>
	public class ActionNextProcessingAttempt
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionNextProcessingAttempt()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="nextTime">The time (in UTC format) when the next attempt to process the action request will be made.
		/// </param>
		public ActionNextProcessingAttempt( DateTime nextTime )
		{
			NextTime = nextTime;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private DateTime _NextTime;
		/// <summary>
		/// The time (in UTC format) when the next attempt to process the action request will be made. READ-ONLY.
		/// </summary>
		public DateTime NextTime
		{
			get { return _NextTime; }
			protected set { _NextTime = value; }
		}

		#endregion Public non-serializable properties
	}
}
