////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Dummy action client manager.
	/// </summary>
	public class DummyActionClientManager : IActionClientManager
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public DummyActionClientManager()
		{
		}

		#endregion Constructors

		#region Public non-serializable properties

		private IRecipientAccessStatesManager _RecipientAccessStatesManager = new DummyRecipientAccessStatesManager();
		/// <summary>
		/// Manager for the recipient access states. Its content is thread safe. The backing field is initialized by default.
		/// READ-ONLY.
		/// </summary>
		public IRecipientAccessStatesManager RecipientAccessStatesManager
		{
			get { return _RecipientAccessStatesManager; }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Adds the specified locator to the list of locators of action requests to process.
		/// </summary>
		/// <param name="requestLocator">The instance locator of the action request to process.</param>
		/// <param name="ignoreScheduler">If this is true then the action request with the specified locator must be processed
		/// even if the retry schedules don't allow it.</param>
		/// <remarks>
		/// <para>If the specified locator is already queued for processing, nothing happens.</para>
		/// </remarks>
		public void Add( Locator requestLocator, bool ignoreScheduler )
		{
			// Nothing to do.
		}

		/// <summary>
		/// Adds the specified locators to the list of locators of action requests to process.
		/// </summary>
		/// <param name="requestLocators">The instance locators of the action requests to process. This may be empty, but not
		/// null.</param>
		/// <param name="ignoreScheduler">If this is true then the action requests with the specified locators must be processed
		/// even if the retry schedules don't allow it.</param>
		/// <remarks>
		/// <para>If the specified locators are already queued for processing, nothing happens.</para>
		/// </remarks>
		public void Add( Locators requestLocators, bool ignoreScheduler )
		{
			// Nothing to do.
		}

		/// <summary>
		/// Stops the action client manager as soon as possible.
		/// </summary>
		public void Stop()
		{
			// Nothing to do.
		}

		/// <summary>
		/// Stops processing the action requests with the specified locators as soon as possible.
		/// </summary>
		/// <param name="requestLocators">The instance locators of the action requests whose processing to stop. If a locator
		/// refers to an action request which is not being processed, nothing happens (with that locator). This may be null or
		/// empty.</param>
		public void StopRequests( Locators requestLocators )
		{
			// Nothing to do.
		}

		#endregion Public methods
	}
}
