////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Dummy manager for the recipient access states.
	/// </summary>
	public class DummyRecipientAccessStatesManager : IRecipientAccessStatesManager
	{
		#region Public methods

		/// <summary>
		/// Resets the access state of the specified recipient UPN fingerprint after an attempt to resolve the specified
		/// recipient UPN fingerprint was successfully made.
		/// </summary>
		/// <param name="recipientUpnFingerprint">The recipient UPN fingerprint whose state to reset.</param>
		/// <remarks>
		/// <para>Call this method only after an attempt to resolve the recipient UPN fingerprint is successfully (but not yet
		/// securely) made.</para>
		/// </remarks>
		public void ResetOnSuccessfulUpnResolution( Locator recipientUpnFingerprint )
		{
			// Nothing to do.
		}

		/// <summary>
		/// Marks the access state of the specified recipient UPN fingerprint as being accessible.
		/// </summary>
		/// <param name="recipientUpnFingerprint">The UPN fingerprint of the recipient whose access state to mark as being
		/// accessible.</param>
		public void RecipientIsAccessibleAndProcessing( Locator recipientUpnFingerprint )
		{
			// Nothing to do.
		}

		/// <summary>
		/// Marks the access state of the specified recipient UPN fingerprint to be processed as soon as possible, by removing it
		/// from the list of states.
		/// </summary>
		/// <param name="recipientUpnFingerprint">The UPN fingerprint of the recipient whose access state to mark to be
		/// processed.</param>
		public void RetrySendingRequestsAsSoonAsPossible( Locator recipientUpnFingerprint )
		{
			// Nothing to do.
		}

		/// <summary>
		/// Gets information about when the next processing attempt of an action request whose recipient UPN fingerprint is
		/// <see cref="ActionProgress.RecipientUpnFingerprint"/> will be made.
		/// </summary>
		/// <param name="actionProgress">The action request progress for which to get the information.</param>
		/// <returns>Returns the information about the next processing attempt, or null if there may / will be no retry.
		/// </returns>
		public ActionNextProcessingAttempt GetNextProcessingAttempt( ActionClientProgress actionProgress )
		{
			return new ActionNextProcessingAttempt( DateTime.MinValue );
		}

		/// <summary>
		/// Gets information about when the next processing attempt of an action request whose recipient UPN fingerprint is
		/// specified will be made.
		/// </summary>
		/// <param name="recipientUpnFingerprint">The fingerprint of the UPN of the recipient for which to get the information.
		/// </param>
		/// <param name="processingState">The processing state of the action request.</param>
		/// <returns>Returns the information about the next processing attempt, or null if there may / will be no retry.
		/// </returns>
		public ActionNextProcessingAttempt GetNextProcessingAttempt( Locator recipientUpnFingerprint
			, ActionProcessingStates processingState )
		{
			return new ActionNextProcessingAttempt( DateTime.MinValue );
		}

		#endregion Public methods
	}
}
