////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action client host.
	/// </summary>
	/// <remarks>
	/// <para>An action client host is mainly used by an action client to update the user interface after an action request and
	/// response are processed, and also used to handle the interaction between the action client and its host application.
	/// </para>
	/// </remarks>
	public interface IActionClientHost : IActionProcessorHost
	{
		#region Public methods

		/// <summary>
		/// Updates the UI while an action request is being processed by an action client, and the service vault is revoked.
		/// </summary>
		/// <param name="serviceUpn">The UPN of the revoked service vault.</param>
		void UpdateUiRevokedServiceVault( Upn serviceUpn );

		/// <summary>
		/// Updates the UI while an action request is being processed by an action client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action client application after an
		/// action request and response are processed.</param>
		void UpdateUi( ActionClientHostUpdateUiContext updateUiContext );

		#endregion Public methods
	}
}
