////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Client-side progress for processing a <see cref="DownloadFilesActionRequest"/> action request.
	/// </summary>
	public class DownloadFilesActionClientProgress : ActionClientProgress
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected DownloadFilesActionClientProgress()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="initiatorUpnFingerprint">The UPN fingerprint of the initiator of the current object.</param>
		/// <param name="recipientUpnFingerprint">The UPN fingerprint of the recipient of the current object.</param>
		/// <param name="referredSheafLocator">The locator of the referred sheaf (which is referred by the referred
		/// action request).</param>
		/// <param name="referredActionRequestTypeName">The name of the type of the referred action request.</param>
		/// <param name="referredActionRequestLocator">The locator of the referred action request.</param>
		/// <param name="referredActionRequestDocumentExpirationTime">The document expiration time (in UTC format) of the
		/// referred action request. The current progress is valid before this time; from and after this time, it should not be
		/// used in processing.</param>
		/// <param name="progressIsPermanent">If this is true then after an action client processes the referred action request,
		/// the current progress is kept in the storehouse (else it's deleted).</param>
		public DownloadFilesActionClientProgress( Locator instanceLocator, Locator initiatorUpnFingerprint
				, Locator recipientUpnFingerprint, Locator referredSheafLocator, string referredActionRequestTypeName
				, Locator referredActionRequestLocator, DateTime referredActionRequestDocumentExpirationTime
				, bool progressIsPermanent )
			: base( instanceLocator, initiatorUpnFingerprint, recipientUpnFingerprint, referredSheafLocator
				, referredActionRequestTypeName, referredActionRequestLocator, referredActionRequestDocumentExpirationTime
				, progressIsPermanent )
		{
		}

		#endregion Constructors
	}
}
