////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Delegate which checks if an action processor must stop processing action requests as soon as possible.
	/// </summary>
	/// <returns>Returns true if the processing must stop.</returns>
	/// <remarks>
	/// <para>This must be thread safe.</para>
	/// </remarks>
	public delegate bool ProcessingMustStopDelegate();

	/// <summary>
	/// Delegate which indicates that an action processor must stop processing action requests as soon as possible.
	/// </summary>
	/// <remarks>
	/// <para>This must be thread safe.</para>
	/// </remarks>
	public delegate void SetProcessingMustStopDelegate();

	/// <summary>
	/// Delegate which checks if an action processor must stop processing the current action request as soon as possible.
	/// </summary>
	/// <param name="instanceLocator">The instance locator of the document which is being processed. For example, this could be
	/// the locator of an action request or of an access granter.</param>
	/// <param name="locatedDocumentType">The type of the document whose instance locator is "instanceLocator".</param>
	/// <returns>Returns true if the processing must stop.</returns>
	/// <remarks>
	/// <para>This must be thread safe.</para>
	/// </remarks>
	public delegate bool MultiframeProcessingMustStopDelegate( Locator instanceLocator, Type locatedDocumentType );
}
