////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Exception which indicates that the service is in maintenance.
	/// </summary>
	public class ServiceInMaintenanceException : RetryCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ServiceInMaintenanceException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public ServiceInMaintenanceException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception which indicates that an error message must be passed from the service to the client. The action client is
	/// informed that the service vault is revoked.
	/// </summary>
	public class RevokedVaultException : FatalCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected RevokedVaultException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		public RevokedVaultException( string message )
			: base( message )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public RevokedVaultException( string message, Exception exception )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception which indicates that a sheaf which is transported by an action request already exists in the storehouse of the
	/// peer which receives the action request because the action request was already processed (but the associated action
	/// response aren't saved in the storehouse).
	/// </summary>
	public class TransportedSheafExistsException : FatalCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected TransportedSheafExistsException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		/// <param name="details">Exception details. This may be null or empty.</param>
		public TransportedSheafExistsException( string message, Exception exception = null, params ExceptionDetail[] details )
			: base( message, exception, details )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception which indicates that an expected interaction session is missing.
	/// </summary>
	public class MissingInteractionSessionException : FatalCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected MissingInteractionSessionException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public MissingInteractionSessionException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}
}
