////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action response associated to an action request which was processed in the name of an initiator account.
	/// </summary>
	public abstract class ActionResponseWithInitiator : ActionResponse
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionResponseWithInitiator()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <remarks>
		/// <para>This is the standard constructor for an action response, and is mandatory if the associated action request has
		/// its <see cref="ActionRequest.ServiceResponseIsConsistentWithStandardConstructor"/> property true, because it may be
		/// invoked dynamically (if the request was already processed by the action service).</para>
		/// </remarks>
		public ActionResponseWithInitiator( Locator instanceLocator, ActionRequestWithInitiator actionRequest
				, SecondaryProcessingState secondaryProcessingState )
			: base( instanceLocator, actionRequest, secondaryProcessingState )
		{
		}

		#endregion Constructors
	}
}
