////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// An action response which is the last frame of a multiframe action response. When an action client receives such a
	/// response, it must stop processing the current request.
	/// </summary>
	/// <remarks>
	/// <para>An action response with this type is sent after all the frames of a multiframe response are sent. This allows both
	/// the service and the client to perform specific operations after the entire multiframe response is sent / received
	/// successfully.</para>
	/// </remarks>
	public class LastFrameActionResponse : AnonymousActionResponse
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LastFrameActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <param name="remoteProcessingIdentity">Remote processing identity publisher.</param>
		public LastFrameActionResponse( Locator instanceLocator, ActionRequest actionRequest
				, SecondaryProcessingState secondaryProcessingState, IIdentityPublisher remoteProcessingIdentity )
			: base( instanceLocator, actionRequest, secondaryProcessingState, remoteProcessingIdentity )
		{
		}

		#endregion Constructors
	}
}
