////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;
using Vela.PeerDocuments;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// An action response for an anonymous action request to get a presenter and create an account.
	/// </summary>
	public class CreateAccountAnonymousActionResponse : AnonymousActionResponse
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected CreateAccountAnonymousActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <param name="presenter">The presenter.</param>
		public CreateAccountAnonymousActionResponse( Locator instanceLocator, AnonymousActionRequest actionRequest
				, SecondaryProcessingState secondaryProcessingState, Presenter presenter )
			: base( instanceLocator, actionRequest, secondaryProcessingState, presenter.ProcessingIdentity )
		{
			Presenter = presenter;
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The time (in UTC format) from which the current object expires and should no longer be used in processing.
		/// READ-ONLY.
		/// </summary>
		public override DateTime ExpirationTime
		{
			get { return KernelUtils.MinTime( base.ExpirationTime, Presenter.ExpirationTime ); }
		}

		#endregion Public non-serializable properties

		#region Public serializable properties

		private Presenter _Presenter;
		/// <summary>
		/// The presenter. READ-ONLY.
		/// </summary>
		/// <remarks>
		/// <para>This must be self-signed.</para>
		/// </remarks>
		[SerializeAttribute]
		public Presenter Presenter
		{
			get { return _Presenter; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "Presenter" );

				_Presenter = value;
			}
		}

		#endregion Public serializable properties
	}
}
