////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// An action response for an anonymous action request to get a file (in its entirety).
	/// </summary>
	public class GetFileAnonymousActionResponse : AnonymousActionResponse
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected GetFileAnonymousActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <param name="remoteProcessingIdentity">Remote processing identity publisher.</param>
		/// <param name="fileContent">The content of the file. This may be null or empty.</param>
		public GetFileAnonymousActionResponse( Locator instanceLocator, AnonymousActionRequest actionRequest
				, SecondaryProcessingState secondaryProcessingState, IIdentityPublisher remoteProcessingIdentity
				, byte[] fileContent )
			: base( instanceLocator, actionRequest, secondaryProcessingState, remoteProcessingIdentity )
		{
			FileContent = fileContent;
		}

		#endregion Constructors

		#region Public serializable properties

		private byte[] _FileContent;
		/// <summary>
		/// The content of the file. This may be null or empty. READ-ONLY.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public byte[] FileContent
		{
			get { return _FileContent; }
			protected set { _FileContent = value; }
		}

		#endregion Public serializable properties
	}
}
