////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// An action response for a request to open an interaction session in the name of an initiator account.
	/// </summary>
	public class OpenSessionActionResponse : ActionResponseWithInitiator
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected OpenSessionActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		public OpenSessionActionResponse( Locator instanceLocator, ActionRequestWithInitiator actionRequest
				, SecondaryProcessingState secondaryProcessingState )
			: base( instanceLocator, actionRequest, secondaryProcessingState )
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private UInt16 _ProcessingPort;
		/// <summary>
		/// The service network port through which to transfer data. This must be at least 1. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public UInt16 ProcessingPort
		{
			get { return _ProcessingPort; }
			protected set
			{
				ValidationUtils.Integer( value, 1, UInt16.MaxValue, "ProcessingPort" );

				_ProcessingPort = value;
			}
		}

		#endregion Public serializable properties
	}
}
