////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// An action response for a request to send a letter.
	/// </summary>
	public class SendLetterActionResponse : ActionResponseWithInitiator
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected SendLetterActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <remarks>
		/// <para>This is the standard constructor for an action response, and is mandatory if the associated action request has
		/// its <see cref="ActionRequest.ServiceResponseIsConsistentWithStandardConstructor"/> property true, because it may be
		/// invoked dynamically (if the request was already processed by the action service).</para>
		/// </remarks>
		public SendLetterActionResponse( Locator instanceLocator, ActionRequestWithInitiator actionRequest
				, SecondaryProcessingState secondaryProcessingState )
			: base( instanceLocator, actionRequest, secondaryProcessingState )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <param name="secondaryProcessingOutput">Is set with the output of the secondary processing. This may be used to send
		/// back to the client a large amount of data which should not be stored in an action progress (where the secondary
		/// processing state is stored). It's highly recommended to treat this information as ephemeral (in terms of storage
		/// requirements). This may be null or empty.</param>
		public SendLetterActionResponse( Locator instanceLocator, ActionRequestWithInitiator actionRequest
				, SecondaryProcessingState secondaryProcessingState, string secondaryProcessingOutput )
			: base( instanceLocator, actionRequest, secondaryProcessingState )
		{
			SecondaryProcessingOutput = secondaryProcessingOutput;
		}

		#endregion Constructors
	}
}
