////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Dummy action service manager.
	/// </summary>
	public class DummyActionServiceManager : IActionServiceManager
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public DummyActionServiceManager()
		{
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// If this is true then the current peer is normally online, else it's always offline and therefore no action client and
		/// service managers are created. READ-ONLY.
		/// </summary>
		public bool PeerIsOnline
		{
			get { return false; }
		}

		/// <summary>
		/// If this is true then the UPN resolvers (like the PNRP) will be used to register UPNs, and resolve UPNs to IP
		/// addresses. If this is false then the UPN resolvers will not be used, so the alternative peer resolution must be used
		/// instead. The default is false. READ-ONLY.
		/// </summary>
		public bool UseUpnResolvers
		{
			get { return false; }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Returns the state of the action service manager.
		/// </summary>
		public ActionServiceManagerStates AreAllRegisteredAndListening()
		{
			return ActionServiceManagerStates.OneNotRegisteredOrListening;
		}

		/// <summary>
		/// Stops the action service manager as soon as possible.
		/// </summary>
		public void Stop()
		{
			// Nothing to do.
		}

		/// <summary>
		/// Stops processing the action requests with the specified locators as soon as possible.
		/// </summary>
		/// <param name="requestLocators">The instance locators of the action requests whose processing to stop. If a locator
		/// refers to an action request which is not being processed, nothing happens (with that locator). This may be null or
		/// empty. This must be thread safe.</param>
		public void StopRequests( Locators requestLocators )
		{
			// Nothing to do.
		}

		#endregion Public methods
	}
}
