////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action service host.
	/// </summary>
	/// <remarks>
	/// <para>An action service host is mainly used by an action service to update the user interface after an action request and
	/// response are processed, and also used to handle the interaction between the action client and its host application.
	/// </para>
	/// </remarks>
	public interface IActionServiceHost : IActionProcessorHost
	{
		#region Public methods

		/// <summary>
		/// Updates the UI after an action request was successfully processed by an action service, and a response was sent to
		/// the client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action service application after an
		/// action request and response are processed.</param>
		void UpdateUi( ActionServiceHostUpdateUiContext updateUiContext );

		#endregion Public methods
	}
}
