////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Cloning;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action service manager.
	/// </summary>
	public interface IActionServiceManager : IUnclonable
	{
		#region Public non-serializable properties

		/// <summary>
		/// If this is true then the current peer is normally online, else it's always offline and therefore no action client and
		/// service managers are created. READ-ONLY.
		/// </summary>
		bool PeerIsOnline { get; }

		/// <summary>
		/// If this is true then the UPN resolvers (like the PNRP) will be used to register UPNs, and resolve UPNs to IP
		/// addresses. If this is false then the UPN resolvers will not be used, so the alternative peer resolution must be used
		/// instead. READ-ONLY.
		/// </summary>
		bool UseUpnResolvers { get; }

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Returns the state of the action service manager.
		/// </summary>
		ActionServiceManagerStates AreAllRegisteredAndListening();

		/// <summary>
		/// Stops the action service manager as soon as possible.
		/// </summary>
		void Stop();

		/// <summary>
		/// Stops processing the action requests with the specified locators as soon as possible.
		/// </summary>
		/// <param name="requestLocators">The instance locators of the action requests whose processing to stop. If a locator
		/// refers to an action request which is not being processed, nothing happens (with that locator). This may be null or
		/// empty. This must be thread safe.</param>
		void StopRequests( Locators requestLocators );

		#endregion Public methods
	}
}
