////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Reflection;
using Vela.Kernel;
using Vela.Kernel.Cloning;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Method information which allows an action processor to handle an action request.
	/// </summary>
	public class HandleRequestMethodInfo : IUnclonable
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected HandleRequestMethodInfo()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="requestTypeName">The type name of the action request to be handled by the "methodInfo" method.</param>
		/// <param name="methodInfo">The information of the method which must be executed when an action request with the type
		/// name "requestTypeName" has to be handled.</param>
		public HandleRequestMethodInfo( string requestTypeName, MethodInfo methodInfo )
		{
			RequestTypeName = requestTypeName;
			MethodInfo = methodInfo;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private string _RequestTypeName;
		/// <summary>
		/// The type name of the action request to be handled by the <see cref="MethodInfo"/> method. READ-ONLY.
		/// </summary>
		public string RequestTypeName
		{
			get { return _RequestTypeName; }
			protected set
			{
				ValidationUtils.TextHasContent( value, "RequestTypeName" );

				_RequestTypeName = value;
			}
		}

		[UnclonableAttribute]
		private MethodInfo _MethodInfo;
		/// <summary>
		/// The information of the method which must be executed when an action request with the type name
		/// <see cref="RequestTypeName"/> has to be handled. READ-ONLY.
		/// </summary>
		public MethodInfo MethodInfo
		{
			get { return _MethodInfo; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "MethodInfo" );

				_MethodInfo = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
