////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// The configuration of the storehouse which contains listener configurations for an action service.
	/// </summary>
	public class ServiceListenersStorehouseConfiguration : StorehouseConfiguration
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ServiceListenersStorehouseConfiguration()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="actionServiceListeners">The action service listener configurations.</param>
		public ServiceListenersStorehouseConfiguration( ActionServiceListenerConfigurations actionServiceListeners )
		{
			ActionServiceListeners = actionServiceListeners;
		}

		#endregion Constructors

		#region Public serializable properties

		private ActionServiceListenerConfigurations _ActionServiceListeners;
		/// <summary>
		/// The action service listener configurations. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public ActionServiceListenerConfigurations ActionServiceListeners
		{
			get { return _ActionServiceListeners; }
			protected set
			{
				ValidationUtils.ListHasContent( value, "ActionServiceListeners" );

				_ActionServiceListeners = value;
			}
		}

		#endregion Public serializable properties
	}
}
