////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Address for a UPN resolver service.
	/// </summary>
	public class UpnResolverAddress : IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected UpnResolverAddress()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="name">The name.</param>
		/// <param name="url">The URL.</param>
		/// <param name="processingPort">The network port where requests are received from clients.</param>
		public UpnResolverAddress( string name, string url, UInt16 processingPort )
		{
			Name = name;
			Url = url;
			ProcessingPort = processingPort;
		}

		#endregion Constructors

		#region Public serializable properties

		private string _Name;
		/// <summary>
		/// The name. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string Name
		{
			get { return _Name; }
			protected set
			{
				ValidationUtils.TextHasContent( value, "Name" );

				_Name = value;
			}
		}

		private string _Url;
		/// <summary>
		/// The URL. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string Url
		{
			get { return _Url; }
			protected set
			{
				ValidationUtils.TextHasContent( value, "Url" );

				_Url = value;
			}
		}

		private UInt16 _ProcessingPort;
		/// <summary>
		/// The network port where requests are received from clients. READ-ONLY.
		/// </summary>
		public UInt16 ProcessingPort
		{
			get { return _ProcessingPort; }
			protected set
			{
				ValidationUtils.Integer( value, 1, UInt16.MaxValue, "ProcessingPort" );

				_ProcessingPort = value;
			}
		}

		#endregion Public serializable properties
	}
}
