////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// List of addresses for UPN resolver services (<see cref="UpnResolverAddress"/>).
	/// </summary>
	public class UpnResolverAddresses : KernelSortedList<string, UpnResolverAddress>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public UpnResolverAddresses()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The <see cref="UpnResolverAddress.Name"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( UpnResolverAddress item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.Name;
		}

		#endregion Public methods
	}
}
