////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an algorithm which generates the retry timespan for the processing of action requests by an action client.
	/// </summary>
	/// <remarks>
	/// <para>An action client may retry to process an action request (an unlimited number of times) until it expires.</para>
	/// </remarks>
	public interface IActionClientRetryScheduleAlg : IImmutableAlgorithm
	{
		#region Public methods

		/// <summary>
		/// Generates the timespan (in seconds) corresponding to the specified retry index.
		/// </summary>
		/// <param name="retryIndex">The index of the last retry to process the referred action request. If this is a negative
		/// value, it means that no retry has been made to process the action request, so 0 is returned.</param>
		/// <returns>Returns the timespan (in seconds) corresponding to the specified retry index.</returns>
		/// <remarks>
		/// <para>An action client has to wait this timespan between consecutive attempts to send an action request to an
		/// action service.</para>
		/// 
		/// <para>The returned timespan is (partly) random.</para>
		/// 
		/// <para>Generally, the higher the retry index is, the higher the timespan is, but there is no guarantee. For any given
		/// retry index, the generated timespan can be smaller or greater than the timespan generated for the previous retry
		/// index.</para>
		/// </remarks>
		double GenerateTimespan( int retryIndex );

		#endregion Public methods
	}
}
