////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Cloning;

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action processor host.
	/// </summary>
	/// <remarks>
	/// <para>An action processor host is mainly used by an action processor to update the user interface when an action request
	/// or response is processed, and also used to handle the interaction between the action client and its host application.
	/// </para>
	/// 
	/// <para>This is meant to be mostly used from a background thread, so it must be synchronized if it's necessary, preferably
	/// using a dispatcher.</para>
	/// 
	/// <para>Exceptions occurred during execution of the member methods are not thrown, they are logged. If they were to be
	/// thrown, they would be thrown on the current / UI thread, not the calling thread, which would cause an error message to be
	/// shown (when caught globally).</para>
	/// </remarks>
	public interface IActionProcessorHost : IUnclonable
	{
		#region Public methods

		/// <summary>
		/// Checks if the action processor is under maintenance.
		/// </summary>
		bool CheckMaintenance();

		#endregion Public methods
	}
}
