////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.ActionProcessor
{
	/// <summary>
	/// Contract for an action request for which the action service which receives it will send a multiframe action response
	/// (= multiple action responses, called frames).
	/// </summary>
	/// <remarks>
	/// <para>A multiframe action response is composed by multiple frames which are sequentially sent by an action service back
	/// to the initiator of the action request (of this type).</para>
	/// </remarks>
	public interface IActionRequestWithMultiframeResponse
	{
		#region Public non-serializable properties

		/// <summary>
		/// If this is true then an action service must encrypt the action responses from the frames of a multiframe response.
		/// This may be false because the frames are (further) encrypted / obfuscated with the response encryption key.
		/// </summary>
		/// <remarks>
		/// <para>If this is false, <see cref="ActionRequest.ServiceShouldCompressResponse"/> is ignored because compression is
		/// only performed when using encrypted envelopes.</para>
		/// 
		/// <para>If this is false, the size of the content of the action response frames is not aligned, so you should either
		/// manually align the size, or send a fixed or random amount of information in each frame.</para>
		/// </remarks>
		bool ServiceMustEncryptResponsesInFrames { get; set; }

		#endregion Public non-serializable properties
	}
}
