////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionService
{
	/// <summary>
	/// List of action service listener workers (<see cref="ActionServiceListenerWorker"/>).
	/// </summary>
	public class ActionServiceListenerWorkers : KernelSortedList<Int64, ActionServiceListenerWorker>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public ActionServiceListenerWorkers()
			: base( Int64Comparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="ActionServiceListenerWorker.InstanceId"/> is used as key.</para>
		/// </remarks>
		public override Int64 GetKey( ActionServiceListenerWorker item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.InstanceId;
		}

		#endregion Public methods
	}
}
