////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionService
{
	/// <summary>
	/// List of action service listeners (<see cref="ActionServiceListener"/>).
	/// </summary>
	public class ActionServiceListeners : KernelSortedList<int, ActionServiceListener>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public ActionServiceListeners()
			: base( IntComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="ActionServiceListener.ProcessingPort"/> is used as key.</para>
		/// </remarks>
		public override int GetKey( ActionServiceListener item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.ProcessingPort;
		}

		/// <summary>
		/// Returns true if all the listeners are listening for client requests, and false if there is at least 1 which is not
		/// listening.
		/// </summary>
		public bool AreAllListening()
		{
			foreach( ActionServiceListener listener in this )
			{
				if( !listener.IsListening )
					return false; // There is a listener which is not listening for client requests.
			}

			// All the listeners are listening for client requests.
			return true;
		}

		#endregion Public methods
	}
}
