////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.CoreDocuments;
using Vela.PeerDocuments;

namespace Vela.ActionService
{
	/// <summary>
	/// A vault which can be the recipient of action requests
	/// (<see cref="Vela.ActionProcessor.ActionRequest"/>).
	/// </summary>
	public class ActionServiceVault
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionServiceVault()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="vault">The service vault.</param>
		public ActionServiceVault( Vault vault )
		{
			Vault = vault;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private Upns _Upns;
		/// <summary>
		/// The UPNs of the vault of the service. This is null if <see cref="Vault"/> is null. READ-ONLY.
		/// </summary>
		public Upns Upns
		{
			get { return _Upns; }
		}

		private Vault _Vault;
		/// <summary>
		/// The service vault. READ-ONLY.
		/// </summary>
		public Vault Vault
		{
			get { return _Vault; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "Vault" );

				_Vault = value;

				_Upns = null;
			}
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Generates the UPNs (and their lazy loaded properties) of the vault of the service.
		/// </summary>
		public void GenerateUpns()
		{
			_Upns = null;

			if( Vault == null ) return;

			_Upns = Vault.GenerateUpns();
		}

		#endregion Public methods
	}
}
