////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ActionService
{
	/// <summary>
	/// Context for processing an action request with initiator.
	/// </summary>
	/// <remarks>
	/// <para>When an action request arrives at the service for processing, the initiator account context is loaded from the
	/// service's storehouse. This context is forwarded to the action processing method.</para>
	/// </remarks>
	public class ActionRequestWithInitiatorContext : ActionRequestContext
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionRequestWithInitiatorContext()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="serviceContext">The service context.</param>
		/// <param name="actionResponseLocator">The locator of the action response associated to the current action
		/// request.</param>
		/// <param name="initiatorAccountContext">The account context of the initiator of the action request, for which to
		/// process the action request.</param>
		public ActionRequestWithInitiatorContext( ActionServiceContext serviceContext, Locator actionResponseLocator
				, ActionAccountContext initiatorAccountContext )
			: base( serviceContext, null, actionResponseLocator )
		{
			InitiatorAccountContext = initiatorAccountContext;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private ActionAccountContext _InitiatorAccountContext;
		/// <summary>
		/// The account context of the initiator of the action request, for which to process the action request. READ-ONLY.
		/// </summary>
		public ActionAccountContext InitiatorAccountContext
		{
			get { return _InitiatorAccountContext; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "InitiatorAccountContext" );

				_InitiatorAccountContext = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
