////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Net.Sockets;
using Vela.Kernel;
using Vela.Kernel.Cloning;

namespace Vela.ActionService
{
	/// <summary>
	/// Action service listener worker context.
	/// </summary>
	public class ActionServiceListenerWorkerContext
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionServiceListenerWorkerContext()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="listenerContext">Service listener context.</param>
		/// <param name="requestSocket">Request socket.</param>
		/// <param name="initiatorIpAddress">The IP address of the initiator of the request.</param>
		public ActionServiceListenerWorkerContext( ActionServiceListenerContext listenerContext, Socket requestSocket
			, byte[] initiatorIpAddress )
		{
			ListenerContext = listenerContext;
			RequestSocket = requestSocket;
			InitiatorIpAddress = initiatorIpAddress;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private ActionServiceListenerContext _ListenerContext;
		/// <summary>
		/// Action service listener context. READ-ONLY.
		/// </summary>
		public ActionServiceListenerContext ListenerContext
		{
			get { return _ListenerContext; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "ListenerContext" );

				_ListenerContext = value;
			}
		}

		[UnclonableAttribute]
		private Socket _RequestSocket;
		/// <summary>
		/// Request socket. READ-ONLY.
		/// </summary>
		public Socket RequestSocket
		{
			get { return _RequestSocket; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "RequestSocket" );

				_RequestSocket = value;
			}
		}

		private byte[] _InitiatorIpAddress;
		/// <summary>
		/// The IP address of the initiator of the request. READ-ONLY.
		/// </summary>
		public byte[] InitiatorIpAddress
		{
			get { return _InitiatorIpAddress; }
			protected set
			{
				ValidationUtils.ArrayHasContent( value, "InitiatorIpAddress" );

				_InitiatorIpAddress = value;
			}
		}

		#endregion Public non-serializable properties
	}
}
