////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.ActionService
{
	/// <summary>
	/// List of action traffic filter records (<see cref="TrafficFilterRecord"/>).
	/// </summary>
	public class TrafficFilterRecords : KernelDictionaryWithLimit<byte[], TrafficFilterRecord>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public TrafficFilterRecords()
			: base( BufferComparer.Instance )
		{
		}

		#endregion Constructors

		#region Private methods

		/// <summary>
		/// Gets the age (in the current list) of the specified item.
		/// </summary>
		/// <param name="item">The item whose age to get. This is not validated.</param>
		/// <returns>Returns the age of the specified item.</returns>
		/// <remarks>
		/// <para>This is used by the <see cref="KernelDictionaryWithLimit{ TKey, TItem }.MakeRoomWhenLimitExceeded"/> method.
		/// </para>
		/// 
		/// <para><see cref="TrafficFilterRecord.LastResetTime"/> is used as age.</para>
		/// </remarks>
		protected override DateTime GetItemAge( TrafficFilterRecord item )
		{
			return item.LastResetTime;
		}

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The <see cref="TrafficFilterRecord.IpAddress"/> is used as key.</para>
		/// </remarks>
		public override byte[] GetKey( TrafficFilterRecord item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.IpAddress;
		}

		#endregion Public methods
	}
}
