////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.PeerDocuments;
using Tuple = Vela.Kernel.Tuple;

namespace Vela.ApplicationDocuments
{
	/// <summary>
	/// A speckle for vaults.
	/// </summary>
	public class VaultSpeckle : ViewSpeckle
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected VaultSpeckle()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="storehouseKey">The storehouse key of the referred sheaf. This must be unique in the storehouse.
		/// </param>
		/// <param name="sheafTypeName">The type name of the stored sheaf.</param>
		public VaultSpeckle( Locator storehouseKey, string sheafTypeName )
			: base( storehouseKey, sheafTypeName )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="storehouseKey">The storehouse key of the referred sheaf. This must be unique in the storehouse.
		/// </param>
		/// <param name="sheafTypeName">The type name of the stored sheaf.</param>
		/// <param name="loadedSpeckleFilters">The speckle filters of the speckle, loaded from the storehouse. This may
		/// be null or empty.</param>
		public VaultSpeckle( Locator storehouseKey, string sheafTypeName, SpeckleFilters loadedSpeckleFilters )
			: base( storehouseKey, sheafTypeName, loadedSpeckleFilters )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="sheaf">The sheaf to refer.</param>
		/// <remarks>
		/// <para>All the properties declared in this class are automatically set in here.</para>
		/// </remarks>
		public VaultSpeckle( ISheaf sheaf )
			: base( sheaf )
		{
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The entity name. READ-ONLY.
		/// </summary>
		public string EntityName
		{
			get { return GetLoadedSpeckleFilter<string>( Vault.EntityNameFilterIdentifier ); }
		}

		/// <summary>
		/// The sort key. READ-ONLY.
		/// </summary>
		public Tuple SortKey
		{
			get { return new Tuple( EntityName, CreationTime, StorehouseKey ); }
		}

		#endregion Public non-serializable properties
	}
}
