////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.ApplicationDocuments
{
	/// <summary>
	/// List of speckles for vaults (<see cref="VaultSpeckle"/>).
	/// </summary>
	public class VaultSpeckles : KernelSortedList<Tuple, VaultSpeckle>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public VaultSpeckles()
			: base( TupleComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The <see cref="VaultSpeckle.SortKey"/> property is used as key.</para>
		/// </remarks>
		public override Tuple GetKey( VaultSpeckle item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.SortKey;
		}

		/// <summary>
		/// Finds the speckle with the specified storehouse key.
		/// </summary>
		/// <param name="storehouseKey">Storehouse key to find.</param>
		/// <returns>Returns the found speckle, or null if none is found.</returns>
		/// <remarks>
		/// <para>The storehouse key is not the item key.</para>
		/// </remarks>
		public VaultSpeckle FindByStorehouseKey( Locator storehouseKey )
		{
			ValidationUtils.ObjectHasContent( storehouseKey, "storehouseKey" );

			foreach( VaultSpeckle speckle in this )
			{
				if( speckle.StorehouseKey.Equals( storehouseKey ) ) return speckle;
			}

			return null;
		}

		#endregion Public methods
	}
}
