////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.BinarySerialization
{
	/// <summary>
	/// List of binary serialization nodes (<see cref="BinarySerializationNode"/>).
	/// </summary>
	public class BinarySerializationNodes : KernelSortedList<string, BinarySerializationNode>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public BinarySerializationNodes()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified node.
		/// </summary>
		/// <param name="node">Node to get the key from.</param>
		/// <returns>Returns the key from the specified node.</returns>
		/// <remarks>
		/// <para><see cref="BinarySerializationNode.SerializationName"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( BinarySerializationNode node )
		{
			ValidationUtils.ObjectHasContent( node, "node" );

			return node.SerializationName;
		}

		#endregion Public methods
	}
}
