////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.IO;
using System.IO.Compression;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// GZIP compression algorithm.
	/// </summary>
	public class Gzip : CompressionAlg
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Gzip()
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Compresses the specified data.
		/// </summary>
		/// <param name="buffer">Buffer to compress.</param>
		/// <returns>Returns the compressed data.</returns>
		public override byte[] Compress( byte[] buffer )
		{
			ValidationUtils.ArrayHasContent( buffer, "buffer" );

			using( MemoryStream destStream = new MemoryStream() )
			{
				using( GZipStream zs = new GZipStream( destStream, CompressionMode.Compress ) )
				{
					zs.Write( buffer, 0, buffer.Length );
				}

				return destStream.ToArray();
			}
		}

		/// <summary>
		/// Decompresses the specified data.
		/// </summary>
		/// <param name="buffer">Buffer to decompress.</param>
		/// <returns>Returns the decompressed data.</returns>
		public override byte[] Decompress( byte[] buffer )
		{
			ValidationUtils.ArrayHasContent( buffer, "buffer" );

			using( MemoryStream sourceStream = new MemoryStream( buffer ) )
			using( MemoryStream destStream = new MemoryStream() )
			{
				using( GZipStream zs = new GZipStream( sourceStream, CompressionMode.Decompress ) )
				{
					zs.CopyTo( destStream );
				}

				return destStream.ToArray();
			}
		}

		#endregion Public methods
	}
}
