////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Constants used for core documents.
	/// </summary>
	public static class CoreDocumentsConsts
	{
		#region Public constants

		/// <summary>
		/// The maximum number of speckle filters (this includes the speckle filters from the inherited classes).
		/// </summary>
		public const int SpeckleFilterSizeMax = 16;

		/// <summary>
		/// The maximum size (in bytes) of the value of a speckle filter.
		/// </summary>
		public const int SpeckleFilterValueSizeMax = 1024;

		/// <summary>
		/// The default value for <see cref="SteganographicAlg.DisalignmentSizeZenith"/>
		/// </summary>
		public const int DisalignmentSizeZenith = 1024;

		/// <summary>
		/// The minimum size (in bytes) of a symmetric encryption key.
		/// </summary>
		public const int SymmEncryptionKeySizeMin = 16;

		/// <summary>
		/// The maximum size (in bytes) of a symmetric encryption key.
		/// </summary>
		public const int SymmEncryptionKeySizeMax = 128;

		/// <summary>
		/// The default size (in bytes) of a symmetric encryption key.
		/// </summary>
		public const int SymmEncryptionKeySizeDef = 32;

		/// <summary>
		/// The maximum size (in characters) of a UPN classifier. This has to be maximum 148, the maximum supported by PNRP.
		/// </summary>
		/// <remarks>
		/// <para>So long as all the UPN classifiers have this size and the same structure, and so long as a fixed number of
		/// classifiers is registered on the network, an attacker can't know how many vaults a peer has. However, if the peer
		/// creates a new vault, the attacker might see a change in the registered classifiers.</para>
		/// </remarks>
		public const int UpnClassifierSizeMax = 128;

		#endregion Public constants
	}
}
