////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Exception which indicates an error with the alignment size limit of encrypted documents
	/// (<see cref="EncryptedEnvelope.AlignToBlockSize"/>).
	/// </summary>
	public class AlignedToBlockSizeException : BaseException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected AlignedToBlockSizeException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public AlignedToBlockSizeException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception thrown when a stamp is invalid.
	/// </summary>
	public abstract class InvalidStampException : FatalCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected InvalidStampException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public InvalidStampException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception thrown when the cost of a stamp is not fulfilled.
	/// </summary>
	public class UnfulfilledStampCostException : InvalidStampException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected UnfulfilledStampCostException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public UnfulfilledStampCostException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception thrown when a storehouse can't be opened.
	/// </summary>
	public class FailedOpenStorehouseException : BaseException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected FailedOpenStorehouseException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public FailedOpenStorehouseException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception thrown when a storehouse is closed.
	/// </summary>
	public class ClosedStorehouseException : BaseException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ClosedStorehouseException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		public ClosedStorehouseException( string message, Exception exception = null )
			: base( message, exception )
		{
		}

		#endregion Constructors
	}
}
