////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Sorted list of session keys for the recipients of an encrypted document. An <see cref="EncryptedEnvelope"/> object may
	/// be encrypted to an entire group of recipients.
	/// </summary>
	public class AsymmRecipientSessionKeys : KernelSortedList<Locator, AsymmRecipientSessionKey>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public AsymmRecipientSessionKeys()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The UPN fingerprint of the <see cref="AsymmRecipientSessionKey.SolitarySessionKey"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( AsymmRecipientSessionKey item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.SolitarySessionKey.UpnFingerprint;
		}

		#endregion Public methods
	}
}
