////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// List of session keys used to store the session keys of the extra recipients (for when some recipients may miss from the
	/// decryption of the document).
	/// </summary>
	public class AsymmSessionKeys : KernelSortedList<Locator, AsymmSessionKey>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public AsymmSessionKeys()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="AsymmSessionKey.UpnFingerprint"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( AsymmSessionKey item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.UpnFingerprint;
		}

		#endregion Public methods
	}
}
