////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto.Mac;
using Vela.Crypto.Symmetric;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Encrypted archive which is used to transport documents.
	/// </summary>
	public class EncryptedArchive : SymmEncryptedEnvelope
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected EncryptedArchive()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="macAlg">MAC algorithm.</param>
		/// <param name="compressionAlg">Compression algorithm. This may be null.</param>
		/// <param name="symmAlg">Symmetric cryptography algorithm.</param>
		/// <param name="passwordBlenderAlg">Password blender algorithm to use to generate the blended password. This may
		/// be null if the password is not textual.</param>
		public EncryptedArchive( Locator instanceLocator, MacAlg macAlg, SymmAlg symmAlg, CompressionAlg compressionAlg
				, PasswordBlenderAlg passwordBlenderAlg )
			: base( instanceLocator, macAlg, compressionAlg, symmAlg, passwordBlenderAlg )
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private Locatables _Documents;
		/// <summary>
		/// Documents. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public Locatables Documents
		{
			get { return _Documents; }
			set { _Documents = value; }
		}

		#endregion Public serializable properties
	}
}
