////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Contract for an object which contains an entity name which is set only by the local peer (never by the remote peer).
	/// </summary>
	/// <remarks>
	/// <para>This exists because the name of a <see cref="INamedEntity"/> may be updated by the remote peer which owns it (after
	/// the account referring to it was created), which means that the remote peer could maliciously change its name to match the
	/// name of another remote peer, and if this name were used to identify a signing identity, it would be a security breach.
	/// </para>
	/// </remarks>
	public interface ILocallyNamedIdentity : INamedEntity
	{
	}
}
