////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// List of signatures (<see cref="Signature"/>). A <see cref="SignedDocument"/> object may be signed with multiple
	/// signatures. The signatures themselves are not signed together with the document they authenticate.
	/// </summary>
	public class Signatures : KernelSortedList<Locator, Signature>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Signatures()
			: base( LocatorComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="signatures">Signatures to add to the list.</param>
		public Signatures( params Signature[] signatures )
			: base( LocatorComparer.Instance )
		{
			ValidationUtils.ArrayHasContent( signatures, "signatures" );

			foreach( Signature signature in signatures )
				Add( signature );
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="Signature.UpnFingerprint"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( Signature item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.UpnFingerprint;
		}

		#endregion Public methods
	}
}
