////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// List of stamps (<see cref="Stamp"/>).
	/// </summary>
	public class Stamps : KernelSortedList<Locator, Stamp>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Stamps()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The instance locator is used as key.</para>
		/// </remarks>
		public override Locator GetKey( Stamp item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.InstanceLocator;
		}

		#endregion Public methods
	}
}
