////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Contract for a sheaf which contains at least 1 private processing identity which contains an entity name which is set
	/// only by the local peer (never by the remote peer).
	/// </summary>
	public interface ILocallyNamedPrivateProcessingIdentitySheaf : ILocallyNamedPublicProcessingIdentitySheaf
	{
		#region Public non-serializable properties

		/// <summary>
		/// Collects the private identities from the current sheaf.
		/// </summary>
		/// <param name="identities">List where to collect the identities. The dictionary key is the instance locator of the
		/// current sheaf. This may be empty, but not null.</param>
		void CollectPrivateIdentities( Dictionary<Locator, PrivateIdentity> identities );

		#endregion Public non-serializable properties
	}
}
