////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Contract for a sheaf which contains at least 1 public processing identity.
	/// </summary>
	public interface IPublicProcessingIdentitySheaf : ISheaf
	{
		#region Public non-serializable properties

		/// <summary>
		/// Collects the identities from the current sheaf.
		/// </summary>
		/// <param name="identityPublishers">List where to collect the identity publishers. The dictionary key is the instance
		/// locator of the current sheaf. This may be empty, but not null.</param>
		/// <param name="identities">List where to collect the identities. The dictionary key is the instance locator of the
		/// current sheaf. This may be empty, but not null.</param>
		void CollectIdentities( Dictionary<Locator, IIdentityPublisher> identityPublishers
			, Dictionary<Locator, PublicIdentity> identities );

		#endregion Public non-serializable properties
	}
}
