////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// List of speckle filter identifiers (<see cref="SpeckleFilterIdentifier"/>).
	/// </summary>
	public class SpeckleFilterIdentifiers : KernelSortedList<int, SpeckleFilterIdentifier>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public SpeckleFilterIdentifiers()
			: base( IntComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="identifiers">The identifiers to add to the list.</param>
		public SpeckleFilterIdentifiers( params SpeckleFilterIdentifier[] identifiers )
			: base( IntComparer.Instance )
		{
			ValidationUtils.ArrayHasContent( identifiers, "identifiers" );

			foreach( SpeckleFilterIdentifier identifier in identifiers )
				Add( identifier );
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="compositeIdentifiers">The composite identifiers to add to the list.</param>
		public SpeckleFilterIdentifiers( params string[] compositeIdentifiers )
			: base( IntComparer.Instance )
		{
			ValidationUtils.ArrayHasContent( compositeIdentifiers, "compositeIdentifiers" );

			foreach( string compositeIdentifier in compositeIdentifiers )
				Add( new SpeckleFilterIdentifier( compositeIdentifier ) );
		}

		#endregion Constructors

		#region Public static methods

		/// <summary>
		/// Packs the specified items into a list.
		/// </summary>
		/// <param name="items">Items to pack into a list. This may be null or empty.</param>
		/// <returns>Returns the created list. This is null if "items" is null.</returns>
		public static SpeckleFilterIdentifiers ToList( params SpeckleFilterIdentifier[] items )
		{
			if( items == null )
				return null;

			SpeckleFilterIdentifiers itemList = new SpeckleFilterIdentifiers();
			foreach( SpeckleFilterIdentifier item in items )
				itemList.Add( item );

			return itemList;
		}

		#endregion Public static methods

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The index of the identifier of the item is used as key.</para>
		/// </remarks>
		public override int GetKey( SpeckleFilterIdentifier item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.Index;
		}

		#endregion Public methods
	}
}
