////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto;
using Vela.Crypto.Hash;
using Vela.Crypto.Mac;
using Vela.Crypto.Symmetric;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Contract for a "Peer name Resolution, Encryption and Authentication with MIST" UPN algorithm.
	/// </summary>
	public abstract class Pream : Prea
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="outputBodySize">The size (in bytes) that the generated body must have. If this is smaller than
		/// <see cref="Prea.OutputBodySizeMin"/>, all the available bytes are used.</param>
		/// <remarks>
		/// <para>The used algorithms are hard-coded because a UPN doesn't have enough space to contain all their names (which
		/// would be required during UPN deserialization, if they were not hard-coded).</para>
		/// </remarks>
		protected Pream( int outputBodySize )
			: base( new Utf8(), new Sha512()
				, new Mist( new Bck( new Sha512() ), new Rijndael256( SymmPaddings.Iso10126, SymmChainings.Cbc )
					, CoreDocumentsConsts.DisalignmentSizeZenith )
				, new Cofa(), outputBodySize, FingerprintSeedDef, HostLabelSeedDef, ClassifierSeedDef, SymmEncryptionKeySeedDef )
		{
		}

		#endregion Constructors
	}
}
