////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.CoreDocuments
{
	/// <summary>
	/// PREAM algorithm with a size 32.
	/// </summary>
	public class Pream32 : Pream
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Pream32()
			: base( 32 )
		{
		}

		#endregion Constructors

		#region Public static methods

		/// <summary>
		/// Checks if the current algorithm may be used to parse the specified data into a UPN.
		/// </summary>
		/// <param name="buffer">Buffer to parse.</param>
		/// <returns>Returns an instance of itself if it may parse the specified data, or null if it may not parse it.</returns>
		public static UpnAlg GetParsingAlgorithm( byte[] buffer )
		{
			return Prea.GetParsingAlgorithm( buffer, typeof( Pream32 ) );
		}

		/// <summary>
		/// Checks if the current algorithm may be used to parse the specified data into a UPN.
		/// </summary>
		/// <param name="data">Data to parse.</param>
		/// <returns>Returns an instance of itself if it may parse the specified data, or null if it may not parse it.</returns>
		public static UpnAlg GetParsingAlgorithm( string data )
		{
			return Prea.GetParsingAlgorithm( data, typeof( Pream32 ) );
		}

		#endregion Public static methods
	}
}
