////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Serialization;
using Vela.Crypto.Asymmetric.Math;

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// Contract for blinding configuration.
	/// </summary>
	public abstract class BlindingConfiguration : IDocument
	{
		#region Public methods

		/// <summary>
		/// Verifies if the current key has the same content as the specified key.
		/// </summary>
		/// <param name="blindingConfiguration">Object to verify against the current object.</param>
		/// <returns>Returns true if the objects have the same content.</returns>
		public abstract bool Equals( BlindingConfiguration blindingConfiguration );

		/// <summary>
		/// Verifies if the specified data may be blinded.
		/// </summary>
		/// <param name="bi">Big integer to check if it may be blinded.</param>
		/// <param name="asymmAlg">The asymmetric algorithm which the blinding will be done.</param>
		/// <returns>Returns true if the specified data may be blinded.</returns>
		public abstract bool IsAllowed( BigInteger bi, AsymmAlg asymmAlg );

		#endregion Public methods
	}
}
