////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// Contract for an asymmetric cryptography encryption padding.
	/// </summary>
	public interface IAsymmEncryptionPaddingAlg : IAsymmPaddingAlg
	{
		#region Public methods

		/// <summary>
		/// Decrypts the specified data using the current encryption padding and the private key of the specified asymmetric
		/// algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to decrypt.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the decrypted data.</returns>
		byte[] DecryptData( byte[] buffer, AsymmAlg asymmAlg );

		/// <summary>
		/// Encrypts the specified data using the current encryption padding and the public key of the specified asymmetric
		/// algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to encrypt. This should be something small, like a hash.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the encrypted data.</returns>
		byte[] EncryptData( byte[] buffer, AsymmAlg asymmAlg );

		#endregion Public methods
	}
}
