////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// Contract for an asymmetric cryptography padding.
	/// </summary>
	public interface IAsymmSigningPaddingAlg : IAsymmPaddingAlg
	{
		#region Public methods

		/// <summary>
		/// Signs the specified data using the private key of the specified asymmetric algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to sign. This should be something small, like a hash.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the signed data.</returns>
		byte[] SignData( byte[] buffer, AsymmAlg asymmAlg );

		/// <summary>
		/// Verifies if the specified signature is valid, using the public key of the specified asymmetric algorithm. An
		/// <see cref="InvalidSignatureException"/> (among others) is thrown if the signature is invalid.
		/// </summary>
		/// <param name="buffer">Buffer whose signature has to be verified.</param>
		/// <param name="signature">The signature against which the data's signature is verified.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		void VerifyDataSignature( byte[] buffer, byte[] signature, AsymmAlg asymmAlg );

		#endregion Public methods
	}
}
