////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto.Hash;
using Vela.Kernel;

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// "VSH" asymmetric cryptography encryption padding.
	/// </summary>
	public class Vshe : Vsh, IAsymmEncryptionPaddingAlg
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected Vshe()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="textEncoding">Text encoding.</param>
		/// <param name="hashAlg">Hash algorithm.</param>
		public Vshe( TextEncoding textEncoding, HashAlg hashAlg )
			: base( textEncoding, hashAlg )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Decrypts the specified data using the current encryption padding and the private key of the specified asymmetric
		/// algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to decrypt.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the decrypted data.</returns>
		public byte[] DecryptData( byte[] buffer, AsymmAlg asymmAlg )
		{
			return InternalDecryptData( buffer, asymmAlg );
		}

		/// <summary>
		/// Encrypts the specified data using the current encryption padding and the public key of the specified asymmetric
		/// algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to encrypt. This should be something small, like a hash.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the encrypted data.</returns>
		public byte[] EncryptData( byte[] buffer, AsymmAlg asymmAlg )
		{
			return InternalEncryptData( buffer, asymmAlg );
		}

		#endregion Public methods
	}
}
