////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto.Hash;
using Vela.Kernel;

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// "VSH" asymmetric cryptography signing padding.
	/// </summary>
	public class Vshs : Vsh, IAsymmSigningPaddingAlg
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected Vshs()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="textEncoding">Text encoding.</param>
		/// <param name="hashAlg">Hash algorithm.</param>
		public Vshs( TextEncoding textEncoding, HashAlg hashAlg )
			: base( textEncoding, hashAlg )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Signs the specified data using the private key of the specified asymmetric algorithm.
		/// </summary>
		/// <param name="buffer">Buffer to sign. This should be something small, like a hash.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		/// <returns>Returns the signed data.</returns>
		public byte[] SignData( byte[] buffer, AsymmAlg asymmAlg )
		{
			return InternalSignData( buffer, asymmAlg );
		}

		/// <summary>
		/// Verifies if the specified signature is valid, using the public key of the specified asymmetric algorithm. An
		/// <see cref="InvalidSignatureException"/> (among others) is thrown if the signature is invalid.
		/// </summary>
		/// <param name="buffer">Buffer whose signature has to be verified.</param>
		/// <param name="signature">The signature against which the data's signature is verified.</param>
		/// <param name="asymmAlg">Asymmetric algorithm.</param>
		public void VerifyDataSignature( byte[] buffer, byte[] signature, AsymmAlg asymmAlg )
		{
			InternalVerifyDataSignature( buffer, signature, asymmAlg );
		}

		#endregion Public methods
	}
}
