////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Crypto.Asymmetric
{
	/// <summary>
	/// An asymmetric cryptographic RSA algorithm with a 6144 bits size.
	/// </summary>
	public class Rsa6144 : RsaAlg
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Rsa6144()
		{
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The size (in bits) of the cryptographic algorithm. This is multiple of 16 so that it can be an even number of bytes;
		/// this is not a technical requirement, but a practical one. READ-ONLY.
		/// </summary>
		public override int AlgSizeBits
		{
			get { return 6144; }
		}

		/// <summary>
		/// The time (in UTC format) from which the current object expires and should no longer be used in processing.
		/// READ-ONLY.
		/// </summary>
		public override DateTime ExpirationTime
		{
			get { return new DateTime( 2045, 1, 1 ); }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Gets the public part of the current algorithm (the properties are deeply cloned).
		/// </summary>
		/// <returns>Returns the public part of the current algorithm.</returns>
		public override AsymmAlg GetPublicAlg()
		{
			// Create a new algorithm.
			RsaAlg asymmAlg = new Rsa6144();

			CopyPublicKeyTo( asymmAlg );

			return asymmAlg;
		}

		#endregion Public methods
	}
}
