////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.Crypto.Hash
{
	/// <summary>
	/// Contract for the stream worker of a hash algorithm.
	/// </summary>
	public abstract class HashAlgStreamWorker
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="hashAlg">Parent hash algorithm.</param>
		protected HashAlgStreamWorker( HashAlg hashAlg )
		{
			ValidationUtils.ObjectHasContent( hashAlg, "hashAlg" );

			HashAlg = hashAlg;
		}

		#endregion Constructors

		#region Private fields

		/// <summary>
		/// Hash algorithm.
		/// </summary>
		protected HashAlg HashAlg;

		#endregion Private fields

		#region Public methods

		/// <summary>
		/// Processes the specified data. The <see cref="ProcessFinal"/> method must be called to finish processing the data.
		/// </summary>
		/// <param name="buffer">Buffer to process. This may be empty, but not null.</param>
		/// <param name="offset">Offset in the input data, from where to start processing. This must be at least 0.</param>
		/// <param name="size">The number of bytes to process. This must be at least 0.</param>
		public abstract void Process( byte[] buffer, int offset, int size );

		/// <summary>
		/// Processes the specified data. The <see cref="ProcessFinal"/> method must be called to finish processing the data.
		/// </summary>
		/// <param name="buffer">Buffer to process. This may be empty, but not null.</param>
		public void Process( byte[] buffer )
		{
			Process( buffer, 0, buffer.Length );
		}

		/// <summary>
		/// Finishes processing the data.
		/// </summary>
		/// <returns>Returns the result of the processing.</returns>
		public abstract byte[] ProcessFinal();

		#endregion Public methods
	}
}
