////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Crypto.Hash
{
	/// <summary>
	/// A Sha512 hash algorithm.
	/// </summary>
	public class Sha512 : HashAlg
	{
		#region Constructor

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Sha512()
		{
		}

		#endregion Constructor

		#region Public non-serializable properties

		/// <summary>
		/// The size (in bits) of the hash algorithm. The resulted hash has to have this size. READ-ONLY.
		/// </summary>
		public override int AlgSizeBits
		{
			get { return 512; }
		}

		/// <summary>
		/// The size (in bytes) of a super-block. READ-ONLY.
		/// </summary>
		public override int SuperBlockSizeBytes
		{
			get { return 128; }
		}

		/// <summary>
		/// The time (in UTC format) from which the current object expires and should no longer be used in processing.
		/// READ-ONLY.
		/// </summary>
		public override DateTime ExpirationTime
		{
			get { return new DateTime( 2040, 1, 1 ); }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Creates a stream worker for the current algorithm.
		/// </summary>
		public override HashAlgStreamWorker CreateStreamWorker()
		{
			return new Sha512StreamWorker( this );
		}

		#endregion Public methods
	}
}
