////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Crypto.Hash;

namespace Vela.Crypto.Mac
{
	/// <summary>
	/// BCK (= Bellare, Canetti, Krawczyk) MAC algorithm.
	/// </summary>
	/// <remarks>
	/// <para>This algorithm is known as HMAC.</para>
	/// </remarks>
	public class Bck : MacAlg
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected Bck()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="hashAlg">Hash algorithm.</param>
		public Bck( HashAlg hashAlg )
			: base( hashAlg )
		{
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The time (in UTC format) from which the current object expires and should no longer be used in processing.
		/// READ-ONLY.
		/// </summary>
		public override DateTime ExpirationTime
		{
			get { return HashAlg.ExpirationTime; }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Creates a stream worker for the current algorithm.
		/// </summary>
		/// <param name="key">The key of the MAC.</param>
		public override MacAlgStreamWorker CreateStreamWorker( byte[] key )
		{
			return new BckAlgStreamWorker( this, key );
		}

		#endregion Public methods
	}
}
