////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.Storehouse;

namespace Vela.DatabaseStorehouse
{
	/// <summary>
	/// Placeholders used in storehouse scripts.
	/// </summary>
	public abstract class DatabaseScriptPlaceholders : IStorehouseScriptPlaceholders
	{
		#region Public constants

		/// <summary>
		/// The "StorehouseRealm" placeholder.
		/// </summary>
		public const string StorehouseRealm = "{StorehouseRealm}";

		/// <summary>
		/// The "SheafTypeNameChecksumSeekList" placeholder.
		/// </summary>
		public const string SheafTypeNameChecksumSeekList = "{SheafTypeNameChecksumSeekList}";

		/// <summary>
		/// The "SheafTypeNameSeekList" placeholder.
		/// </summary>
		public const string SheafTypeNameSeekList = "{SheafTypeNameSeekList}";

		/// <summary>
		/// The "SpeckleFilterChecksumColumnList" placeholder.
		/// </summary>
		public const string SpeckleFilterChecksumColumnList = "{SpeckleFilterChecksumColumnList}";

		/// <summary>
		/// The "SpeckleFilterTypeNameColumnList" placeholder.
		/// </summary>
		public const string SpeckleFilterTypeNameColumnList = "{SpeckleFilterTypeNameColumnList}";

		/// <summary>
		/// The "SpeckleFilterNameColumnList" placeholder.
		/// </summary>
		public const string SpeckleFilterNameColumnList = "{SpeckleFilterNameColumnList}";

		/// <summary>
		/// The "SpeckleFilterValueColumnList" placeholder.
		/// </summary>
		public const string SpeckleFilterValueColumnList = "{SpeckleFilterValueColumnList}";

		/// <summary>
		/// The "SpeckleFilterChecksumParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterChecksumParameterList = "{SpeckleFilterChecksumParameterList}";

		/// <summary>
		/// The "SpeckleFilterTypeNameParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterTypeNameParameterList = "{SpeckleFilterTypeNameParameterList}";

		/// <summary>
		/// The "SpeckleFilterNameParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterNameParameterList = "{SpeckleFilterNameParameterList}";

		/// <summary>
		/// The "SpeckleFilterValueParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterValueParameterList = "{SpeckleFilterValueParameterList}";

		/// <summary>
		/// The "SpeckleFilterChecksumColumnParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterChecksumColumnParameterList = "{SpeckleFilterChecksumColumnParameterList}";

		/// <summary>
		/// The "SpeckleFilterTypeNameColumnParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterTypeNameColumnParameterList = "{SpeckleFilterTypeNameColumnParameterList}";

		/// <summary>
		/// The "SpeckleFilterNameColumnParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterNameColumnParameterList = "{SpeckleFilterNameColumnParameterList}";

		/// <summary>
		/// The "SpeckleFilterValueColumnParameterList" placeholder.
		/// </summary>
		public const string SpeckleFilterValueColumnParameterList = "{SpeckleFilterValueColumnParameterList}";

		/// <summary>
		/// The "SpeckleFilterChecksumSeekList" placeholder.
		/// </summary>
		public const string SpeckleFilterChecksumSeekList = "{SpeckleFilterChecksumSeekList}";

		/// <summary>
		/// The "SpeckleFilterValueSeekList" placeholder.
		/// </summary>
		public const string SpeckleFilterValueSeekList = "{SpeckleFilterValueSeekList}";

		/// <summary>
		/// The "SpeckleFilterTypeNameLoadList" placeholder.
		/// </summary>
		public const string SpeckleFilterTypeNameLoadList = "{SpeckleFilterTypeNameLoadList}";

		/// <summary>
		/// The "SpeckleFilterNameLoadList" placeholder.
		/// </summary>
		public const string SpeckleFilterNameLoadList = "{SpeckleFilterNameLoadList}";

		/// <summary>
		/// The "SpeckleFilterValueLoadList" placeholder.
		/// </summary>
		public const string SpeckleFilterValueLoadList = "{SpeckleFilterValueLoadList}";

		#endregion Public constants

		#region Public methods

		/// <summary>
		/// Gets the script fragment which contains the condition to load information from a database, according to the
		/// specified seek sheaf type name checksums.
		/// </summary>
		/// <param name="sheafTypes">Sheaf types whose names to include in the script.</param>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSheafTypeNameChecksumSeek( PortableTypes sheafTypes );

		/// <summary>
		/// Gets the script fragment which contains the condition to load information from a database, according to the
		/// specified seek sheaf type names.
		/// </summary>
		/// <param name="sheafTypes">Sheaf types whose names to include in the script.</param>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSheafTypeNameSeek( PortableTypes sheafTypes );

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter checksum columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterChecksumColumnList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter type name columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterTypeNameColumnList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter name columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterNameColumnList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter value columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterValueColumnList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter checksum parameters.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterChecksumParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter type name parameters.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterTypeNameParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter name parameters.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterNameParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter value parameters.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterValueParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter checksum assignments of parameters to columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterChecksumColumnParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter type name assignments of parameters to columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterTypeNameColumnParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter name assignments of parameters to columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterNameColumnParameterList();

		/// <summary>
		/// Gets the script fragment which contains the all the speckle filter value assignments of parameters to columns.
		/// </summary>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterValueColumnParameterList();

		/// <summary>
		/// Gets the script fragment which contains the condition to load information from a database, according to the
		/// specified speckle filter checksums.
		/// </summary>
		/// <param name="filters">The speckle filters to include in the script fragment. This may be null or empty.</param>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterChecksumSeek( SpeckleFilters filters );

		/// <summary>
		/// Gets the script fragment which contains the condition to load information from a database, about the speckle filter
		/// values, according to the specified speckle filters.
		/// </summary>
		/// <param name="filters">The speckle filters to include in the script fragment. This may be null or empty.</param>
		/// <returns>Returns the created script fragment.</returns>
		public abstract string GetSpeckleFilterValueSeek( SpeckleFilters filters );

		/// <summary>
		/// Gets the script fragment which contains the speckle filter type names to load from a database, according to the
		/// specified speckle filter identifiers.
		/// </summary>
		/// <param name="filterIdentifiers">The speckle filters to include in the script fragment. This may be null or empty.
		/// </param>
		/// <returns>Returns the created script fragment. This may be empty, but not null.</returns>
		public abstract string GetSpeckleFilterTypeNameLoad( SpeckleFilterIdentifiers filterIdentifiers );

		/// <summary>
		/// Gets the script fragment which contains the speckle filters to load from a database, about the speckle filter
		/// names, according to the specified speckle filter identifiers.
		/// </summary>
		/// <param name="filterIdentifiers">The speckle filter identifiers to include in the script fragment. This may be null or
		/// empty.</param>
		/// <returns>Returns the created script fragment. This may be empty, but not null.</returns>
		public abstract string GetSpeckleFilterNameLoad( SpeckleFilterIdentifiers filterIdentifiers );

		/// <summary>
		/// Gets the script fragment which contains the speckle filters to load from a database, about the speckle filter
		/// values, according to the specified speckle filter identifiers.
		/// </summary>
		/// <param name="filterIdentifiers">The speckle filter identifiers to include in the script fragment. This may be null or
		/// empty.</param>
		/// <returns>Returns the created script fragment. This may be empty, but not null.</returns>
		public abstract string GetSpeckleFilterValueLoad( SpeckleFilterIdentifiers filterIdentifiers );

		#endregion Public methods
	}
}
