////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// An exception detail.
	/// </summary>
	public class ExceptionDetail
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ExceptionDetail()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="name">Detail name. This may be null or empty.</param>
		/// <param name="value">Detail value. This may be null or empty.</param>
		public ExceptionDetail( string name, string value )
		{
			Name = name;
			Value = value;
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="name">Detail name. This may be null or empty.</param>
		/// <param name="locator">Detail value. This may be null.</param>
		public ExceptionDetail( string name, Locator locator )
		{
			Name = name;
			Value = (locator != null) ? locator.ToString() : null;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private string _Name;
		/// <summary>
		/// Detail name. This may be null or empty. READ-ONLY.
		/// </summary>
		public string Name
		{
			get { return _Name; }
			protected set { _Name = value; }
		}

		private string _Value;
		/// <summary>
		/// Detail value. This may be null or empty. READ-ONLY.
		/// </summary>
		public string Value
		{
			get { return _Value; }
			protected set { _Value = value; }
		}

		#endregion Public non-serializable properties
	}
}
