////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Serialization;

namespace Vela.Kernel.Cloning
{
	/// <summary>
	/// Contract from which all the classes whose content may NOT be (deep) cloned must derive.
	/// </summary>
	/// <remarks>
	/// <para>This interface indicates that the implementing class could not be used in a multithreaded context even if it were
	/// (deep) cloned, and as such there is no point in cloning it (either in a shallow or deep manner). An example is a class
	/// which contains some handles to (unclonable) system resources.</para>
	/// </remarks>
	public interface IUnclonable : IUnserializable
	{
	}
}
