////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for buffers.
	/// </summary>
	public class BufferComparer : IItemEqualityComparer<byte[]>
	{
		#region Public static properties

		private static readonly BufferComparer _Instance = new BufferComparer();
		/// <summary>
		/// Global comparer for buffers. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static BufferComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified buffer.
		/// </summary>
		/// <param name="buffer">Buffer whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified buffer.</returns>
		public int GetHashCode( byte[] buffer )
		{
			return BufferUtils.ComputeChecksum32( buffer );
		}

		/// <summary>
		/// Verifies if the specified buffers have the same value.
		/// </summary>
		/// <param name="buffer1">Buffer to verify.</param>
		/// <param name="buffer2">Buffer to verify.</param>
		/// <returns>Returns true if the buffers have the same value.</returns>
		public bool Equals( byte[] buffer1, byte[] buffer2 )
		{
			return BufferUtils.Equals( buffer1, buffer2 );
		}

		/// <summary>
		/// Compares the specified buffers.
		/// </summary>
		/// <param name="buffer1">Buffer to compare.</param>
		/// <param name="buffer2">Buffer to compare.</param>
		/// <returns>Returns 0 if the buffers have the same value, -1 if "buffer1" is smaller than "buffer2", and 1 if
		/// "buffer1" is greater than "buffer2".</returns>
		public int Compare( byte[] buffer1, byte[] buffer2 )
		{
			return BufferUtils.Compare( buffer1, buffer2 );
		}

		#endregion Public methods
	}
}
