////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for integers.
	/// </summary>
	public class IntComparer : IItemEqualityComparer<int>
	{
		#region Public static properties

		private static readonly IntComparer _Instance = new IntComparer();
		/// <summary>
		/// Global comparer for integers. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static IntComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified integer.
		/// </summary>
		/// <param name="integer">Integer whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified integer.</returns>
		public int GetHashCode( int integer )
		{
			return integer.GetHashCode();
		}

		/// <summary>
		/// Verifies if the specified integers have the same value.
		/// </summary>
		/// <param name="integer1">Integer to verify.</param>
		/// <param name="integer2">Integer to verify.</param>
		/// <returns>Returns true if the integers have the same value.</returns>
		public bool Equals( int integer1, int integer2 )
		{
			return integer1 == integer2;
		}

		/// <summary>
		/// Compares the specified integers.
		/// </summary>
		/// <param name="integer1">Integer to compare.</param>
		/// <param name="integer2">Integer to compare.</param>
		/// <returns>Returns 0 if the integers have the same value, -1 if "integer1" is smaller than "integer2", and 1 if
		/// "integer1" is greater than "integer2".</returns>
		public int Compare( int integer1, int integer2 )
		{
			return integer1.CompareTo( integer2 );
		}

		#endregion Public methods
	}
}
