////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for object references (/ pointers).
	/// </summary>
	public class ReferenceComparer : EqualityComparer<object>
	{
		#region Public static properties

		private static readonly ReferenceComparer _Instance = new ReferenceComparer();
		/// <summary>
		/// Global comparer for references. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static ReferenceComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified object.
		/// </summary>
		/// <param name="data">Object whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified object.</returns>
		public override int GetHashCode( object data )
		{
			return data.GetHashCode();
		}

		/// <summary>
		/// Verifies if the specified objects have the same value.
		/// </summary>
		/// <param name="object1">Object to verify. This may be null.</param>
		/// <param name="object2">Object to verify. This may be null.</param>
		/// <returns>Returns true if the objects have the same value.</returns>
		public override bool Equals( object object1, object object2 )
		{
			return object.ReferenceEquals( object1, object2 );
		}

		#endregion Public methods
	}
}
