////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for strings.
	/// </summary>
	public class StringInsensitiveComparer : IItemEqualityComparer<string>
	{
		#region Public static properties

		private static readonly StringInsensitiveComparer _Instance = new StringInsensitiveComparer();
		/// <summary>
		/// Global comparer for strings. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static StringInsensitiveComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified text.
		/// </summary>
		/// <param name="text">Text whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified text.</returns>
		public int GetHashCode( string text )
		{
			return StringComparer.OrdinalIgnoreCase.GetHashCode( text );
		}

		/// <summary>
		/// Verifies if the specified texts have the same value.
		/// </summary>
		/// <param name="text1">Text to verify.</param>
		/// <param name="text2">Text to verify.</param>
		/// <returns>Returns true if the texts have the same value.</returns>
		public bool Equals( string text1, string text2 )
		{
			return StringComparer.OrdinalIgnoreCase.Equals( text1, text2 );
		}

		/// <summary>
		/// Compares the specified texts.
		/// </summary>
		/// <param name="text1">Text to compare.</param>
		/// <param name="text2">Text to compare.</param>
		/// <returns>Returns 0 if the texts have the same value, -1 if "text1" is smaller than "text2", and 1 if "text1" is
		/// greater than "text2".</returns>
		public int Compare( string text1, string text2 )
		{
			return StringComparer.OrdinalIgnoreCase.Compare( text1, text2 );
		}

		#endregion Public methods
	}
}
