////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for tuples.
	/// </summary>
	public class TupleComparer : IItemEqualityComparer<Tuple>
	{
		#region Public static properties

		private static readonly TupleComparer _Instance = new TupleComparer();
		/// <summary>
		/// Global comparer for tuples. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static TupleComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified tuple.
		/// </summary>
		/// <param name="tuple">Tuple whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified tuple.</returns>
		public int GetHashCode( Tuple tuple )
		{
			ValidationUtils.ObjectHasContent( tuple, "tuple" );

			return tuple.GetHashCode();
		}

		/// <summary>
		/// Verifies if the specified tuples have the same value.
		/// </summary>
		/// <param name="tuple1">Tuple to verify.</param>
		/// <param name="tuple2">Tuple to verify.</param>
		/// <returns>Returns true if the tuples have the same value.</returns>
		public bool Equals( Tuple tuple1, Tuple tuple2 )
		{
			ValidationUtils.ObjectHasContent( tuple1, "tuple1" );

			return tuple1.Equals( tuple2 );
		}

		/// <summary>
		/// Compares the specified tuples.
		/// </summary>
		/// <param name="tuple1">Tuple to compare.</param>
		/// <param name="tuple2">Tuple to compare.</param>
		/// <returns>Returns 0 if the tuples have the same value, -1 if "tuple1" is smaller than "tuple2", and 1
		/// if "tuple1" is greater than "tuple2".</returns>
		public int Compare( Tuple tuple1, Tuple tuple2 )
		{
			ValidationUtils.ObjectHasContent( tuple1, "tuple1" );

			return tuple1.Compare( tuple2 );
		}

		#endregion Public methods
	}
}
