////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel.Serialization;

namespace Vela.Kernel
{
	/// <summary>
	/// A locator-time pair.
	/// </summary>
	public class LocatorTime : IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LocatorTime()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="locator">The locator of the referred document.</param>
		/// <param name="time">A time relevant to the referred document.</param>
		public LocatorTime( Locator locator, DateTime time )
		{
			Locator = locator;
			Time = time;
		}

		#endregion Constructors

		#region Public serializable properties

		private Locator _Locator;
		/// <summary>
		/// The locator of the referred document. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public Locator Locator
		{
			get { return _Locator; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "Locator" );

				_Locator = value;
			}
		}

		private DateTime _Time;
		/// <summary>
		/// A time (in UTC format) relevant to the referred document. READ-ONLY.
		/// </summary>
		public DateTime Time
		{
			get { return _Time; }
			protected set { _Time = value; }
		}

		#endregion Public serializable properties
	}
}
