////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// List of locator-time pairs (<see cref="LocatorTime"/>).
	/// </summary>
	public class LocatorTimes : KernelSortedList<Locator, LocatorTime>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public LocatorTimes()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="LocatorTime.Locator"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( LocatorTime item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.Locator;
		}

		#endregion Public methods
	}
}
