////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.ComponentModel;

namespace Vela.Kernel
{
	/// <summary>
	/// Implements notifications for changed properties.
	/// </summary>
	public class NotifyPropertyChanged : INotifyPropertyChanged
	{
		#region Events

		/// <summary>
		/// Event raised when a property of the current class changes. This may be null.
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged;

		#endregion Events

		#region Private fields

		/// <summary>
		/// If this is true then the notification events are not raised while the content of the current object is changed.
		/// </summary>
		protected bool FrozenCollectionChangedNotifications;

		#endregion Private fields

		#region Private methods

		/// <summary>
		/// Notifies property observers when a property was changed.
		/// </summary>
		/// <param name="propertyName">The name of the property which has changed. Validation is not performed.</param>
		protected virtual void OnPropertyChanged( string propertyName )
		{
			if( (PropertyChanged == null) || FrozenCollectionChangedNotifications )
				return;

			PropertyChangedEventArgs eventArgs = new PropertyChangedEventArgs( propertyName );

			PropertyChanged( this, eventArgs );
		}

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Freezes or unfreezes the notification events.
		/// </summary>
		/// <param name="freeze">If this is true then the notification events are not raised while the content of the current
		/// object is changed.</param>
		public virtual void FreezeCollectionChangedNotifications( bool freeze )
		{
			FrozenCollectionChangedNotifications = freeze;
		}

		#endregion Public methods
	}
}
