////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for a communication frame algorithm.
	/// </summary>
	/// <remarks>
	/// <para>A communication frame is a block of data which is tranfered over the network, and contains a header (of a fixed
	/// size, at least 1 byte) and a body (of a variable size, at least 1 byte).</para>
	/// </remarks>
	public interface ICommunicationFrameAlg : IImmutableAlgorithm
	{
		#region Public non-serializable properties

		/// <summary>
		/// The size of the header. READ-ONLY.
		/// </summary>
		int HeaderSize { get; }

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Sets up the header of the communication frame.
		/// </summary>
		/// <param name="body">The body of the communication frame.</param>
		/// <returns>Returns the created header.</returns>
		byte[] SetupHeader( byte[] body );

		/// <summary>
		/// Encodes the specified message into the body of the communication frame.
		/// </summary>
		/// <param name="message">The message to encode.</param>
		/// <returns>Returns the resulted body.</returns>
		byte[] EncodeBody( byte[] message );

		/// <summary>
		/// Decodes the specified body of the communication frame into a message.
		/// </summary>
		/// <param name="body">The body to decode.</param>
		/// <returns>Returns the resulted message.</returns>
		byte[] DecodeBody( byte[] body );

		#endregion Public methods
	}
}
