////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel.Serialization;

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for an expirable algorithm.
	/// </summary>
	/// <remarks>
	/// <para>An expirable algorithm expires at a given time.</para>
	/// 
	/// <para>For example, expirable algorithms expire because (it's assumed that) the algorithm can be broken with the
	/// computing power available at that time.</para>
	/// </remarks>
	public interface IExpirableAlgorithm : IDocument
	{
		#region Public non-serializable properties

		/// <summary>
		/// The time (in UTC format) from which the current object expires and should no longer be used in processing.
		/// READ-ONLY.
		/// </summary>
		DateTime ExpirationTime { get; }

		#endregion Public non-serializable properties
	}
}
