////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for an expirable document.
	/// </summary>
	/// <remarks>
	/// <para>An expirable document expires at a given time, time which may be set. The document should be considered invalid
	/// from that time onward, should not be used in processing, and may be deleted or moved to an archive.</para>
	/// </remarks>
	public interface IExpirableDocument : ILocatable, IExpirableAlgorithm
	{
		#region Public serializable properties

		/// <summary>
		/// The creation time (in UTC format) of the document. This is automatically set with the time of the creation of the
		/// current document. The current document is valid from and after this time; before this time, it should not be used in
		/// processing. READ-ONLY.
		/// </summary>
		DateTime CreationTime { get; }

		/// <summary>
		/// The expiration time (in UTC format) of the document. The current document is valid before this time; from and after
		/// this time, it should not be used in processing. READ-ONLY.
		/// </summary>
		DateTime DocumentExpirationTime { get; }

		#endregion Public serializable properties
	}
}
