////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for a (binary) progression algorithm.
	/// </summary>
	public interface IProgressionAlgorithm : IImmutableAlgorithm
	{
		#region Public methods

		/// <summary>
		/// Returns an array of bytes, as a progression of the current algorithm.
		/// </summary>
		/// <param name="seed">The seed from which to start the progression. This is incremented in here.</param>
		/// <param name="size">The number of bytes to return in the array. This must be at least 1.</param>
		/// <returns>Returns an array of bytes, as a progression of the current algorithm.</returns>
		/// <remarks>
		/// <para>The specified seed is incremented and then progressed, iteratively, until the specified size is bytes is
		/// generated.</para>
		/// </remarks>
		byte[] GetProgressionBytes( byte[] seed, int size );

		#endregion Public methods
	}
}
