////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Kernel
{
	/// <summary>
	/// Delegate for an event raised when a log record is added to the log manager.
	/// </summary>
	/// <param name="record">Log record added to the log manager.</param>
	public delegate void LogRecordAddedDelegate( LogRecord record );

	/// <summary>
	/// Delegate for an event raised when an error occurs.
	/// </summary>
	/// <param name="message">Error message.</param>
	/// <param name="exception">Exception.</param>
	public delegate void ErrorDelegate( string message, Exception exception );

	/// <summary>
	/// Delegate for an event raised when progress occurs during a long operation.
	/// </summary>
	/// <param name="lop">The long operation progress object.</param>
	public delegate void LongOperationProgressDelegate( LongOperationProgress lop );
}
