////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections;

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for an observable list.
	/// </summary>
	public interface IKernelObservableList : IItemTypeAwareList, IEnumerable
	{
		#region Public non-serializable properties

		/// <summary>
		/// The number of items from the list. READ-ONLY.
		/// </summary>
		int Count { get; }

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Adds a new item to the list. Notifies property observers. Notifies list observers.
		/// </summary>
		/// <param name="item">Item to add to the list.</param>
		/// <remarks>
		/// <para>Required for deserialization.</para>
		/// </remarks>
		void Add( object item );

		#endregion Public methods
	}
}
