////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for a dictionary, that is, for a list in which items can be quickly found based on their key
	/// (<see cref="KernelKeyedList&lt;TKey, TItem&gt;.GetKey"/>), using a binary search algorithm.
	/// </summary>
	/// <remarks>
	/// <para>Avoid using dictionaries in (signed) documents because the order of the items is not guaranteed, so signatures
	/// would fail. Prefer to use either ordered or sorted lists.</para>
	/// </remarks>
	public abstract class KernelDictionary<TKey, TItem> : KernelKeyedList<TKey, TItem>, IUnsignable
		where TItem : class
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected KernelDictionary()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="comparer">The equality comparer used to compare keys.</param>
		protected KernelDictionary( IEqualityComparer<TKey> comparer )
			: base( comparer )
		{
			Items = new Dictionary<TKey, TItem>( comparer );
		}

		#endregion Constructors
	}
}
