////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// List of locatable documents.
	/// </summary>
	public class Locatables : KernelSortedList<Locator, ILocatable>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Locatables()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="ILocatable.InstanceLocator"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( ILocatable item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.InstanceLocator;
		}

		#endregion Public methods
	}
}
