////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.Generic;

namespace Vela.Kernel
{
	/// <summary>
	/// Comparer for locators.
	/// </summary>
	public class LocatorComparer : IItemEqualityComparer<Locator>
	{
		#region Public static properties

		private static readonly LocatorComparer _Instance = new LocatorComparer();
		/// <summary>
		/// Global comparer for locators. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		public static LocatorComparer Instance
		{
			get { return _Instance; }
		}

		#endregion Public static properties

		#region Public methods

		/// <summary>
		/// Gets the hash code of the specified locator.
		/// </summary>
		/// <param name="locator">Locator whose hash code to get.</param>
		/// <returns>Returns the hash code of the specified locator.</returns>
		/// <remarks>
		/// <para>The hash code is generated from the <see cref="Locator.Value"/> property.</para>
		/// </remarks>
		public int GetHashCode( Locator locator )
		{
			ValidationUtils.ObjectHasContent( locator, "locator" );

			return locator.GetHashCode();
		}

		/// <summary>
		/// Verifies if the specified locators have the same value.
		/// </summary>
		/// <param name="locator1">Locator to verify.</param>
		/// <param name="locator2">Locator to verify.</param>
		/// <returns>Returns true if the locators have the same value.</returns>
		/// <remarks>
		/// <para>The locators are equal if their <see cref="Locator.Value"/> properties are equal.</para>
		/// </remarks>
		public bool Equals( Locator locator1, Locator locator2 )
		{
			ValidationUtils.ObjectHasContent( locator1, "locator1" );

			return locator1.Equals( locator2 );
		}

		/// <summary>
		/// Compares the specified locators.
		/// </summary>
		/// <param name="locator1">Locator to compare.</param>
		/// <param name="locator2">Locator to compare.</param>
		/// <returns>Returns 0 if the locators have the same value, -1 if "locator1"is smaller than "locator2", and 1 if
		/// "locator1" is greater than
		/// "locator2".</returns>
		/// <remarks>
		/// <para>The locators are equal if their <see cref="Locator.Value"/> properties are equal.</para>
		/// </remarks>
		public int Compare( Locator locator1, Locator locator2 )
		{
			ValidationUtils.ObjectHasContent( locator1, "locator1" );

			return locator1.Compare( locator2 );
		}

		#endregion Public methods
	}
}
