////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// List of locators (<see cref="Locator"/>).
	/// </summary>
	public class Locators : KernelSortedList<Locator, Locator>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public Locators()
			: base( LocatorComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="locators">The locators to add to the list. This may be empty, but not null.</param>
		public Locators( params Locator[] locators )
			: base( LocatorComparer.Instance )
		{
			ValidationUtils.ObjectHasContent( locators, "locators" );

			foreach( Locator locator in locators )
				Add( locator );
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The item itself is used as key.</para>
		/// </remarks>
		public override Locator GetKey( Locator item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item;
		}

		#endregion Public methods
	}
}
