////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// A log record field.
	/// </summary>
	public class LogRecordField
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LogRecordField()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="name">Field name. This may be null or empty.</param>
		/// <param name="value">Field value. This should be either a scalar or an exception. This may be null.</param>
		/// <param name="showToUser">If this is true then the field must be shown to the user.</param>
		/// <param name="priority">The display priority.</param>
		public LogRecordField( string name, object value, bool showToUser, LogRecordFieldPriorities priority )
		{
			Name = name;
			Value = value;
			ShowToUser = showToUser;
			Priority = priority;
		}

		#endregion Constructors

		#region Public non-serializable properties

		private string _Name;
		/// <summary>
		/// Field name. This may be null or empty. READ-ONLY.
		/// </summary>
		public string Name
		{
			get { return _Name; }
			protected set { _Name = value; }
		}

		private object _Value;
		/// <summary>
		/// Field value. This should be either a scalar or an exception. This may be null. READ-ONLY.
		/// </summary>
		public object Value
		{
			get { return _Value; }
			protected set { _Value = value; }
		}

		private bool _ShowToUser;
		/// <summary>
		/// If this is true then the field should be shown to the user. READ-ONLY.
		/// </summary>
		public bool ShowToUser
		{
			get { return _ShowToUser; }
			protected set { _ShowToUser = value; }
		}

		private LogRecordFieldPriorities _Priority;
		/// <summary>
		/// The display priority. READ-ONLY.
		/// </summary>
		public LogRecordFieldPriorities Priority
		{
			get { return _Priority; }
			protected set { _Priority = value; }
		}

		#endregion Public non-serializable properties
	}
}
