﻿////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Serialization;

namespace Vela.Kernel
{
	/// <summary>
	/// A textual form field made from a pair of a name and a value.
	/// </summary>
	public class NameValueField
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public NameValueField( string name, string value )
		{
			Name = name;
			Value = value;
		}

		#endregion Constructors

		#region Public serializable properties

		private string _Name;
		/// <summary>
		/// The name of the field. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string Name
		{
			get { return _Name; }
			protected set
			{
				ValidationUtils.TextHasContent( value, "Name" );

				_Name = value;
			}
		}

		private string _Value;
		/// <summary>
		/// The value of the field. This may be null or empty. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string Value
		{
			get { return _Value; }
			protected set { _Value = value; }
		}

		#endregion Public serializable properties
	}
}
