////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for a parsing algorithm.
	/// </summary>
	/// <remarks>
	/// <para>A parsing algorithm is a registrable algorithm which must be able to parse some serialized data, using an instance
	/// of itself.</para>
	/// 
	/// <para>A parsing algorithm must fulfill the following criteria:</para>
	/// <list type="bullet">
	///		<item>Must derive from this interface.</item>
	///		<item>Must be immutable.</item>
	///		<item>Must have a static method called <see cref="RegistrableAlgorithmUtils.GetParsingAlgorithmMethodName"/> which
	///			must have a single buffer or text parameter, and must return an instance of itself if it may parse the input
	///			data; the buffer may be binary data or a binary encoded text. If the input data is a buffer then the method with
	///			a buffer parameter is called (if it exists), and if the data is a text then the method with a text parameter is
	///			called (if it exists). The method must extract the full state of the algorithm, from the input data, before it
	///			returns (a non null value). The method may either return null or may throw an exception if it can't parse the
	///			data; throwing an exception may be extremely costly in practical scenarios (for example, extracting a
	///			deserializer may be tens of times slower than the actual deserialization).</item>
	///		<item>Must have an instance method which has a single buffer or text parameter, which parses the input data and
	///			returns some object (which may be a mutable registrable algorithm).</item>
	/// </list>
	/// </remarks>
	public interface IParsingAlgorithm : IImmutableAlgorithm
	{
	}
}
