////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel.Serialization
{
	/// <summary>
	/// Contract for a document. A document is a serializable class.
	/// </summary>
	/// <remarks>
	/// <para>All serializable classes must derive from this interface.</para>
	/// 
	/// <para>A serializable class is one which has no non-serializable properties / fields which must be set from outside the
	/// class, after deserialization, in order to get a working class instance. This means that a serializable class may be
	/// cloned through serialization and deserialization into a consistent state (without further changes).</para>
	/// 
	/// <para>The parameterless constructor may set some non-serializable properties because it's also used during
	/// deserialization to restore the object, but no other constructor may do this. Still, the constructors with parameters may
	/// do this so long as they set the same non-serializable properties as the parameterless constructor, and with the same
	/// values.</para>
	/// 
	/// <para>A document may be passed among processes, in a serialized form.</para>
	/// </remarks>
	public interface IDocument : IPortableType
	{
	}
}
