////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel.Serialization
{
	/// <summary>
	/// Contract for an unserializable class.
	/// </summary>
	/// <remarks>
	/// <para>Classes which are (indirectly) derived from <see cref="IDocument"/>, but are not serializable themselves, must
	/// derive from this interface.</para>
	/// 
	/// <para>This interface indicates that the implementing class can't maintain its internal consistency if it were to be
	/// serialized and then deserialized. An example is a class which contains some handles to (unserializable) system resources;
	/// such handles may be shallow cloned, but not deep cloned.</para>
	/// 
	/// <para>An unserializable object may be cloned for use only within the same process.</para>
	/// </remarks>
	public interface IUnserializable
	{
	}
}
