////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Kernel
{
	/// <summary>
	/// Contract for a test.
	/// </summary>
	public abstract class Test
	{
		#region Public constants

		/// <summary>
		/// The default value for <see cref="SortPrefix"/>.
		/// </summary>
		public const string SortPrefixDef = "0000 0000 00";

		#endregion Public constants

		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public abstract string Name { get; }

		/// <summary>
		/// If this is true then the test is long. By default, <code>false</code> is returned.
		/// </summary>
		public virtual bool IsLong
		{
			get { return false; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test. The value is <see cref="SortPrefixDef"/>.
		/// </summary>
		/// <remarks>
		/// <para>Use the following parttern: "aaaa bbbb cc"; use only digits in order to have a clear view of the order of
		/// execution of the tests.</para>
		/// 
		/// <para>Tests which don't override this property will be executed before those which override it.</para>
		/// </remarks>
		public virtual string SortPrefix
		{
			get { return SortPrefixDef; }
		}

		/// <summary>
		/// The sort key for the order in which to run the test.
		/// </summary>
		public string SortKey
		{
			get { return SortPrefix + Name; }
		}

		#endregion Public non-serializable properties

		#region Public methods

		/// <summary>
		/// Gets the textual representation of the current object.
		/// </summary>
		/// <returns>Returns the textual representation of the current object.</returns>
		public override string ToString()
		{
			return Name;
		}

		/// <summary>
		/// Executes the test.
		/// </summary>
		/// <param name="context">The test context.</param>
		public abstract void Execute( TestContext context );

		#endregion Public methods
	}
}
