////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Threading;
namespace Vela.Kernel
{
	/// <summary>
	/// Time utilities.
	/// </summary>
	public static class TimeUtils
	{
		#region Public static methods

		/// <summary>
		/// Converts the specified number of seconds to milliseconds.
		/// </summary>
		/// <param name="seconds">The number of seconds to convert.</param>
		/// <returns>Returns the resulted number of milliseconds.</returns>
		public static int SecondsToMilli( double seconds )
		{
			return (int)(seconds * 1000);
		}

		/// <summary>
		/// Converts the specified number of minutes to seconds.
		/// </summary>
		/// <param name="minutes">The number of minutes to convert.</param>
		/// <returns>Returns the resulted number of seconds.</returns>
		public static double MinutesToSeconds( double minutes )
		{
			return minutes * 60;
		}

		/// <summary>
		/// Converts the specified number of hours to seconds.
		/// </summary>
		/// <param name="hours">The number of hours to convert.</param>
		/// <returns>Returns the resulted number of seconds.</returns>
		public static double HoursToSeconds( double hours )
		{
			return hours * 3600;
		}

		/// <summary>
		/// The current thread sleeps the specified number of milliseconds.
		/// </summary>
		/// <param name="milliseconds">Number of milliseconds for the current thread to sleep. If this is 0 or a negative number,
		/// nothing happens.</param>
		public static void SleepMilliseconds( int milliseconds )
		{
			if( milliseconds > 0 ) Thread.Sleep( milliseconds );
		}

		/// <summary>
		/// Sleeps the current thread for the specified number of seconds.
		/// </summary>
		/// <param name="seconds">The number of seconds for the current thread to sleep.</param>
		/// <param name="checkAbort">Event raised once per second in order to check if the sleep must be aborted. This may be
		/// null.</param>
		public static void SleepSeconds( double seconds, Func<bool> checkAbort )
		{
			if( seconds <= 0 ) return;

			int fullSeconds = (int)seconds;

			for( int i = 0; i < fullSeconds; i++ )
			{
				SleepMilliseconds( 1000 );

				if( (checkAbort != null) && checkAbort() ) return;
			}

			SleepMilliseconds( SecondsToMilli( seconds - fullSeconds ) );
		}

		/// <summary>
		/// Gets the maximum time from the specified values.
		/// </summary>
		/// <param name="time1">Time 1.</param>
		/// <param name="time2">Time 2.</param>
		/// <returns>Returns the maximum time from the specified values.</returns>
		public static DateTime Max( DateTime time1, DateTime time2 )
		{
			return (time1 >= time2) ? time1 : time2;
		}

		#endregion Public static methods
	}
}
