////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Kernel
{
	/// <summary>
	/// Type utilities.
	/// </summary>
	public static class TypeUtils
	{
		#region Public static methods

		/// <summary>
		/// Checks if an instance of the specified type may be null.
		/// </summary>
		/// <param name="type">Type to check.</param>
		/// <returns>Returns true if an instance of the specified type may be null.</returns>
		public static bool MayHaveNullInstance( Type type )
		{
			ValidationUtils.ObjectHasContent( type, "type" );

			if( !type.IsValueType ) return true;

			if( Nullable.GetUnderlyingType( type ) != null ) return true;

			return false;
		}

		#endregion Public static methods
	}
}
