////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Data.SqlServerCe;
using System.Reflection;
using Vela.Kernel;
using Vela.Storehouse;

namespace Vela.DatabaseStorehouse
{
	/// <summary>
	/// Transaction for an SQL Server CE (= Compact Edition) database.
	/// </summary>
	public class MsSqlCeDatabaseTransaction : DatabaseTransaction
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected MsSqlCeDatabaseTransaction()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="storehouseProvider">The storehouse provider which has created the current transaction.</param>
		/// <remarks>
		/// <para>The storehouse is opened in here, but the storehouse header is not loaded (because it's lazy loaded).</para>
		/// </remarks>
		public MsSqlCeDatabaseTransaction( IStorehouseProvider storehouseProvider )
			: base( storehouseProvider )
		{
		}

		#endregion Constructors

		#region Private methods

		/// <summary>
		/// Commits the current transaction in the storehouse.
		/// </summary>
		protected override void InternalCommit()
		{
			{
				LogManager logManager = LogManagerStartMethod( MethodBase.GetCurrentMethod() );

				try
				{
					SqlCeTransaction transactionTyped = (SqlCeTransaction)Transaction;
					transactionTyped.Commit( CommitMode.Immediate );
				}
				finally
				{
					LogManagerEndMethod( logManager );
				}
			}
		}

		#endregion Private methods
	}
}
