////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.ActionProcessor;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// An action reponse to make a payment.
	/// </summary>
	public class MakePaymentActionResponse : ActionResponseWithBeneficiary
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected MakePaymentActionResponse()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="actionRequest">The action request to which the current action response is associated.</param>
		/// <param name="secondaryProcessingState">Secondary processing state. This may be null.</param>
		/// <param name="balances">The balances of the account.</param>
		public MakePaymentActionResponse( Locator instanceLocator, ActionRequestWithBeneficiary actionRequest
				, SecondaryProcessingState secondaryProcessingState, PaymentBalances balances )
			: base( instanceLocator, actionRequest, secondaryProcessingState )
		{
			Balances = balances;
		}

		#endregion Constructors

		#region Public serializable properties

		private PaymentBalances _Balances;
		/// <summary>
		/// The balances of the account. READ-ONLY.
		/// </summary>
		[SerializeAttribute( ListItemName = "Balance" )]
		public PaymentBalances Balances
		{
			get { return _Balances; }
			protected set
			{
				ValidationUtils.ListHasContent( value, "Balances" );

				_Balances = value;
			}
		}

		#endregion Public serializable properties
	}
}
