////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.Kernel.Serialization;
using Vela.PeerDocuments;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// Payment account.
	/// </summary>
	public class PaymentAccount : Account
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected PaymentAccount()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="localUpn">The UPN of the local peer.</param>
		/// <param name="remoteUpn">The UPN of the remote peer.</param>
		/// <param name="alias">The account alias. This may be null.</param>
		public PaymentAccount( Locator instanceLocator, Upn localUpn, Upn remoteUpn, AccountAlias alias )
			: base( instanceLocator, localUpn, remoteUpn, alias )
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private PaymentBalances _Balances = new PaymentBalances();
		/// <summary>
		/// The balances of the account. The backing field is initialized by default. READ-ONLY.
		/// </summary>
		[SerializeAttribute( ListItemName = "Balance" )]
		public PaymentBalances Balances
		{
			get { return _Balances; }
			protected set
			{
				ValidationUtils.ListHasContent( value, "Balances" );

				_Balances = value;
			}
		}

		#endregion Public serializable properties
	}
}
