////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;
using Vela.Serialization;
using Vela.Crypto;
using Vela.CoreDocuments;
using Vela.PeerDocuments;
using Vela.ActionProcessor;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// Payment appendix.
	/// </summary>
	public class PaymentAppendix : Appendix
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected PaymentAppendix()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="entityName">The name of the identified entity.</param>
		public PaymentAppendix( string entityName )
			: base( entityName )
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private PaymentFeePlans _FeePlans = new PaymentFeePlans();
		/// <summary>
		/// The fee plans charged by the payment service for every payment, for each currency name
		/// (<see cref="PaymentFeePlan.CurrencyName"/>). The backing field is initialized by default.
		/// </summary>
		[SerializeAttribute( ListItemName = "FeePlan" )]
		public PaymentFeePlans FeePlans
		{
			get { return _FeePlans; }
			set
			{
				ValidationUtils.ObjectHasContent( value, "FeePlans" );

				_FeePlans = value;
			}
		}

		#endregion Public serializable properties
	}
}
