	////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// A payment balance.
	/// </summary>
	public class PaymentBalance : IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PaymentBalance()
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private string _CurrencyName;
		/// <summary>
		/// The name of the currency of the balance.
		/// </summary>
		[SerializeAttribute]
		public string CurrencyName
		{
			get { return _CurrencyName; }
			set
			{
				ValidationUtils.TextHasContent( value, "CurrencyName" );

				_CurrencyName = value;
			}
		}

		private double _CurrencyAmount;
		/// <summary>
		/// The amount of currency of the balance, expressed in <see cref="CurrencyName"/> currency units. This must be at least
		/// <see cref="double.Epsilon"/>.
		/// </summary>
		[SerializeAttribute]
		public double CurrencyAmount
		{
			get { return _CurrencyAmount; }
			set
			{
				ValidationUtils.Real( value, double.Epsilon, double.MaxValue, "CurrencyAmount" );

				_CurrencyAmount = value;
			}
		}

		#endregion Public serializable properties
	}
}
