////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// List of payment balances (<see cref="PaymentBalance"/>).
	/// </summary>
	public class PaymentBalances : KernelSortedList<string, PaymentBalance>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PaymentBalances()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="PaymentBalance.CurrencyName"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( PaymentBalance item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.CurrencyName;
		}

		#endregion Public methods
	}
}
