////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// List of payment fee plans (<see cref="PaymentFeePlan"/>).
	/// </summary>
	public class PaymentFeePlans : KernelSortedList<string, PaymentFeePlan>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PaymentFeePlans()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="feePlans">List of fee plans to add to the new list.</param>
		public PaymentFeePlans( params PaymentFeePlan[] feePlans )
			: base( StringInsensitiveComparer.Instance )
		{
			ValidationUtils.ArrayHasContent( feePlans, "feePlans" );

			foreach( PaymentFeePlan feePlan in feePlans )
				Add( feePlan );
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="PaymentFeePlan.CurrencyName"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( PaymentFeePlan item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.CurrencyName;
		}

		#endregion Public methods
	}
}
