////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;
using Vela.CoreDocuments;
using Vela.PeerDocuments;

namespace Vela.PaymentDocuments
{
	/// <summary>
	/// Payment vault.
	/// </summary>
	public class PaymentVault : Vault
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected PaymentVault()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="instanceLocator">Instance locator.</param>
		/// <param name="rootSecretSize">The size (in bytes) that the root secret must have. If this is 0 or a negative number,
		/// the default <see cref="CoreDocumentsConsts.SymmEncryptionKeySizeDef"/> is used.</param>
		/// <param name="processingIdentity">The private identity used for processing.</param>
		/// <param name="appendix">The appendix.</param>
		public PaymentVault( Locator instanceLocator, int rootSecretSize, PrivateIdentity processingIdentity, Appendix appendix )
			: base( instanceLocator, rootSecretSize, processingIdentity, appendix )
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private bool _SignChargedFee = true;
		/// <summary>
		/// If this is true then the charged fees are signed by the action service. The default value is true.
		/// </summary>
		/// <remarks>
		/// <para>If the performance of the storehouse must be increased, set this with false.</para>
		/// </remarks>
		[SerializeAttribute]
		public bool SignChargedFee
		{
			get { return _SignChargedFee; }
			set { _SignChargedFee = value; }
		}

		#endregion Public serializable properties
	}
}
