///////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
///////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// List of attached file names (<see cref="AttachedFileName"/>).
	/// </summary>
	public class AttachedFileNames : KernelSortedList<string, AttachedFileName>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public AttachedFileNames()
			: base( StringInsensitiveComparer.Instance )
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="fileNames">The names of the attached files. This may be null or empty.</param>
		public AttachedFileNames( Strings fileNames )
			: base( StringInsensitiveComparer.Instance )
		{
			if( ListUtils.NoContent( fileNames ) )
				return;

			foreach( string fileName in fileNames )
				Add( new AttachedFileName( fileName ) );
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="AttachedFileName.SortKey"/> is used as key.</para>
		/// </remarks>
		public override string GetKey( AttachedFileName item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.SortKey;
		}

		#endregion Public methods
	}
}
