///////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
///////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// Attached file with a local file name.
	/// </summary>
	public class LocalAttachedFile
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LocalAttachedFile()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="attachedFile">Attached file.</param>
		/// <param name="localFileName">Local file name.</param>
		public LocalAttachedFile( AttachedFile attachedFile, string localFileName )
		{
			AttachedFile = attachedFile;
			LocalFileName = localFileName;
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The sort key. READ-ONLY.
		/// </summary>
		public string SortKey
		{
			get { return AttachedFile.SortKey; }
		}

		#endregion Public non-serializable properties

		#region Public serializable properties

		private AttachedFile _AttachedFile;
		/// <summary>
		/// Attached file. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public AttachedFile AttachedFile
		{
			get { return _AttachedFile; }
			protected set
			{
				ValidationUtils.ObjectHasContent( value, "AttachedFile" );

				_AttachedFile = value;
			}
		}

		private string _LocalFileName;
		/// <summary>
		/// Local file name. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string LocalFileName
		{
			get { return _LocalFileName; }
			protected set
			{
				ValidationUtils.TextHasContent( value, "LocalFileName" );

				_LocalFileName = value;
			}
		}

		#endregion Public serializable properties
	}
}
