////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// List of peer IP addresses (<see cref="PeerIpAddress"/>).
	/// </summary>
	public class PeerIpAddresses : KernelSortedList<byte[], PeerIpAddress>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PeerIpAddresses()
			: base( BufferComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para>The <see cref="PeerIpAddress.IpAddress"/> is used as key.</para>
		/// </remarks>
		public override byte[] GetKey( PeerIpAddress item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.IpAddress;
		}

		/// <summary>
		/// Gets the item from the list which was created most recently.
		/// </summary>
		/// <returns>Returns the item from the list which was created most recently. This is null if the list is empty.</returns>
		public PeerIpAddress GetMostRecent()
		{
			DateTime maxTime = DateTime.MinValue;
			PeerIpAddress recentIpAddress = null;

			foreach( PeerIpAddress ipAddress in this )
			{
				if( ipAddress.CreationTime >= maxTime )
				{
					maxTime = ipAddress.CreationTime;
					recentIpAddress = ipAddress;
				}
			}

			return recentIpAddress;
		}

		#endregion Public methods
	}
}
