////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// A virtual identity for an organization.
	/// </summary>
	public class OrganizationVirtualIdentity : VirtualIdentity
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public OrganizationVirtualIdentity()
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private string _ServiceLegalContract;
		/// <summary>
		/// The service's legal contract. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string ServiceLegalContract
		{
			get { return _ServiceLegalContract; }
			set
			{
				ValidationUtils.Text( value, -2, KernelConsts.LegalContractSizeMax, TextValidations.None
					, "ServiceLegalContract" );

				_ServiceLegalContract = value;
			}
		}

		#endregion Public serializable properties
	}
}
