////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// A virtual identity for a person.
	/// </summary>
	public class PersonVirtualIdentity : VirtualIdentity
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PersonVirtualIdentity()
		{
		}

		#endregion Constructors

		#region Public serializable properties

		private string _FamilyName;
		/// <summary>
		/// The name of the family (= the "last name") of the identified person. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string FamilyName
		{
			get { return _FamilyName; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.EntityName, "FamilyName" );

				_FamilyName = value;
			}
		}

		private string _GivenName;
		/// <summary>
		/// The given name (= the "first name") of the identified person. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string GivenName
		{
			get { return _GivenName; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.EntityName, "GivenName" );

				_GivenName = value;
			}
		}

		private Genders _Gender = Genders.NotSpecified;
		/// <summary>
		/// The (self-assumed) gender of the person.
		/// </summary>
		[SerializeAttribute]
		public Genders Gender
		{
			get { return _Gender; }
			set { _Gender = value; }
		}

		private SentimentalRelationships _SentimentalRelationship = SentimentalRelationships.NotSpecified;
		/// <summary>
		/// The sentimental relationship of the person.
		/// </summary>
		[SerializeAttribute]
		public SentimentalRelationships SentimentalRelationship
		{
			get { return _SentimentalRelationship; }
			set { _SentimentalRelationship = value; }
		}

		#endregion Public serializable properties
	}
}
