////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.PeerDocuments
{
	/// <summary>
	/// A physical address.
	/// </summary>
	public class PhysicalAddress : IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PhysicalAddress()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="country">The country where the peer lives. This may be null or empty.</param>
		/// <param name="province">The province where the peer lives. This may be null or empty.</param>
		/// <param name="city">The city where the peer lives. This may be null or empty.</param>
		/// <param name="streetName">The name of the street where the peer lives. This may be null or empty.</param>
		/// <param name="streetNumber">The number of the street where the peer lives. This may be null or empty.</param>
		/// <param name="building">The building number where the peer lives. This may be null or empty.</param>
		/// <param name="postalCode">The postal code where the peer lives. This may be null or empty.</param>
		public PhysicalAddress( Countries country, string province, string city, string streetName, string streetNumber
			, string building, string postalCode )
		{
			Country = country;
			Province = province;
			City = city;
			StreetName = streetName;
			StreetNumber = streetNumber;
			Building = building;
			PostalCode = postalCode;
		}

		#endregion Constructors

		#region Public serializable properties

		private Countries _Country = Countries.NotSpecified;
		/// <summary>
		/// The country where the peer lives.
		/// </summary>
		[SerializeAttribute]
		public Countries Country
		{
			get { return _Country; }
			set { _Country = value; }
		}

		private string _Province;
		/// <summary>
		/// The province where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string Province
		{
			get { return _Province; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.EntityName, "Province" );

				_Province = value;
			}
		}

		private string _City;
		/// <summary>
		/// The city where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string City
		{
			get { return _City; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.EntityName, "City" );

				_City = value;
			}
		}

		private string _StreetName;
		/// <summary>
		/// The name of the street where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string StreetName
		{
			get { return _StreetName; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.EntityName, "StreetName" );

				_StreetName = value;
			}
		}

		private string _StreetNumber;
		/// <summary>
		/// The number of the street where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string StreetNumber
		{
			get { return _StreetNumber; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.Code, "StreetNumber" );

				_StreetNumber = value;
			}
		}

		private string _Building;
		/// <summary>
		/// The building number where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string Building
		{
			get { return _Building; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.Code, "Building" );

				_Building = value;
			}
		}

		private string _PostalCode;
		/// <summary>
		/// The postal code where the peer lives. This may be null or empty.
		/// </summary>
		[SerializeAttribute( MustBeDeserialized = false )]
		public string PostalCode
		{
			get { return _PostalCode; }
			set
			{
				ValidationUtils.Text( value, -2, -1, TextValidations.Code, "PostalCode" );

				_PostalCode = value;
			}
		}

		#endregion Public serializable properties
	}
}
