////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.Pnrp
{
	/// <summary>
	/// List of peer registrations (<see cref="PeerRegistration"/>).
	/// </summary>
	public class PeerRegistrations : KernelSortedList<Locator, PeerRegistration>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public PeerRegistrations()
			: base( LocatorComparer.Instance )
		{
		}

		#endregion Constructors

		#region Public methods

		/// <summary>
		/// Gets the key from the specified item.
		/// </summary>
		/// <param name="item">Item to get the key from.</param>
		/// <returns>Returns the key from the specified item.</returns>
		/// <remarks>
		/// <para><see cref="PeerRegistration.ParentLocator"/> is used as key.</para>
		/// </remarks>
		public override Locator GetKey( PeerRegistration item )
		{
			ValidationUtils.ObjectHasContent( item, "item" );

			return item.ParentLocator;
		}

		#endregion Public methods
	}
}
