////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.Serialization
{
	/// <summary>
	/// Contract for a deserializer. It can deserialize documents which were serialized with <see cref="ISerializer"/>.
	/// </summary>
	public interface IDeserializer : ISerializationFactory, IParsingAlgorithm
	{
		#region Public methods

		/// <summary>
		/// Loads the class object from the specified buffer.
		/// </summary>
		/// <param name="buffer">Buffer to deserialize. This may be null or empty.</param>
		/// <param name="documentType">The root type of the document to load; the document to load may either have this type or
		/// a type derived from this (if it's found in the global portable types from
		/// <see cref="PortableTypes.Instance"/>). If this is null, the type specified in the document's root node is
		/// searched in the global portable types. If the name of the document's root node is not found, an exception is
		/// thrown.</param>
		/// <returns>Returns the deserialized document, or null if the input data is null or empty.</returns>
		IDocument LoadFromBuffer( byte[] buffer, Type documentType );

		/// <summary>
		/// Loads the class object from the specified file.
		/// </summary>
		/// <param name="fileName">The name of the file to deserialize. The file may be missing and its content may be null or
		/// empty.</param>
		/// <param name="documentType">The root type of the document to load; the document to load may either have this type or
		/// a type derived from this (if it's found in the global portable types from
		/// <see cref="PortableTypes.Instance"/>). If this is null, the type specified in the document's root node is
		/// searched in the global portable types. If the name of the document's root node is not found, an exception is
		/// thrown.</param>
		/// <returns>Returns the deserialized document, or null if the file is missing or its content is null or empty.</returns>
		IDocument LoadFromFile( string fileName, Type documentType );

		#endregion Public methods
	}
}
