////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Serialization
{
	/// <summary>
	/// Pool of serialization algorithms.
	/// </summary>
	public interface ISerializationAlgorithmPool
	{
		#region Public methods

		/// <summary>
		/// Gets the binary serializer.
		/// </summary>
		/// <returns>Returns the binary serializer.</returns>
		ISerializer GetBinarySerializer();

		/// <summary>
		/// Gets the XML serializer.
		/// </summary>
		/// <returns>Returns the XML serializer.</returns>
		ISerializer GetXmlSerializer();

		/// <summary>
		/// Gets the serializer.
		/// </summary>
		/// <returns>Returns the serializer.</returns>
		ISerializer GetSerializer();

		/// <summary>
		/// Gets the deserializer.
		/// </summary>
		/// <returns>Returns the deserializer.</returns>
		IDeserializer GetDeserializer();

		/// <summary>
		/// Gets the hash serializer.
		/// </summary>
		/// <param name="serializeValueTypeName">If this is true then the type names of the serialized values are stored in the
		/// serialization output. If this is true, the compatibility level of different versions of a serialized document is
		/// limited (see the "Serialization versioning" section from the documentation of the <see cref="IHashSerializer"/>
		/// interface). This must be true for a hash serializer which will be used to test the equality of documents.</param>
		/// <returns>Returns the hash serializer.</returns>
		IHashSerializer GetHashSerializer( bool serializeValueTypeName );

		/// <summary>
		/// Gets the serializer for checking the equality of documents.
		/// </summary>
		/// <returns>Returns the serializer for checking the equality of documents.</returns>
		IHashSerializer GetHashSerializerForEquality();

		/// <summary>
		/// Gets the serializer for export.
		/// </summary>
		/// <returns>Returns the serializer for export.</returns>
		ISerializer GetSerializerForExport();

		#endregion Public methods
	}
}
