////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Serialization;

namespace Vela.Serialization
{
	/// <summary>
	/// Contract for a serializer. The serialization output can be deserialized with <see cref="IDeserializer"/>.
	/// </summary>
	public interface ISerializer : ISerializationFactory
	{
		#region Public methods

		/// <summary>
		/// Saves the specified class object to a buffer.
		/// </summary>
		/// <param name="serializableData">The object to serialize. This has to be a class.</param>
		/// <param name="rootName">The name of the root class object which is serialized. This name will be used during
		/// deserialization to recognize the serialized type. If this is null then the name of the specified type is used
		/// instead.</param>
		/// <returns>Returns the serialized document.</returns>
		byte[] SaveToBuffer( IDocument serializableData, string rootName );

		/// <summary>
		/// Saves the specified class object to the specified file. Existing files are overwritten.
		/// </summary>
		/// <param name="serializableData">The object to serialize. This has to be a class.</param>
		/// <param name="rootName">The name of the root class object which is serialized. This name will be used during
		/// deserialization to recognize the serialized type. If this is null then the name of the specified type is used
		/// instead.</param>
		/// <param name="fileName">The name of the file to be saved.</param>
		void SaveToFile( IDocument serializableData, string rootName, string fileName );

		#endregion Public methods
	}
}
