////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;

namespace Vela.Serialization
{
	/// <summary>
	/// Contract for a serializer writer.
	/// </summary>
	public interface ISerializerWriter
	{
		#region Public methods

		/// <summary>
		/// Adds a new class type name node to the writer.
		/// </summary>
		/// <param name="serializationName">Serialization name.</param>
		/// <param name="type">Class type.</param>
		void AddClassTypeName( string serializationName, Type type );

		/// <summary>
		/// Adds a new list type name node to the writer.
		/// </summary>
		/// <param name="serializationName">Serialization name.</param>
		/// <param name="type">List type.</param>
		void AddListTypeName( string serializationName, Type type );

		/// <summary>
		/// Adds a new scalar node to the writer.
		/// </summary>
		/// <param name="serializationName">Serialization name.</param>
		/// <param name="value">Value. This must be a scalar.</param>
		void AddScalar( string serializationName, object value );

		/// <summary>
		/// Writes the output of the serializer.
		/// </summary>
		void WriteOutput();

		#endregion Public methods
	}
}
