////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Serialization
{
	/// <summary>
	/// Constants used for serialization.
	/// </summary>
	public static class SerializationConsts
	{
		#region Public constants

		/// <summary>
		/// The separator used when formatting serialization names (<see cref="SerializationUtils.FormatSerializationName"/>)in a
		/// serializer.
		/// </summary>
		public const string FormattedSerializationNameSeparator = ".";

		/// <summary>
		/// The separator used when formatting names (<see cref="SerializationUtils.FormatSerializationListItemName"/>)in a
		/// serializer.
		/// </summary>
		public const string FormattedSerializationListItemNameSeparator = "_";

		/// <summary>
		/// The default serialization name of a list item.
		/// </summary>
		public const string ListItemName = "Item";

		/// <summary>
		/// The name of an instance method with a single "object" parameter, which adds items to a serializable list.
		/// </summary>
		public const string ListAddMethodName = "Add";

		/// <summary>
		/// The name of an instance method with a <see cref="ISerializer"/> parameter, which is called before a class object is
		/// serialized.
		/// </summary>
		public const string SerializingMethodName = "Serializing";

		/// <summary>
		/// The name of an instance method with a <see cref="ISerializer"/> parameter, which is called after a class object is
		/// serialized.
		/// </summary>
		public const string SerializedMethodName = "Serialized";

		/// <summary>
		/// The name of an instance method with a <see cref="IDeserializer"/> parameter, which is called before a class object
		/// has been deserialized.
		/// </summary>
		public const string DeserializingMethodName = "Deserializing";

		/// <summary>
		/// The name of an instance method with a <see cref="IDeserializer"/> parameter, which is called after a class object
		/// has been deserialized.
		/// </summary>
		public const string DeserializedMethodName = "Deserialized";

		/// <summary>
		/// The maximum size of a serializer's type name.
		/// </summary>
		public const int SerializerTypeNameSizeMax = 500;

		#endregion Public constants
	}
}
