////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.Kernel.Serialization;

namespace Vela.StarkDocuments
{
	/// <summary>
	/// The display shortcut key of a short command.
	/// </summary>
	public class DisplayShortCommandShortcutKey : NotifyPropertyChanged, IDocument
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected DisplayShortCommandShortcutKey()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="shortcutKey">Shortcut key.</param>
		/// <remarks>
		/// <para>The default display text is used.</para>
		/// </remarks>
		public DisplayShortCommandShortcutKey( char shortcutKey )
		{
			ShortcutKey = shortcutKey;
			DisplayText = DisplayShortcutKey;
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="shortcutKey">Shortcut key.</param>
		/// <param name="displayText">Display text. This may be null or empty.</param>
		public DisplayShortCommandShortcutKey( char shortcutKey, string displayText )
		{
			ShortcutKey = shortcutKey;
			DisplayText = displayText;
		}

		#endregion Constructors

		#region Public non-serializable properties

		/// <summary>
		/// The default display text for the shortcut key. This may be empty, but not null. READ-ONLY.
		/// </summary>
		public string DisplayShortcutKey
		{
			get { return ShortCommand.GetDisplayShortcutKey( ShortcutKey ); }
		}

		#endregion Public non-serializable properties

		#region Public serializable properties

		private char _ShortcutKey;
		/// <summary>
		/// Shortcut key. Notifies property observers. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public char ShortcutKey
		{
			get { return _ShortcutKey; }
			protected set
			{
				_ShortcutKey = value;

				// Notify property observers.
				OnPropertyChanged( "ShortcutKey" );
				OnPropertyChanged( "DisplayShortcutKey" );
			}
		}

		private string _DisplayText;
		/// <summary>
		/// Display text. This may be null or empty. Notifies property observers. READ-ONLY.
		/// </summary>
		[SerializeAttribute]
		public string DisplayText
		{
			get { return _DisplayText; }
			protected set
			{
				_DisplayText = value;

				// Notify property observers.
				OnPropertyChanged( "DisplayText" );
			}
		}

		#endregion Public serializable properties
	}
}
