////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;

namespace Vela.StarkDocuments
{
	/// <summary>
	/// List of display shortcut keys for short commands (<see cref="DisplayShortCommandShortcutKeys"/>).
	/// </summary>
	public class DisplayShortCommandShortcutKeys : KernelList<DisplayShortCommandShortcutKey>
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public DisplayShortCommandShortcutKeys()
		{
		}

		#endregion Constructors

		#region Public static methods

		/// <summary>
		/// Gets a new initialized instance of the current class.
		/// </summary>
		/// <returns>Returns a new initialized instance of the current class.</returns>
		public static DisplayShortCommandShortcutKeys GetInitializedInstance()
		{
			DisplayShortCommandShortcutKeys shortcutKeys = new DisplayShortCommandShortcutKeys();

			DisplayShortCommandShortcutKey shortcutKey;

			// "None" shortcut key.
			shortcutKey = new DisplayShortCommandShortcutKey( ShortCommand.NoShortcutKey, "None" );
			shortcutKeys.Add( shortcutKey );

			for( char i = 'A'; i <= 'Z'; i++ )
			{
				shortcutKey = new DisplayShortCommandShortcutKey( i );
				shortcutKeys.Add( shortcutKey );
			}

			return shortcutKeys;
		}

		#endregion Public static methods

		#region Public methods

		/// <summary>
		/// Finds the item with the specified shortcut key.
		/// </summary>
		/// <param name="shortcutKey">The shortcut key of the item to find.</param>
		/// <returns>Returns the found item, or null if none is found.</returns>
		public DisplayShortCommandShortcutKey FindByShortcutKey( char shortcutKey )
		{
			foreach( DisplayShortCommandShortcutKey item in this )
			{
				if( item.ShortcutKey == shortcutKey ) return item;
			}

			return null;
		}

		#endregion Public methods
	}
}
