////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.Storehouse
{
	/// <summary>
	/// <para><b>Storehouse structure</b></para>
	/// 
	/// <para>A storehouse is made a of header file (which is managed by Vela), and at least 1 other file (which is
	/// managed by the underlying storehouse provider, like a database server engine) attached to the header.</para>
	/// 
	/// <para>The storehouse header is symmetrically encrypted with the user typed password. The files attached to the header are
	/// symmetrically encrypted with a random key which is stored in the header. The documents which are stored in the storehouse
	/// are symmetrically encrypted with the document-specific key derived from the random root key which is stored in the
	/// header.</para>
	/// 
	/// <para>Some information related to the stored documents is stored outside the documents, directly in the attached files.
	/// This information is used to quickly perform certain operations. This information is stored in storehouse search
	/// filters.</para>
	/// 
	/// <para>The storehouse search filters include information like: class type names, (randomly generated) locators, creation
	/// and update times, states of objects (like letter sent / not sent), entity names, up to 1024 characters from the beginning
	/// of letters.</para>
	/// 
	/// <para><b>Various</b></para>
	/// 
	/// <para>The header is loaded once for a storehouse provider.</para>
	/// 
	/// <para>Speckles are saved unencrypted in the storehouse.</para>
	/// 
	/// <para>Each sheaf is encrypted with an encryption key generated from the storehouse root key (stored in the header) and
	/// the storehouse key of the sheaf.</para>
	/// 
	/// <para>When the storehouse owner changes his password, only the header has to be re-encrypted (not each sheaf stored in
	/// the storehouse).</para>
	/// 
	/// <para>If the caller intends to write a sheaf, it's is locked at storehouse level. This allows for the processing load to
	/// be distributed on multiple threads, either for backup or performance reasons, without worrying that stale data could be
	/// saved by some of the threads.</para>
	/// 
	/// <para>You should always load sheafs in the same order so as to minimize the chances of deadlocks and timeouts if the
	/// sheafs were to be requested from several threads at the same time.</para>
	/// 
	/// <br/>
	/// 
	/// <para><b>Service scalability</b></para>
	/// 
	/// <para>Care must be taken when implementing a scalable service. In general, when an action request is processed, the
	/// storehouse must not be locked in its entirety. For example, a payment service needs to implement a mechanism for storing
	/// the fee charged for every payment.</para>
	/// 
	/// <para>This can't be done by having a central sheaf which is modified every time a fee is charged, although this would
	/// be easier to do, because no other transactions could access this sheaf (since it's locked) and thusly no other
	/// payment could be processed by another thread. Therefore, each charged fee must be saved in an individual sheaf, and
	/// when it's necessary, the service can calculate the sum of the fees from all these sheafs.</para>
	/// 
	/// <para>If, for example, a payment is made from an account to another, only those accounts must be locked while the
	/// payment is being made; the storehouse must not be locked in its entirety. All the other threads can process other action
	/// requests, in parallel.</para>
	/// </summary>
	class NamespaceDoc
	{
		// Only for documentation.
	}
}
