////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.Kernel;

namespace Vela.CoreDocuments
{
	/// <summary>
	/// Exception which indicates that a sheaf could not be reloaded after it was just saved.
	/// </summary>
	public class SheafReloadException : BaseException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected SheafReloadException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		/// <param name="details">Exception details. This may be null or empty.</param>
		public SheafReloadException( string message, Exception exception = null, params ExceptionDetail[] details )
			: base( message, exception, details )
		{
		}

		#endregion Constructors
	}

	/// <summary>
	/// Exception which indicates that a sheaf could not be updated (likely) because its update version is older than the one
	/// from the storehouse, meaning that another thread has updated the sheaf after the current thread has loaded it.
	/// </summary>
	public class SheafUpdateVersionException : RetryCrossServiceException
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected SheafUpdateVersionException()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="message">The description of the exception. This may be null or empty.</param>
		/// <param name="exception">The existing exception when the current exception was created. This may be null.</param>
		/// <param name="details">Exception details. This may be null or empty.</param>
		public SheafUpdateVersionException( string message, Exception exception = null, params ExceptionDetail[] details )
			: base( message, exception, details )
		{
		}

		#endregion Constructors
	}
}
