////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Serialization;

namespace Vela.XmlSerialization
{
	/// <summary>
	/// Contract for a textual serializer writer.
	/// </summary>
	public interface ITextSerializerWriter : ISerializerWriter
	{
		#region Public methods

		/// <summary>
		/// Gets the key from the specified value.
		/// </summary>
		/// <param name="value">Value to get the key from.</param>
		/// <returns>Returns the key from the specified value. This must not be null or empty.</returns>
		/// <remarks>
		/// <para><see cref="TextSerializationNode.SerializationName"/> is used as key.</para>
		/// </remarks>
		string GetKey( TextSerializationNode value );

		/// <summary>
		/// Adds a new node to the writer. If the writer already contains a node with the same key, an exception is
		/// thrown. Notifies property observers. Notifies list observers.
		/// </summary>
		/// <param name="node">Node to add to the writer.</param>
		void Add( TextSerializationNode node );

		#endregion Public methods
	}
}
