////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

namespace Vela.XmlSerialization
{
	/// <summary>
	/// Contract for an XML serializer writer.
	/// </summary>
	public interface IXmlSerializerWriter
	{
		#region Public methods

		/// <summary>
		/// Writes the end of the current document to the output.
		/// </summary>
		void EndDocument();

		/// <summary>
		/// Writes the start of the named serialization node to the output. The serialization node can't have attributes.
		/// </summary>
		/// <param name="nodeName">The name of the serialization node.</param>
		void StartNodeNoAttr( string nodeName );

		/// <summary>
		/// Writes the start of the named serialization node to the output. The serialization node has attributes. The start of
		/// the serialization node must be closed using the <see cref="CloseStartNodeWithAttr"/> method.
		/// </summary>
		/// <param name="nodeName">The name of the serialization node.</param>
		void StartNodeWithAttr( string nodeName );

		/// <summary>
		/// Writes the end of the start of a serialization node which has attributes, to the output.
		/// </summary>
		void CloseStartNodeWithAttr();

		/// <summary>
		/// Writes the end of the named serialization node to the output.
		/// </summary>
		/// <param name="nodeName">The name of the serialization node.</param>
		void EndNode( string nodeName );

		/// <summary>
		/// Writes a serialization node with the specified name and value, to the output.
		/// </summary>
		/// <param name="nodeName">The name of the serialization node.</param>
		/// <param name="contentTypeName">The name of the type of the node's value of the serialized property.</param>
		/// <param name="value">Buffer to write in the node's value.</param>
		void WriteScalar( string nodeName, string contentTypeName, object value );

		/// <summary>
		/// Writes the specified text in the currently opened serialization node, to the output.
		/// </summary>
		/// <param name="attrName">The name of the serialization node attribute to write.</param>
		/// <param name="value">Buffer to write in the attribute's value.</param>
		void WriteAttribute( string attrName, string value );

		#endregion Public methods
	}
}
