////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using Vela.Kernel;

namespace Vela.Im
{
	/// <summary>
	/// Constants used for the application.
	/// </summary>
	public static class ImConsts
	{
		#region Public constants

		/// <summary>
		/// The prefix used to get the resource files which contain the icons used for application notifications.
		/// </summary>
		public const string AppNotificationResourcePrefix = "Resources.Images.ApplicationNotifications.";

		/// <summary>
		/// The prefix used to get the resource files which contain the root presenters.
		/// </summary>
		public const string RootPresentersResourcePrefix = "Vela.Im.Resources.RootPresenters.";

		/// <summary>
		/// The file name of the missing photo of a peer. This may be null or empty.
		/// </summary>
		/// <remarks>
		/// <para>Example: "pack://application:,,,/Vela.ImEmoticons;component/Emoticons/FullSized/Main/Smile.png".</para>
		/// </remarks>
		public const string MissingPeerPhotoFileName = "";

		/// <summary>
		/// The width of a thumb-sized image preview.
		/// </summary>
		public static readonly GridLength ThumbSizedImagePreviewWidth = new GridLength(
			KernelConsts.ThumbSizedImagePreviewWidth, GridUnitType.Pixel );

		/// <summary>
		/// The time (in seconds) which must have passed since the time when the last letter was received
		/// (<see cref="Vela.ImBackend.LettersModel.LastReceivedLetterTime"/>), in order to clear the time (when the last letter
		/// was received).
		/// </summary>
		public const double TimePassedFromLastReceivedLetterTimeToClearIt = 2;

		/// <summary>
		/// The command line with which the user can view the PNRP state.
		/// </summary>
		public const string ViewPnrpStateCommandLine = "netsh p2p pnrp cloud show statistics Global_";

		#endregion Public constants
	}
}
