////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using System.Windows.Media;
using Vela.ActionProcessor;
using Vela.ApplicationDocuments;

namespace Vela.Im
{
	/// <summary>
	/// Converter for a brush used to render the processing state of an action request to create an account.
	/// </summary>
	public class CreateAccountProcessingStateBrushConverter : IMultiValueConverter
	{
		#region Public methods

		/// <summary>
		/// Determines the brush which has to be used.
		/// </summary>
		/// <param name="values">The values to convert, as follows: the last processing attempt of the action request to create
		/// an account, account speckle, success brush, retry or error brush.</param>
		/// <param name="targetType">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the brush which has to be used.</returns>
		public object Convert( object[] values, Type targetType, object parameter, CultureInfo culture )
		{
			if( (values == null) || (values.Length != 4)
				|| (values[ 0 ] == null) || (values[ 1 ] == null) || (values[ 2 ] == null) || (values[ 3 ] == null)
				|| (values[ 0 ] == DependencyProperty.UnsetValue) || (values[ 1 ] == DependencyProperty.UnsetValue)
				|| (values[ 2 ] == DependencyProperty.UnsetValue) || (values[ 3 ] == DependencyProperty.UnsetValue) )
			{
				return null;
			}

			ActionLastProcessingAttempt lastProcessingAttempt = (ActionLastProcessingAttempt)values[ 0 ];
			AccountOrRequestSpeckle accountOrRequestSpeckle = (AccountOrRequestSpeckle)values[ 1 ];
			Brush successBrush = (Brush)values[ 2 ];
			Brush retryOrErrorBrush = (Brush)values[ 3 ];

			bool processingStateIsRetryOrError = (lastProcessingAttempt.ProcessingState == ActionProcessingStates.Retry)
				|| (lastProcessingAttempt.ProcessingState == ActionProcessingStates.Error);

			return processingStateIsRetryOrError ? retryOrErrorBrush : successBrush;
		}

		/// <summary>
		/// Converts back the specified value to the specified target types. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetTypes">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted values.</returns>
		public object[] ConvertBack( object value, Type[] targetTypes, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
