////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using Vela.ApplicationDocuments;

namespace Vela.Im
{
	/// <summary>
	/// Converter for the <see cref="Visibility.Collapsed"/> visibility of the full-sized emoticons of a letter.
	/// </summary>
	public class FullSizedEmoticonVisibilityConverter : IMultiValueConverter
	{
		#region Public methods

		/// <summary>
		/// Loads the image preview.
		/// </summary>
		/// <param name="values">The values to convert, as follows: a boolean which if it's true indicates that the full-sized
		/// emoticons have to be shown, letter speckle.</param>
		/// <param name="targetType">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the image preview which was loaded synchronously. This may be null.</returns>
		public object Convert( object[] values, Type targetType, object parameter, CultureInfo culture )
		{
			if( (values == null) || (values.Length != 2)
				|| (values[ 0 ] == null) || (values[ 1 ] == null)
				|| (values[ 0 ] == DependencyProperty.UnsetValue) || (values[ 1 ] == DependencyProperty.UnsetValue) )
			{
				return null;
			}

			bool showFullSizedEmoticonsInLetters = (bool)values[ 0 ];
			LetterSpeckle letterSpeckle = (LetterSpeckle)values[ 1 ];

			return (showFullSizedEmoticonsInLetters || letterSpeckle.HasImagePreview)
				? Visibility.Visible : Visibility.Collapsed;
		}

		/// <summary>
		/// Converts back the specified value to the specified target types. Not implemented.
		/// </summary>
		/// <param name="value">Value to convert.</param>
		/// <param name="targetTypes">Target types to which to convert.</param>
		/// <param name="parameter">Parameter.</param>
		/// <param name="culture">Culture.</param>
		/// <returns>Returns the converted values.</returns>
		public object[] ConvertBack( object value, Type[] targetTypes, object parameter, CultureInfo culture )
		{
			throw new NotImplementedException();
		}

		#endregion Public methods
	}
}
