////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using System.Windows.Controls;
using Vela.Controls;
using Vela.ImBackend;

namespace Vela.Im
{
	/// <summary>
	/// View for working with accounts.
	/// </summary>
	[FunctionViewRegistrationAttribute( "400" )]
	public partial class AccountsUserControl : AppViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected AccountsUserControl()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public AccountsUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Public static properties

		/// <summary>
		/// Title.
		/// </summary>
		public static string Title
		{
			get { return "Accounts"; }
		}

		/// <summary>
		/// Tooltip.
		/// </summary>
		public static string Tooltip
		{
			get { return "An account stores information about a contact of yours, in relation to one of your vaults"; }
		}

		#endregion Public static properties

		#region Event handlers

		private void Tooltip_Opening( object sender, ToolTipEventArgs e )
		{
			ControlsUtils.UpdateBindingTargets( ((FrameworkElement)sender).ToolTip as FrameworkElement );
		}

		private void SetAccountModelButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.SetAccountModel();

			// Navigate to the "Letters" view.
			ApplicationModel.ViewsModel.Navigate( typeof( LettersUserControl ) );
		}

		private void EditAccountButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.EditAccount();
		}

		private void DeleteAccountButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.DeleteAccount();
		}

		private void AccountsListBox_PreviewMouseDoubleClick( object sender, System.Windows.Input.MouseButtonEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.EditAccount();
		}

		private void SetAccountModelMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.SetAccountModel();

			// Navigate to the "Letters" view.
			ApplicationModel.ViewsModel.Navigate( typeof( LettersUserControl ) );
		}

		private void EditAccountMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.EditAccount();
		}

		private void DeleteAccountMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.DeleteAccount();
		}

		private void QueuePullUpdatePresenterMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.QueuePullUpdatePresenter();
		}

		private void VerifyAttestingDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.VerifyAttestingDocument();
		}

		private void CreateSecuringDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.CreateSecuringDocument();
		}

		private void UnpackSecuringDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AccountsModel.UnpackSecuringDocument();
		}

		#endregion Event handlers

		#region Public methods

		/// <summary>
		/// Method called when the application loads the control into view.
		/// </summary>
		public override void EnteringUi()
		{
			base.EnteringUi();

			IsEnabled = (ApplicationModel != null) && ApplicationModel.StorehouseExists;
		}

		#endregion Public methods
	}
}
