////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using Vela.ApplicationBackend;
using Vela.Controls;
using Vela.ImBackend;
using Vela.Kernel;

namespace Vela.Im
{
	/// <summary>
	/// View with application functions.
	/// </summary>
	[FunctionViewRegistrationAttribute( "100" )]
	public partial class ApplicationUserControl : AppViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ApplicationUserControl()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public ApplicationUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Public static properties

		/// <summary>
		/// Title.
		/// </summary>
		public static string Title
		{
			get { return "Application"; }
		}

		/// <summary>
		/// Tooltip.
		/// </summary>
		public static string Tooltip
		{
			get { return "Application functions"; }
		}

		#endregion Public static properties

		#region Event handlers

		private void CloseButton_Click( object sender, RoutedEventArgs e )
		{
			App.CloseMode = ApplicationCloseModes.UserPermission;
			ControlsUtils.CloseApplication();
		}

		private void QuickHelpButton_Click( object sender, RoutedEventArgs e )
		{
			QuickHelpWindow.ShowDialogInstance();
		}

		private void AboutButton_Click( object sender, RoutedEventArgs e )
		{
			AboutWindow window = new AboutWindow( null );

			ControlsUtils.ShowDialog( window );
		}

		private void EditConfigurationButton_Click( object sender, RoutedEventArgs e )
		{
			ImUtils.EditApplicationConfiguration( ApplicationModel );
		}

		private void ConfigureFirewallButton_Click( object sender, RoutedEventArgs e )
		{
			ImUtils.ConfigureFirewall();
		}

		private void ViewPnrpStateButton_Click( object sender, RoutedEventArgs e )
		{
			FileUtils.RunCommandLine( ImConsts.ViewPnrpStateCommandLine, true );
		}

		private void ExploreConfigurationFolderButton_Click( object sender, RoutedEventArgs e )
		{
			FileUtils.ExploreFile( AssemblyUtils.GetApplicationDataFolderName() );
		}

		private void ExploreTemporaryFolderButton_Click( object sender, RoutedEventArgs e )
		{
			FileUtils.ExploreFile( AssemblyUtils.GetApplicationTempFolderName( null ) );
		}

		private void OpenErrorLogButton_Click( object sender, RoutedEventArgs e )
		{
			FileUtils.RunFile( LogManager.CurrentLogFileName );
		}

		private void ViewCommandLinesOutputButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.AppViewWindowsManager.ShowCommandLinesOutput();
		}

		private void VerifyAttestingDocumentButton_Click( object sender, RoutedEventArgs e )
		{
			ImBackendStorehouse.VerifyAttestingDocument( null, true, null, ImConsts.RootPresentersResourcePrefix, false, null );
		}

		#endregion Event handlers
	}
}
