////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using System.Windows.Input;
using Vela.ImBackend;

namespace Vela.Im
{
	/// <summary>
	/// View for working with log records.
	/// </summary>
	[FunctionViewRegistrationAttribute( "600" )]
	public partial class LogRecordsUserControl : AppViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected LogRecordsUserControl()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public LogRecordsUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Public static properties

		/// <summary>
		/// Title.
		/// </summary>
		public static string Title
		{
			get { return "Log"; }
		}

		/// <summary>
		/// Tooltip.
		/// </summary>
		public static string Tooltip
		{
			get { return "Shows messages about the flow of the application"; }
		}

		#endregion Public static properties

		#region Event handlers

		private void TraceMessagesListBox_PreviewMouseDoubleClick( object sender, MouseButtonEventArgs e )
		{
			ApplicationModel.LogRecordsModel.ViewLogRecordInWindow();
		}

		private void ViewLogRecordInWindowMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.LogRecordsModel.ViewLogRecordInWindow();
		}

		private void ClearLogRecordsMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.LogRecordsModel.ClearLogRecords();
		}

		#endregion Event handlers
	}
}
