////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using Vela.ImBackend;

namespace Vela.Im
{
	/// <summary>
	/// View for working with storehouses.
	/// </summary>
	[FunctionViewRegistrationAttribute( "200" )]
	public partial class StorehouseUserControl : AppViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected StorehouseUserControl()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public StorehouseUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Public static properties

		/// <summary>
		/// Title.
		/// </summary>
		public static string Title
		{
			get { return "Storehouse"; }
		}

		/// <summary>
		/// Tooltip.
		/// </summary>
		public static string Tooltip
		{
			get { return "A storehouse stores all your vaults, accounts, letters and so on"; }
		}

		#endregion Public static properties

		#region Event handlers

		private void CreateStorehouseButton_Click( object sender, RoutedEventArgs e )
		{
			ImUtils.CreateStorehouse( ApplicationModel );
		}

		private void OpenStorehouseButton_Click( object sender, RoutedEventArgs e )
		{
			ImUtils.OpenStorehouse( ApplicationModel, true, null );
		}

		private void EditConfigurationButton_Click( object sender, RoutedEventArgs e )
		{
			ImUtils.EditStorehouseConfiguration( ApplicationModel );
		}

		private void ChangePasswordButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.ChangePassword();
		}

		private void AddEntropyButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.AddEntropy();
		}

		private void VerifyAttestingDocumentButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VerifyAttestingDocument();
		}

		private void UnpackSecuringDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.UnpackSecuringDocument();
		}

		private void ClipStorehouseAttachmentsPasswordButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.ClipStorehouseAttachmentsPassword();
		}

		#endregion Event handlers
	}
}
