////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Windows;
using Vela.ImBackend;
using Vela.Kernel;

namespace Vela.Im
{
	/// <summary>
	/// View for working with vaults.
	/// </summary>
	[FunctionViewRegistrationAttribute( "300" )]
	public partial class VaultsUserControl : AppViewUserControl
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected VaultsUserControl()
		{
			InitializeComponent();

			LoadUi();
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="applicationModel">Application model.</param>
		public VaultsUserControl( ApplicationModel applicationModel )
			: base( applicationModel )
		{
			InitializeComponent();

			LoadUi();
		}

		#endregion Constructors

		#region Public static properties

		/// <summary>
		/// Title.
		/// </summary>
		public static string Title
		{
			get { return "Vaults"; }
		}

		/// <summary>
		/// Tooltip.
		/// </summary>
		public static string Tooltip
		{
			get { return "A vault stores your private peer information"; }
		}

		#endregion Public static properties

		#region Event handlers

		private void AddVaultButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.AddVault( AlgorithmSecurityLevel.Normal );
		}

		private void EditVaultButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.EditVault();
		}

		private void DeleteVaultButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.DeleteVault();
		}

		private void QueueCreateAccountButton_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.QueueCreateAccountWithUpn();
		}

		private void VaultsListBox_PreviewMouseDoubleClick( object sender, System.Windows.Input.MouseButtonEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.EditVault();
		}

		private void AddNormalAlgsVaultMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.AddVault( AlgorithmSecurityLevel.Normal );
		}

		private void AddStrongAlgsVaultMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.AddVault( AlgorithmSecurityLevel.Strong );
		}

		private void AddStrongestAlgsVaultMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.AddVault( AlgorithmSecurityLevel.Strongest );
		}

		private void EditVaultMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.EditVault();
		}

		private void DeleteVaultMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.DeleteVault();
		}

		private void ExportPresenterMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.ExportPresenter();
		}

		private void QueueCreateAccountWithUpnMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.QueueCreateAccountWithUpn();
		}

		private void AddAccountWithFileMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.AddAccountWithFile();
		}

		private void CreateAttestingDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.CreateAttestingDocument();
		}

		private void VerifyAttestingDocumentMenuItem_Click( object sender, RoutedEventArgs e )
		{
			ApplicationModel.StorehouseModel.VaultsModel.VerifyAttestingDocument();
		}

		#endregion Event handlers

		#region Public methods

		/// <summary>
		/// Method called when the application loads the control into view.
		/// </summary>
		public override void EnteringUi()
		{
			base.EnteringUi();

			IsEnabled = (ApplicationModel != null) && ApplicationModel.StorehouseExists;
		}

		#endregion Public methods
	}
}
