////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Windows.Threading;
using Vela.Kernel;
using Vela.CoreDocuments;
using Vela.ActionProcessor;

namespace Vela.PaymentServiceOps
{
	/// <summary>
	/// Action client host.
	/// </summary>
	public class ActionClientHost : ActionProcessorHost, IActionClientHost
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionClientHost()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="mainWindow">The application's main window.</param>
		public ActionClientHost( MainWindow mainWindow )
			: base( mainWindow )
		{
		}

		#endregion Constructors

		#region Private methods

		/// <summary>
		/// Updates the UI while an action request is being processed by an action client, and the service vault is revoked.
		/// </summary>
		/// <param name="serviceUpn">The UPN of the revoked service vault.</param>
		public void UpdateUiRevokedServiceVault( Upn serviceUpn )
		{
			//?
		}

		/// <summary>
		/// Updates the UI while an action request is being processed by an action client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action client application after an
		/// action request and response are processed.</param>
		/// <remarks>
		/// <para>This is already running on the dispatcher of the application model.</para>
		/// </remarks>
		private void UpdateUiOnUiThread( ActionClientHostUpdateUiContext updateUiContext )
		{
			try
			{
				ValidationUtils.ObjectHasContent( updateUiContext, "updateUiContext" );

				// Nothing to do.

				// Only log other action request types.
				LogManager.DebugAddFormat( "The type \"{0}\" of the action request with the locator \"{1}\" was not"
						+ " processed by the action client host."
					, updateUiContext.ActionProgress.ReferredActionRequestTypeName
					, updateUiContext.ActionProgress.ReferredActionRequestLocator );
			}
			catch( Exception ex )
			{
				throw new BackgroundOperationException( ex );
			}
		}

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Updates the UI while an action request is being processed by an action client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action client application after an
		/// action request and response are processed.</param>
		public void UpdateUi( ActionClientHostUpdateUiContext updateUiContext )
		{
			// Process on the UI thread.
			MainWindow.Dispatcher.Invoke( new Action( delegate { UpdateUiOnUiThread( updateUiContext ); } )
				, DispatcherPriority.Background );
		}

		#endregion Public methods
	}
}
