////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Windows.Threading;
using Vela.Kernel;
using Vela.ActionProcessor;

namespace Vela.PaymentServiceOps
{
	/// <summary>
	/// Action service host.
	/// </summary>
	public class ActionServiceHost : ActionProcessorHost, IActionServiceHost
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		protected ActionServiceHost()
		{
		}

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		/// <param name="mainWindow">The application's main window.</param>
		public ActionServiceHost( MainWindow mainWindow )
			: base( mainWindow )
		{
		}

		#endregion Constructors

		#region Private methods

		/// <summary>
		/// Updates the UI after an action request was successfully processed by an action service, and a response was sent to
		/// the client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action service application after an
		/// action request and response are processed.</param>
		/// <remarks>
		/// <para>This is already running on the dispatcher of the application model.</para>
		/// </remarks>
		private void UpdateUiOnUiThread( ActionServiceHostUpdateUiContext updateUiContext )
		{
			try
			{
				ValidationUtils.ObjectHasContent( updateUiContext, "updateUiContext" );

				// Nothing to do.

				// Only log other action request types.
				LogManager.DebugAddFormat( "The type \"{0}\" of the action request with the locator \"{1}\" was not"
						+ " processed by the action service host."
					, updateUiContext.ActionRequest.GetType().FullName, updateUiContext.ActionRequest.InstanceLocator );
			}
			catch( Exception ex )
			{
				throw new BackgroundOperationException( ex );
			}
		}

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Updates the UI after an action request was successfully processed by an action service, and a response was sent to
		/// the client.
		/// </summary>
		/// <param name="updateUiContext">Host context for updating the user interface of an action service application after an
		/// action request and response are processed.</param>
		public void UpdateUi( ActionServiceHostUpdateUiContext updateUiContext )
		{
			// Process on the UI thread.
			MainWindow.Dispatcher.Invoke( new Action( delegate { UpdateUiOnUiThread( updateUiContext ); } )
				, DispatcherPriority.Background );
		}

		#endregion Public methods
	}
}
