////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.ApplicationBackend;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Contract for an application test.
	/// </summary>
	/// <remarks>
	/// <para>All tests are instantiated when the application starts. Therefore, you must ensure that each test can be run
	/// multiple times with the same instance, in an identical manner. Take particular care at the initialization of the global
	/// fields.</para>
	/// </remarks>
	public abstract class AppTest : Test
	{
		#region Private fields

		/// <summary>
		/// The application test context.
		/// </summary>
		protected AppTestContext Context;

		/// <summary>
		/// Algorithm pool.
		/// </summary>
		protected AlgorithmPool AlgorithmPool
		{
			get { return AlgorithmPool.Instance; }
		}

		/// <summary>
		/// Application configuration.
		/// </summary>
		protected AppConfiguration Configuration
		{
			get { return Context.Configuration; }
		}

		#endregion Private fields

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected abstract void Execute();

		#endregion Private methods

		#region Public methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		/// <param name="context">The test context.</param>
		public override void Execute( TestContext context )
		{
			ValidationUtils.ObjectHasContent( context, "context" );

			Context = (AppTestContext)context;

			Context.LogStart( Name );

			Execute();

			Context.LogEnd();
		}

		#endregion Public methods
	}
}
