////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto;
using Vela.Crypto.Asymmetric;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class AsymmRsaSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Asymmetric RSA speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0018 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			const int publicExponent = 65537;

			const int iterPrivate = 50;
			const int iterPublic = 2000;

			Context.LogSubtest( "Generate asymmetric RSA-2048 key" );

			RsaAlg rsaAlg = new Rsa2048();
			rsaAlg.GenerateKeyPair( publicExponent, Context.LongOperationProgress );

			Context.LogSpeed( SpeedModes.Sec, null );
			Context.LogSubtestSeparator();

			byte[] buffer = EntropyPool.GetBytes( rsaAlg.MaxProcessableSizeBytes );
			string dataText = TextUtils.ArrayToText16( buffer );

			Context.LogSubtest( "Process with private key" );

			// Process the data with the private key.
			for( int i = 0; i < iterPrivate; i++ )
				rsaAlg.ProcessWithPrivateKey( buffer, true );

			Context.LogSpeed( SpeedModes.Msec_Oper, iterPrivate );
			Context.LogSubtestSeparator();

			Context.LogSubtest( "Process with public key" );

			// Process the data with the public key.
			for( int i = 0; i < iterPublic; i++ )
				rsaAlg.ProcessWithPublicKey( buffer, false );

			Context.LogSpeed( SpeedModes.Msec_Oper, iterPublic );
		}

		#endregion Private methods
	}
}
