////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Cloning;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class CloningSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Cloning speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0013 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		private void ClonerSpeed()
		{
			IDeserializer deserializer;

			#region Data

			// Load the document which is to be cloned.
			Presenter presenter = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName, typeof( Presenter )
				, out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenter, "presenter" );

			#endregion Data

			Presenter clonedPresenter = null;

			const int iter = 1000;

			for( int i = 0; i < iter; i++ )
				clonedPresenter = Cloner.Deep<Presenter>( presenter );

			Context.LogSpeed( SpeedModes.Msec_Oper, iter );
		}

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			ClonerSpeed();
		}

		#endregion Private methods
	}
}
