////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class EntropyCollisionTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Entropy collision"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0001 0001 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			const int bufferSize = 4;

			Buffers buffers = new Buffers();
			int collisions = 0;

			int iter = 0;

			Chronometer chrono = new Chronometer();
			chrono.Start();
			while( !chrono.PassedSeconds( 1 ) )
			{
				// Get random data.
				byte[] buffer = EntropyPool.GetBytes( bufferSize );

				if( buffers.ContainsKey( buffer ) )
				{
					collisions++;
				}
				else
				{
					buffers.Add( buffer );
				}

				iter++;
			}

			Context.Log( string.Format( "Buffer size {0}, iterations {1}, collisions {2}.", bufferSize, iter, collisions ) );
		}

		#endregion Private methods
	}
}
