////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.CoreDocuments;
using Vela.Crypto.Asymmetric;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class GenerateIdentitySpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Generate identity speed *"; }
		}

		/// <summary>
		/// This is true, meaning that the test is long.
		/// </summary>
		public override bool IsLong
		{
			get { return true; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "9000 0002 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			for( int i = 0; i < AppTestContext.IdentitySpeedCount; i++ )
			{
				Context.LongOperationProgress.PersistentMessage = string.Format( "Identities {0} / {1}", i
					, AppTestContext.IdentitySpeedCount );
				Context.LongOperationProgress.Progress();

				AsymmAlg aea = AlgorithmPool.GenerateAsymmAlg( AlgorithmSecurityLevel.Normal, Context.LongOperationProgress );
				AsymmAlg asa = AlgorithmPool.GenerateAsymmAlg( AlgorithmSecurityLevel.Normal, Context.LongOperationProgress );
				UpnAlg upnAlg = AlgorithmPool.GetUpnAlg( AlgorithmSecurityLevel.Normal );
				UInt16 processingPort = Configuration.ActionServiceListenerTemplate.ProcessingPort;

				PrivateIdentity pi = new PrivateIdentity( upnAlg, processingPort, aea, asa );
			}

			Context.LogSpeed( SpeedModes.Sec_Oper, AppTestContext.IdentitySpeedCount );
		}

		#endregion Private methods
	}
}
