////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Vela.CoreDocuments;
using Vela.Crypto;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class GenerateStampTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Generate stamp"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0012 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			byte[] linkedData = EntropyPool.GetBytes( 16 );
			int stampCost = 20;

			Context.Log( string.Format( "Stamp cost {0}", stampCost ) );

			// Load the public identity who is the generator of the stamp.
			IDeserializer deserializer;
			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );

			Stamp stamp = new StampWithRecipient( CryptoUtils.GetLocator(), AlgorithmPool.GetHashAlg()
				, AlgorithmPool.GetHashSerializer( false ), DateTime.MaxValue, stampCost
				, presenterAlice.ProcessingIdentity.Upn.Fingerprint, CryptoUtils.GetLocator() );

			Context.LogProcessing();

			int iter = stamp.Generate( Context.LongOperationProgress );

			Context.Log( string.Format( "Iterations {0}", iter ), true );

			Context.LogSpeed( SpeedModes.Oper_Sec, iter );
		}

		#endregion Private methods
	}
}
