////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class LoadSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Load speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0016 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer deserializer;

			const int iter = 500;

			for( int i = 0; i < iter; i++ )
			{
				SymmEncryptedEnvelope see = SymmEncryptedEnvelope.LoadFromFile( Context.VaultAliceFileName
					, AppTestContext.DocumentPassword, typeof( Vault ), out deserializer );
				ValidationUtils.ObjectHasContent( see, "see" );
			}

			Context.LogSpeed( SpeedModes.Oper_Sec, iter );
		}

		#endregion Private methods
	}
}
