////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Crypto;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class PasswordBlenderSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Password blender speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0019 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			const int entropySize = 20;

			byte[] salt = EntropyPool.GetBytes( entropySize );
			string userPassword = EntropyPool.GetText32( entropySize ).ToLowerInvariant();

			PasswordBlenderAlg blenderAlg = AlgorithmPool.GetPasswordBlender();

			int iter = 0;

			Chronometer chrono = new Chronometer();
			chrono.Start();
			while( !chrono.PassedSeconds( 1 ) )
			{
				blenderAlg.GenerateBlendedPassword( salt, userPassword, true );

				iter++;
			}

			Context.LogSpeed( SpeedModes.Oper_Sec, iter );
		}

		#endregion Private methods
	}
}
