////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Crypto;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class SaveLoadSymmEnvelopeTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Save and load symmetric envelope"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0002 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			string letterMessage = EntropyPool.GetText16( 1000 );

			Letter letter = new Letter( CryptoUtils.GetLocator(), AlgorithmPool.GetMacAlg()
				, AlgorithmPool.GetAsymmSigningPadding(), AlgorithmPool.GetHashSerializer( false ), CryptoUtils.GetLocator()
				, letterMessage, null, false, CryptoUtils.GetLocator(), new AttachedFiles(), false, false );

			// Save.
			ISerializer serializer = AlgorithmPool.GetSerializerForExport();
			SymmEncryptedEnvelope seeLetter = AlgorithmPool.GetSymmEncryptedEnvelope();
			seeLetter.EncryptableDocument = letter;
			seeLetter.SaveToFile( Context.SaveLoadSymmEnvelopeFileName, null, AppTestContext.DocumentPassword, serializer );

			// Load.
			IDeserializer deserializer;
			SymmEncryptedEnvelope seeLetterLoaded = SymmEncryptedEnvelope.LoadFromFile(
				Context.SaveLoadSymmEnvelopeFileName, AppTestContext.DocumentPassword, typeof( Letter ), out deserializer );
			ValidationUtils.ObjectHasContent( seeLetterLoaded, "seeLetterLoaded" );
			Letter letterLoaded = (Letter)seeLetterLoaded.EncryptableDocument;

			if( !letter.InstanceLocator.Equals( letterLoaded.InstanceLocator ) )
			{
				throw new ValidationException( string.Format( "The loaded letter has the locator \"{0}\" instead of \"{1}\"."
					, letter.InstanceLocator, letterLoaded.InstanceLocator ) );
			}
		}

		#endregion Private methods
	}
}
