////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class SignSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Sign speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0015 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer deserializer;

			SymmEncryptedEnvelope seeIdDaniel = SymmEncryptedEnvelope.LoadFromFile( Context.VaultDanielFileName
				, AppTestContext.DocumentPassword, typeof( Vault ), out deserializer );
			ValidationUtils.ObjectHasContent( seeIdDaniel, "seeIdDaniel" );
			Vault vaultDaniel = (Vault)seeIdDaniel.EncryptableDocument;

			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );

			IHashSerializer hashSerializer = deserializer.GetHashSerializer( false );

			const int iter = 100;

			Context.LogProcessing();

			// Raw signing ("AsymmAlg.SigningAca.ProcessWithPrivateKey"), compared to document signing, shows virtually no
			// improvement in performance. That's how slow asymmetric cryptography is compared to the serialization of the
			// document.
			for( int i = 0; i < iter; i++ ) presenterAlice.Sign( vaultDaniel.ProcessingIdentity, null );

			Context.LogSpeed( SpeedModes.Msec_Oper, iter );
		}

		#endregion Private methods
	}
}
