////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto;
using Vela.Crypto.Hash;
using Vela.Crypto.Symmetric;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class SymmetricSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Symmetric speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0017 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		private void Sha512Speed()
		{
			Context.LogSubtest( "Sha512 speed" );

			int iter = 100;
			int size = 1000000;

			HashAlg hashAlg = new Sha512();
			byte[] input = EntropyPool.GetBytes( size );

			Context.LogProcessing();

			for( int i = 0; i < iter; i++ )
				hashAlg.Compute( input );

			Context.LogSpeed( SpeedModes.MB_Sec, iter * size );
			Context.LogSubtestSeparator();
		}

		private void Rijndael256Speed()
		{
			Context.LogSubtest( "Rijndael256 speed" );

			int iter = 50;
			int size = 1000000;

			Rijndael256 rijndael = new Rijndael256( SymmPaddings.Iso10126, SymmChainings.Cbc );

			byte[] salt = EntropyPool.GetBytes( rijndael.AlgSizeBytes );
			byte[] key = EntropyPool.GetBytes( rijndael.AlgSizeBytes );

			byte[] buffer = EntropyPool.GetBytes( size );

			Context.LogProcessing();

			for( int i = 0; i < iter; i++ )
				rijndael.Encrypt( buffer, salt, key );

			Context.LogSpeed( SpeedModes.MB_Sec, iter * size );
			Context.LogSubtestSeparator();
		}

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			Sha512Speed();

			Rijndael256Speed();
		}

		#endregion Private methods
	}
}
