////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.PaymentDocuments;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifyActionRequestTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify action request"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0011 0000 01"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer deserializer;

			// Load the service vault.
			SymmEncryptedEnvelope seeServiceVault = SymmEncryptedEnvelope.LoadFromFile( Context.PaymentVaultFileName
				, AppTestContext.DocumentPassword, typeof( PaymentVault ), out deserializer );
			ValidationUtils.ObjectHasContent( seeServiceVault, "seeServiceVault" );
			PaymentVault vault = (PaymentVault)seeServiceVault.EncryptableDocument;

			// Load the public identity of the issuer of the action request.
			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );

			#region Load the action request

			IDeserializer encrEnvDeserializer;
			AsymmDecryptionPassword adp = new AsymmDecryptionPassword(
				vault.ProcessingIdentity );

			AsymmEncryptedEnvelope ase = AsymmEncryptedEnvelope.LoadFromFile( Context.ActionRequestFileName, adp
				, typeof( MakePaymentActionRequest ), out encrEnvDeserializer );
			ValidationUtils.ObjectHasContent( ase, "ase" );

			MakePaymentActionRequest actionRequest = ase.EncryptableDocument as MakePaymentActionRequest;

			if( actionRequest == null ) throw new ValidationException( "There is no action request to verify." );

			#endregion Load the action request

			// Check if the signature of the action request is valid, using the identity publisher of its issuer.
			actionRequest.VerifySignature( presenterAlice.ProcessingIdentity );

			// The action request is valid.
		}

		#endregion Private methods
	}
}
