////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.IO;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;
using Vela.StarkDocuments;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifyAttestingDocumentTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify attesting document"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0008 0000 01"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer deserializer;

			// Load the public identity of the issuer of the document.
			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );

			// Load the attesting document.
			AttestingDocument attestingDocument = SerializationUtils.LoadFromFile( Context.AttestingDocumentFileName
				, typeof( AttestingDocument ), out deserializer ) as AttestingDocument;
			ValidationUtils.ObjectHasContent( attestingDocument, "attestingDocument" );

			// Check if the signature of the document is valid, using the identity publisher of its issuer.
			attestingDocument.VerifySignature( presenterAlice.ProcessingIdentity );

			#region Verify the attested document

			using( FileStream fs = File.OpenRead( Context.DocumentToAttestFileName ) )
			{
				byte[] hashValue = attestingDocument.Process( fs, null );

				if( !BufferUtils.Equals( hashValue, attestingDocument.AttestedMacValue ) )
					throw new ValidationException( "The hash from the attesting document is different from the computed one." );
			}

			#endregion Verify the attested document
		}

		#endregion Private methods
	}
}
