////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.CoreDocuments;
using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifyIdentitiesSignatureTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify identities signatures"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0005 0000 01"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer presenterDanielDeser;
			Presenter presenterDaniel = SerializationUtils.LoadFromFile( Context.PresenterDanielFileName
				, typeof( Presenter ), out presenterDanielDeser ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterDaniel, "presenterDaniel" );
			presenterDaniel.VerifySignature( presenterDaniel.ProcessingIdentity );

			IDeserializer presenterClaudiaDeser;
			Presenter presenterClaudia = SerializationUtils.LoadFromFile( Context.PresenterClaudiaFileName
				, typeof( Presenter ), out presenterClaudiaDeser ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterClaudia, "presenterClaudia" );
			presenterClaudia.VerifySignature( presenterClaudia.ProcessingIdentity );

			IDeserializer presenterBobDeser;
			Presenter presenterBob = SerializationUtils.LoadFromFile( Context.PresenterBobFileName
				, typeof( Presenter ), out presenterBobDeser ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterBob, "presenterBob" );
			presenterBob.VerifySignature( presenterBob.ProcessingIdentity );

			IDeserializer presenterAliceDeser;
			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out presenterAliceDeser ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );
			presenterAlice.VerifySignature( presenterAlice.ProcessingIdentity );
			presenterAlice.VerifySignature( presenterDaniel.ProcessingIdentity );

			IDeserializer groupIdentityPublisherDeser;
			GroupIdentityPublisher groupIdentityPublisher = SerializationUtils.LoadFromFile(
					Context.GroupIdentityPublisherFileName, typeof( GroupIdentityPublisher ), out groupIdentityPublisherDeser )
				as GroupIdentityPublisher;
			ValidationUtils.ObjectHasContent( groupIdentityPublisher, "groupIdentityPublisher" );
		}

		#endregion Private methods
	}
}
