////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Crypto;
using Vela.Kernel;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifyRadix32Test : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify radix-32 conversion"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0003 0000 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			#region Buffer to text

			byte[] buffer = EntropyPool.GetBytes( 32 );
			string text32 = TextUtils.ArrayToText32( buffer );
			byte[] buffer2 = TextUtils.Text32ToArray( text32 );

			Context.Log( string.Format( "Data = {0}", TextUtils.ArrayToText16( buffer ) ), true );
			Context.Log( string.Format( "Text = {0}", text32 ), true );
			Context.Log( string.Format( "Data = {0}", TextUtils.ArrayToText16( buffer2 ) ), true );

			if( !BufferUtils.Equals( buffer, buffer2 ) )
				throw new ValidationException( "Buffer re-conversion (through radix-32 text) has failed." );

			#endregion Buffer to text

			#region Text to buffer

			text32 = "j7";
			buffer = TextUtils.Text32ToArray( text32 );
			string text2 = TextUtils.ArrayToText32( buffer );

			Context.Log( string.Format( "Text = {0}", text32 ), true );
			Context.Log( string.Format( "Data = {0}", TextUtils.ArrayToText16( buffer ) ), true );
			Context.Log( string.Format( "Text = {0}", text2 ), true );

			if( !TextUtils.Equals( text32, text2 ) )
				throw new ValidationException( "Radix-32 text re-conversion (through buffer) has failed." );

			#endregion Text to buffer

			Context.LogSubtestSeparator();

			#region Text to buffer

			text32 = "j170";
			buffer = TextUtils.Text32ToArray( text32 );
			text2 = TextUtils.ArrayToText32( buffer );

			Context.Log( string.Format( "Text = {0}", text32 ), true );
			Context.Log( string.Format( "Data = {0}", TextUtils.ArrayToText16( buffer ) ), true );
			Context.Log( string.Format( "Text = {0}", text2 ), true );

			if( !TextUtils.Equals( text32, text2 ) )
				throw new ValidationException( "Radix-32 text re-conversion (through buffer) has failed." );

			#endregion Text to buffer
		}

		#endregion Private methods
	}
}
