////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel.Serialization;
using Vela.Serialization;
using Vela.StarkDocuments;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifySerializationTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify serialization"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0014 0001 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		private void SerializeList()
		{
			#region Data

			// Create the list.
			ShortCommands list = ShortCommands.GetInitializedInstance();

			#endregion Data

			Context.LogSubtest( "Serialize-deserialize list" );

			#region Binary

			ISerializer serializer = AlgorithmPool.GetBinarySerializer();
			IDeserializer deserializer = serializer.GetDeserializer();

			byte[] serializedData = serializer.SaveToBuffer( list, null );
			IDocument deserializedDoc = deserializer.LoadFromBuffer( serializedData, null );

			#endregion Binary

			#region XML

			serializer = AlgorithmPool.GetXmlSerializer();
			deserializer = serializer.GetDeserializer();

			serializedData = serializer.SaveToBuffer( list, null );
			deserializedDoc = deserializer.LoadFromBuffer( serializedData, null );

			#endregion XML

			Context.LogSubtestEnd();
		}

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			SerializeList();
		}

		#endregion Private methods
	}
}
