////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using Vela.Kernel;
using Vela.PeerDocuments;
using Vela.Serialization;

namespace Vela.TesterBackend
{
	/// <summary>
	/// Test.
	/// </summary>
	public class VerifySignatureSpeedTest : AppTest
	{
		#region Public non-serializable properties

		/// <summary>
		/// The name of the test.
		/// </summary>
		public override string Name
		{
			get { return "Verify signature speed"; }
		}

		/// <summary>
		/// The prefix for the sort order in which to run the test.
		/// </summary>
		public override string SortPrefix
		{
			get { return "0015 0001 00"; }
		}

		#endregion Public non-serializable properties

		#region Private methods

		/// <summary>
		/// Executes the test.
		/// </summary>
		protected override void Execute()
		{
			IDeserializer deserializer;

			Presenter presenterDaniel = SerializationUtils.LoadFromFile( Context.PresenterDanielFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterDaniel, "presenterDaniel" );

			Presenter presenterAlice = SerializationUtils.LoadFromFile( Context.PresenterAliceFileName
				, typeof( Presenter ), out deserializer ) as Presenter;
			ValidationUtils.ObjectHasContent( presenterAlice, "presenterAlice" );

			// Read the document in a text in order to load it from there at every cycle of the test.
			byte[] documentData = FileUtils.Read( Context.PresenterAliceFileName, true );

			const int iter = 500;

			Context.LogProcessing();

			for( int i = 0; i < iter; i++ )
			{
				// Deserialize the document whose signature is to be verified.
				Presenter presenter = SerializationUtils.LoadFromBuffer( documentData, typeof( Presenter )
					, out deserializer ) as Presenter;
				ValidationUtils.ObjectHasContent( presenter, "presenter" );

				presenter.VerifySignature( presenterDaniel.ProcessingIdentity );
			}

			Context.LogSpeed( SpeedModes.Msec_Oper, iter );
		}

		#endregion Private methods
	}
}
