﻿////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System;
using System.Windows;
using System.Windows.Threading;
using Vela.Controls;
using Vela.Kernel;

namespace Vela.ThemeTester
{
	/// <summary>
	/// Application entry point.
	/// </summary>
	public partial class App : Application
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public App()
		{
			// Adding this event from XAML (instead of code) cause it to be raised twice consecutively.
			DispatcherUnhandledException += Application_DispatcherUnhandledException;

			InitializeComponent();
		}

		#endregion Constructors

		#region Event handlers

		private void Application_DispatcherUnhandledException( object sender, DispatcherUnhandledExceptionEventArgs e )
		{
			if( ExceptionUtils.IsCritical( e.Exception ) )
			{
				// Log even critical exceptions.
				LogManager.Add( e.Exception );

				Application.Current.Shutdown( -1 );

				return;
			}

			ControlsUtils.ShowException( e.Exception );

			// Don't let the exception propagate.
			e.Handled = true;
		}

		#endregion Event handlers

		#region Private methods

		/// <summary>
		/// Sets the regional configuration for bindings.
		/// </summary>
		/// <param name="e">Event data.</param>
		protected override void OnStartup( StartupEventArgs e )
		{
			ControlsUtils.SetApplicationGlobalUiSettings();

			base.OnStartup( e );
		}

		#endregion Private methods

		#region Public static methods

		/// <summary>
		/// Application entry point.
		/// </summary>
		[System.STAThreadAttribute()]
		public static void Main()
		{
			App appInstance = null;

			try
			{
				AssemblyUtils.ApplicationBuildInfo = new AppBuildInfo();

				appInstance = new App();
				appInstance.InitializeComponent();

				ControlsUtils.SetApplicationInstanceGlobalSettings( appInstance );

				appInstance.Run();
			}
			catch( Exception ex )
			{
				// Log even critical exceptions.
				LogManager.Add( ex );

				if( ExceptionUtils.IsCritical( ex ) ) throw ExceptionUtils.PreserveStackTrace( ex );

				MessageWindow.ShowDialog( ex.Message, MessageWindowModes.Error );

				if( appInstance != null ) appInstance.Shutdown( -1 );
			}
		}

		#endregion Public static methods
	}
}
