﻿////////////////////////////////////////////////////////////////////////////////
//
// Developed by the Vela Entity (vela.im).
// Released under a "Common Sense License".
//
// Original author: Gardener of Thoughts (gardenerofthoughts.org).
//
////////////////////////////////////////////////////////////////////////////////

using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Vela.Controls;

namespace Vela.ThemeTester
{
	/// <summary>
	/// A window which allows to test the current theme.
	/// </summary>
	public partial class MainWindow : Window
	{
		private const string LongText = "List item which is very long in order to test the text wrapping feature";

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the current class.
		/// </summary>
		public MainWindow()
		{
			for( int i = 0; i < 10; i++ ) Persons.Add( new Person( (i + 1000).ToString(), "Doe" + i, "John" + i ) );
			for( int i = 10; i < 15; i++ ) Persons.Add( new Person( (i + 1000).ToString() + LongText, "Doe" + i, "John" + i ) );

			DataContext = this;

			InitializeComponent();
		}

		#endregion Constructors

		#region Public non-serializable properties

		private ObservableCollection<Person> _Persons = new ObservableCollection<Person>();
		public ObservableCollection<Person> Persons
		{
			get { return _Persons; }
			set { _Persons = value; }
		}

		#endregion Public non-serializable properties

		private void VectorImagesMenuItem_Click( object sender, RoutedEventArgs e )
		{
			Window window = new VectorImagesWindow();
			ControlsUtils.ShowDialog( window );
		}

		private void GotDmgMenuItem_Click( object sender, RoutedEventArgs e )
		{
			Window window = new GotDmgWindow();
			ControlsUtils.ShowDialog( window );
		}

		private void TooltipMenuItem_Click( object sender, RoutedEventArgs e )
		{
			TooltipWindow.ShowTooltip();
		}

		private void Button_Click( object sender, RoutedEventArgs e )
		{
			Window window = new GotDmgWindow();
			window.Owner = this;
			window.ShowDialog();
		}

		private void ListView_SizeChanged( object sender, SizeChangedEventArgs e )
		{
			if( e.WidthChanged ) ListViewPercentualResize( (ListView)sender );
		}

		private void ListView_TargetUpdated( object sender, System.Windows.Data.DataTransferEventArgs e )
		{
			ListViewPercentualResize( (ListView)sender );
		}

		private static void ListViewPercentualResize( ListView listView )
		{
			if( listView == null ) return;

			GridView view = listView.View as GridView;
			Decorator border = VisualTreeHelper.GetChild( listView, 0 ) as Decorator;
			if( border == null ) return;

			ScrollViewer scroller = border.Child as ScrollViewer;
			if( scroller == null ) return;

			ItemsPresenter presenter = scroller.Content as ItemsPresenter;
			if( presenter == null ) return;

			view.Columns[ 0 ].Width = presenter.ActualWidth;
			for( int i = 1; i < view.Columns.Count; i++ )
				view.Columns[ 0 ].Width -= view.Columns[ i ].ActualWidth;
		}
	}
}
