﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Threading;
using Vela.Controls;
using Vela.Kernel;

namespace Vela.ThemeTester
{
	/// <summary>
	/// Interaction logic for VectorImagesWindow.xaml
	/// </summary>
	public partial class VectorImagesWindow : Window
	{
		public VectorImagesWindow()
		{
			InitializeComponent();
		}

		private void Window_KeyDown( object sender, System.Windows.Input.KeyEventArgs e )
		{
			if( e.Key != System.Windows.Input.Key.Space ) return;

			// Shows all the tabs so that their content is created.
			for( int i = 0; i < ShapesTabControl.Items.Count; i++ )
			{
				ShapesTabControl.SelectedIndex = i;

				Dispatcher.Invoke( new Action( delegate { } ), DispatcherPriority.Background );
			}

			RenderToBitmap( ApplicationShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Application.png" ) );
			RenderToBitmap( ErrorMessageShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Error.png" ) );
			RenderToBitmap( InfoMessageShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Info.png" ) );
			RenderToBitmap( QueryMessageShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Query.png" ) );
			RenderToBitmap( WarningMessageShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Warning.png" ) );
			RenderToBitmap( DoneMessageShape, AssemblyUtils.GetApplicationDataFileName( "Images", "Done.png" ) );
			RenderToBitmap( NoPreviewShape, AssemblyUtils.GetApplicationDataFileName( "Images", "NoPreview.png" ) );
			RenderToBitmap( GenericEmoticonShape, AssemblyUtils.GetApplicationDataFileName( "Images", "GenericEmoticon.png" ) );
			RenderToBitmap( OneNotStartedTrayShape, AssemblyUtils.GetApplicationDataFileName( "Images", "OneNotStarted.png" ) );
			RenderToBitmap( AllServicesStartedTrayShape, AssemblyUtils.GetApplicationDataFileName( "Images"
				, "AllServicesStarted.png" ) );
			RenderToBitmap( AllStartedTrayShape, AssemblyUtils.GetApplicationDataFileName( "Images", "AllStarted.png" ) );
			RenderToBitmap( NewLetterTrayShape, AssemblyUtils.GetApplicationDataFileName( "Images", "NewLetter.png" ) );

			TooltipWindow.ShowTooltip();
		}

		public void RenderToBitmap( FrameworkElement control, string outputImageFile )
		{
			FrameworkElement actualControl = (FrameworkElement)control.Parent;

			RenderTargetBitmap renderTargetBitmap = new RenderTargetBitmap( (int)actualControl.Width, (int)actualControl.Height
				, 96, 96, PixelFormats.Pbgra32 );
			renderTargetBitmap.Render( actualControl );

			PngBitmapEncoder encoder = new PngBitmapEncoder();

			BitmapFrame frame = BitmapFrame.Create( renderTargetBitmap );
			encoder.Frames.Add( frame );

			using( FileStream fileStream = new FileStream( outputImageFile, FileMode.Create ) )
			{
				encoder.Save( fileStream );
			}
		}
	}
}
